function powergui(numfig,flag,systeme)
%POWERGUI  Graphical user interface for the Power System Blockset.
% 
%   POWERGUI opens a visual tool for the power2sys.m function
%
%   See also POWERINIT and POWER2SYS.

%   Patrice Brunelle (TEQSIM) 23-06-97, 15-07-97
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.4 $  

if nargin==0,return;end 

if flag~=0
	objets=get(numfig,'UserData');
	bstart=objets(1);
	bstop=objets(2);
	bclose=objets(3);
	bedit=objets(4);
	bflow=objets(5);
	systeme=get(bedit,'String');
	if flag<6&flag>1
		if ~exist(systeme)
			errordlg([systeme,': File not found'],'Invalid system');
			return
		end
  		%z=loadsavedata(systeme,'load');	
		%if isempty(z)
		%	errordlg('You need to start the simulation first.');
		%	return
		%end
	end
end 


if flag==1
	set(bedit,'ForeGroundColor','black');
	set(numfig,'Pointer','watch');pause(0.1);
	power2sys(systeme);
	set(numfig,'Pointer','arrow');
end
if flag==2

end
if flag==3
	set(bedit,'ForeGroundColor','black');
	powergui_state(numfig,0,systeme);
end
if flag==4
	set(bedit,'ForeGroundColor','black');
	powergui_steady(numfig,0,systeme);
end
if flag==5
	set(bedit,'ForeGroundColor','black');
	powergui_loadflow(numfig,0,systeme);
end
if flag==6
	close(numfig);
end
if flag==7
	set(bedit,'ForeGroundColor','white');
	% a new system is specified: close load flow window
	listefig=get(0,'children');
	flownum=get(bedit,'UserData');
	recherche=find(listefig==flownum);
	if ~isempty(recherche)
		close(flownum);
		set(bedit,'UserData',-1);
	end
	% a new system is specified: close steady state window
	steadynum=get(bstart,'UserData');
	recherche=find(listefig==steadynum);
	if ~isempty(recherche)
		close(steadynum);
		set(bstart,'UserData',-1);
	end
	% a new system is specified: close state variable window
	statenum=get(bstop,'UserData');
	recherche=find(listefig==statenum);
	if ~isempty(recherche),
		close(statenum);
		set(bstop,'UserData',-1);
	end
end

if flag==0

load powergui                             


a = figure('Units','normalized', ...
	'Color',[0.701961 0.701961 0.701961], ...
	'Colormap',mat0, ...
	'MenuBar','none', ...
	'name','POWERGUI',...
	'NumberTitle','off', ...
	'resize','off',...
	'Position',[0.0494792 0.325556 0.116319*1.2 0.282222]*1.1, ...
	'Tag','PowerSystemBlocksetGUI');
b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'Position',[0.0397015 0.0293701 0.915672 0.89189], ...
	'Style','frame', ...
	'Tag','Frame1');
bstop = uicontrol('Parent',a, ...
	'CallBack',['powergui(',num2str(a),',2);'],...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'FontSize',12, ...
	'Position',[0.0746269 0.515748 0.835821 0.0944882], ...
	'String','Stop simulation', ...
	'visible','off', ...
	'UserData',-1, ...
	'Tag','Pushbutton1');
b = uicontrol('Parent',a, ...
	'CallBack',['powergui(',num2str(a),',3);'],...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'FontSize',12, ...
	'Position',[0.0746269 0.401575 0.835821 0.0944882], ...
	'String','Set state variables', ...
	'enable','on',...
	'Tag','Pushbutton1');
b = uicontrol('Parent',a, ...
	'CallBack',['powergui(',num2str(a),',4);'],...
	'Units','normalized', ...
	'FontSize',12, ...
	'Position',[0.0746269 0.287402 0.835821 0.0944882], ...
	'String','Steady state', ...
	'Tag','Pushbutton1');
bflow = uicontrol('Parent',a, ...
	'CallBack',['powergui(',num2str(a),',5);'],...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'FontSize',12, ...
	'Position',[0.0746269 0.173228 0.835821 0.0944882], ...
	'String','Machine load flow', ...
	'enable','off',...
	'Tag','Pushbutton1');
bclose = uicontrol('Parent',a, ...
	'CallBack',['powergui(',num2str(a),',6);'],...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'FontSize',12, ...
	'Position',[0.0746269 0.0590551 0.835821 0.0944882], ...
	'String','Close', ...
	'Tag','Pushbutton1');
bstart = uicontrol('Parent',a, ...
	'CallBack',['powergui(',num2str(a),',1);'],...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'FontSize',12, ...
	'Position',[0.0746269 0.629921 0.835821 0.0944882], ...
	'String','Analyze', ...
	'visible','off', ...
	'UserData',-1, ...
	'Tag','Pushbutton1');
bedit = uicontrol('Parent',a, ...
	'CallBack',['powergui(',num2str(a),',7);'],...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'FontSize',12, ...
	'HorizontalAlignment','center', ...
	'Position',[0.075188 0.744094 0.827068 0.106299], ...
	'String',systeme, ...
	'Style','text', ...
	'UserData',-1, ...
	'Tag','EditText1');

b = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'FontSize',12, ...
	'Position',[0.293233 0.874016 0.388421 0.0669291], ...
	'String','System', ...
	'Style','text', ...
	'Tag','StaticText1');

set(a,'UserData',[bstart bstop bclose bedit bflow]); 
hidegui;
end
