function powergui_loadflow(numfig,flag,systeme,no_edit)
% POWERGUI_LOADFLOW  Graphical user interface for the Machine Load Flow.
%
%    POWERGUI_LOADFLOW opens a visual tool to compute load flow for 
%    circuits that contains machines.
%
%    See also POWERGUI.

%   Patrice Brunelle (TEQSIM) 03-07-97,15-07-97
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.4 $

% initializations.

if nargin==0;return;end
if flag~=0
	objets=get(numfig,'UserData');
	MN=objets(1:3); 
	UABampl=objets(4:6);
	UABphase=objets(7:9); 
	UBCampl=objets(10:12);
	UBCphase=objets(13:15); 
	IAampl=objets(16:18);
	IAphase=objets(19:21); 
	IBampl=objets(22:24);
	IBphase= objets(25:27);
	Pwatt=objets(28:30); 
	bQ=objets(31:33);
	bPmec=objets(34:36); 
	bEf=objets(37:39); 
	chek=objets(40:42);
	shiftL=objets(43); 
	shiftR=objets(44);
	bLoadF=objets(45);
	bClose=objets(46);
	UANphase=objets(47:49);
	popINIT=objets(50);
	popFREQ=objets(51);
	bREVERT=objets(52);
	eds=[UANphase UABampl Pwatt bPmec];
	systeme=get(bLoadF,'UserData');

	pss=loadsavedata(systeme,'load');
	freqyss=pss.freqyss;
	yss=pss.yss;
	uss=pss.uss;

	machines=get(bClose,'UserData');
	dimmin=size(machines,2);
	color=get(MN(2),'UserData');	
end


%%%%%%%%%%%%%%%%   CALLBACK FOR LOAD FLOW BUTTON  %%%%%%%%%%%%%%%%%%%%%%
if flag==1

	initval=get(popINIT,'Value')-1;
	frequen=freqyss(get(popFREQ,'Value'));

	machines=powerflow(systeme,[],[],[],machines,initval,frequen);

	set(bClose,'UserData',machines);
	set(shiftL,'UserData',0); % offset remis a zero
	powergui_loadflow(numfig,3,[],1); % reafficher les resultats
	set(eds(1:12) ,'ForeGroundColor','black');
	set(chek(1:3),'ForeGroundColor','black');
	for i=1:dimmin
		color(i).UANphase='black';
		color(i).UABampl ='black';
		color(i).Pwatt   ='black';
		color(i).Pmec    ='black';
		color(i).chek    ='black';
	end
	set(MN(2),'UserData',color);
end


%%%%%%%%%%%%%%%%   CALLBACK FOR CLOSE BUTTON  %%%%%%%%%%%%%%%%%%%%%%%%%%
if flag==2  % close
	nummaster=get(MN(1),'UserData');
	listefig=get(0,'children');
	recherche=find(listefig==nummaster);
	if ~isempty(recherche)
		objmaster=get(nummaster,'UserData');
		editmaster=objmaster(4);
		set(editmaster,'UserData',-1);
	end
	close(numfig);
end


%%%%%%%%%%%%%%%%   CALLBACK FOR << & >> BUTTONS  %%%%%%%%%%%%%%%%%%%%%%%
if flag==3
	offset=get(shiftL,'UserData');
	if no_edit==1;
		offset=offset-1;
		if offset<0,offset=0;end
	end
	if no_edit==2;
		offset=offset+1;
		if offset>dimmin-3,offset=dimmin-3;end
	end
	set(shiftL,'UserData',offset);
	machinesPART=machines(1+offset:min(dimmin,3)+offset);
	for i=1:min(dimmin,3);
		set(MN(i),'String',machinesPART(i).name);
		valeur=machinesPART(i).Phase;
		set(UANphase(i),'String',valeur, ...
				'ForeGroundColor',color(i+offset).UANphase);
		valeur=yss(machinesPART(i).output)/sqrt(2);
		%amplitude=abs(valeur);
		phase=angle(valeur)*180/pi;
		phase=[sprintf('%3.2f',phase) setstr(176)];
		%amplitude=sprintf('%0.5g',amplitude);
		set(UABampl(i),'String',machines(i+offset).Vt, ...
				'ForeGroundColor',color(i+offset).UABampl);
		set(UABphase(i),'String',phase);
		valeur=yss(machinesPART(i).output+1)/sqrt(2);	
		amplitude=abs(valeur);
		amplitude=sprintf('%0.5g',amplitude);
		phase=angle(valeur)*180/pi;
		phase=[sprintf('%3.2f',phase) setstr(176)];
		set(UBCampl(i),'String',amplitude);
		set(UBCphase(i),'String',phase);
		valeur=uss(machinesPART(i).input)/sqrt(2);  	
		amplitude=abs(valeur);
		amplitude=sprintf('%0.5g',amplitude);
		phase=angle(valeur)*180/pi;
		phase=[sprintf('%3.2f',phase) setstr(176)];
		set(IAampl(i),'String',amplitude);
		set(IAphase(i),'String',phase);
		valeur=uss(machinesPART(i).input+1)/sqrt(2); 	
		amplitude=abs(valeur);
		amplitude=sprintf('%0.5g',amplitude);
		phase=angle(valeur)*180/pi;
		phase=[sprintf('%3.2f',phase) setstr(176)];
		set(IBampl(i),'String',amplitude);
		set(IBphase(i),'String',phase);
		valeur=machinesPART(i).P;
		valeur=sprintf('%0.5g',valeur);
		set(Pwatt(i),'String',valeur, ...
			     'ForeGroundColor',color(i+offset).Pwatt);
		valeur=machinesPART(i).Q;
		valeur=sprintf('%0.5g',valeur);
		set(bQ(i),'String',valeur);
		valeur=machinesPART(i).Pmec;
		valeur=sprintf('%0.5g',valeur);
		set(bPmec(i),'String',valeur, ...
			     'ForeGroundColor',color(i+offset).Pmec);
		valeur=machinesPART(i).Ef;
		valeur=sprintf('%0.4g',valeur);
		set(bEf(i),'String',valeur);
		valeur=(machinesPART(i).bustype);
		if machinesPART(i).type==33 % PM motor
			set(chek(i),'String','Asynchronous motor', ...
				    'Value',[1], ...
				    'style','text', ...
				    'ForeGroundColor',color(i+offset).chek);
			set(UABampl(i),'style','text');
			set(Pwatt(i),'style','text');
			set(bPmec(i),'style','edit');
		else
			set(chek(i),'Style','popup', ...
				    'String','PV generator|Swing generator', ...
				    'Value',valeur, ...
			    	    'ForeGroundColor',color(i+offset).chek);
			set(UABampl(i),'style','edit');
			set(Pwatt(i),'style','edit');
			set(bPmec(i),'style','text');
		end	    
		if valeur~=2
			set(UANphase(i),'style','text');
		else 
			set(UANphase(i),'style','edit');
		end
	end
end


%%%%%%%%%%%%%%%%   CALLBACK FOR POPUP   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if flag==4
	offset=get(shiftL,'UserData');
	set(chek(no_edit),'ForeGroundColor','white');
	color(no_edit+offset).chek='white';
	valeur=get(chek(no_edit),'Value');
	offset=get(shiftL,'UserData');
	machines(no_edit+offset).bustype=valeur;
	set(bClose,'UserData',machines);
	if valeur~=2, set(UANphase(no_edit),'style','text');
	  else set(UANphase(no_edit),'style','edit');
	end;
	set(MN(2),'UserData',color);
end


%%%%%%%%%%%%%%%%   CALLBACK for EDITS   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if flag==5
	valeur=str2num(get(eds(no_edit),'String'));
	offset=get(shiftL,'UserData');
	switch no_edit
	case {1,2,3}
		machines(no_edit+offset).Phase=valeur;
		color(no_edit+offset).UANphase='white';
	case {4,5,6}
		machines(no_edit-3+offset).Vt=valeur;
		color(no_edit-3+offset).UABampl='white';
	case {7,8,9}
		machines(no_edit-6+offset).P=valeur;
		color(no_edit-6+offset).Pwatt='white';
	case {10,11,12}
		machines(no_edit-9+offset).Pmec=valeur;
		color(no_edit-9+offset).Pmec='white';
	end
	set(bClose,'UserData',machines);
	set(eds(no_edit),'ForeGroundColor','white');
	set(MN(2),'UserData',color);
end

%%%%%%%%%%%%%%%%   CALLBACK for REVERT   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if flag==6
	machines=get(bREVERT,'UserData');
	set(bClose,'UserData',machines);
	set(shiftL,'UserData',0); % offset remis a zero
	powergui_loadflow(numfig,3,[],1); % reafficher les resultats
	set(eds(1:12) ,'ForeGroundColor','black');
	set(chek(1:3),'ForeGroundColor','black');
	for i=1:dimmin
		color(i).UANphase='black';
		color(i).UABampl ='black';
		color(i).Pwatt   ='black';
		color(i).Pmec    ='black';
		color(i).chek    ='black';
	end
	set(MN(2),'UserData',color);

	pss.machines=machines;
	loadsavedata(systeme,'save',pss);

end

%%%%%%%%%%%%%%%%%%   OPEN the GUI   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if flag==0  % ouverture et affichage initial

	load powergui_loadflow 
 	pss=loadsavedata(systeme,'load');
	machines=pss.machines;
	yss=pss.yss;
	uss=pss.uss;
	freqyss=pss.freqyss;

	dimmin=size(machines,2);
	if dimmin==0,warndlg(['There is no machine blocks in ',systeme],'Load Flow message');
		return;
	end
	for i=1:dimmin
		color(i).UANphase='black';
		color(i).UABampl ='black';
		color(i).Pwatt   ='black';
		color(i).Pmec	 ='black';
		color(i).chek    ='black';
	end

	a = figure('Units','normalized', ...
		'Color',[0.701961 0.701961 0.701961], ...
		'Colormap',mat0, ...
		'Resize','off', ...
		'MenuBar','none', ...
		'NumberTitle','off', ...
		'Name',['MACHINE LOAD FLOW     system:  ',systeme], ...
		'Position',[0.1866,0.1289,0.5625,0.4911]*1.1, ...
		'Tag','LoadFlowComputation');
			
	positions=[	0.00154083 0.108352 0.178737 0.889391;
			-0.00154083 0 0.998459 0.103837;
			0.177196 0.108352 0.27735 0.889391;
			0.449923 0.108352 0.275809 0.889391;
			0.721109 0.108352 0.27735 0.889391];
	for i=1:5
		bf(i) = uicontrol('Parent',a, ...
		'Units','normalized', ...
		'Position',positions(i,1:4), ...
		'Style','frame', ...
		'Tag','Frame');
	end
	
	objmaster=get(numfig,'UserData');
	editmaster=objmaster(4);
	set(editmaster,'UserData',a);  % keep loadflowfigurenumber in mainwindowedit UI

	positions=[	0.194145 0.873589 0.243451 0.0925508;
			0.465331 0.873589 0.243451 0.0925508;
			0.736518 0.873589 0.244992 0.0902935];
	for i=1:3
		MN(i) = uicontrol('Parent',a, ...
		'Units','normalized', ...
		'BackgroundColor',[0.701961 0.701961 0.701961], ...
		'Max',5, ...
		'Position',positions(i,1:4), ...
		'String',' ', ...
		'Style','text', ...
		'Tag','StaticText');
		if i<=dimmin, set(MN(i),'String',machines(i).name);end
	end
	
	set(MN(1),'UserData',numfig);
	set(MN(2),'UserData',color);
			
	positions=[	0.194145 0.133183 0.112481 0.0383747;
			0.468413 0.133183 0.112481 0.0383747;
			0.74114  0.133183 0.112481 0.0383747];
	for i=1:3
		Gliss(i) = uicontrol('Parent',a, ...
		'Units','normalized', ...
		'BackgroundColor',[0.701961 0.701961 0.701961], ...
		'HorizontalAlignment','right', ...
		'Position',positions(i,1:4), ...
		'String',' ', ...
		'Style','text', ...
		'Tag','StaticText');
		if i<=dimmin, set(Gliss(i),'String',machines(i).slip);end
	end

	positions=[	0.194145 0.738149 0.11094  0.0474041 ;
			0.468413 0.738149 0.112481 0.0474041 ;
			0.744222 0.738149 0.112481 0.0474041 ];
	for i=1:3	  	
		UANphase(i) = uicontrol('Parent',a, ...
		'CallBack',['powergui_loadflow(',num2str(a),',5,[],' num2str(i) ');'],...
		'Units','normalized', ...
		'BackgroundColor',[0.701961 0.701961 0.701961], ...
		'Position',positions(i,1:4), ...
		'String',' ', ...
		'HorizontalAlignment','right',...
		'Style','edit', ...
		'Tag','');
		if i<=dimmin,
			valeur=machines(i).Phase;
			set(UANphase(i),'String',valeur);
		else
			set(UANphase(i),'visible','off');
		end
	end

	positions=[	0.194145 0.670429 0.11094 0.0496614 0.328197 0.670429 0.112481 0.0406321;
			0.468413 0.670429 0.112481 0.0496614 0.607088 0.670429 0.11094 0.0406321;
			0.744222 0.670429 0.112481 0.0496614 0.882897 0.670429 0.11094 0.0406321];

	for i=1:3	
		UABampl(i) = uicontrol('Parent',a, ...
		'CallBack',['powergui_loadflow(',num2str(a),',5,[],' num2str(i+3) ');'],...
		'Units','normalized', ...
		'BackgroundColor',[0.701961 0.701961 0.701961], ...
		'Position',positions(i,1:4), ...
		'String',' ', ...
		'HorizontalAlignment','right',...
		'Style','edit', ...
		'Tag','');
		UABphase(i) = uicontrol('Parent',a, ...
		'Units','normalized', ...
		'BackgroundColor',[0.701961 0.701961 0.701961], ...
		'Position',positions(i,5:8), ...
		'String',' ', ...
		'HorizontalAlignment','left',...
		'Style','text', ...
		'Tag','');
		if i<=dimmin,
			valeur=yss(machines(i).output)/sqrt(2);	  % Vrms
			%amplitude=abs(valeur);
			phase=angle(valeur)*180/pi;
			phase=[sprintf('%3.2f',phase) setstr(176)];
			%amplitude=sprintf('%0.5g',amplitude);
			set(UABampl(i),'String',machines(i).Vt);
			set(UABphase(i),'String',phase);
		else
			set(UABampl(i),'visible','off');
		end
	end
	
	positions=[	0.194145 0.604966 0.11094 0.0406321 0.328197 0.604966 0.112481 0.0406321;
			0.468413 0.604966 0.112481 0.0406321 0.607088 0.604966 0.11094 0.0406321;
			0.744222 0.604966 0.112481 0.0406321 0.882897 0.604966 0.11094 0.0406321];

	for i=1:3
		UBCampl(i) = uicontrol('Parent',a, ...
		'Units','normalized', ...
		'BackgroundColor',[0.701961 0.701961 0.701961], ...
		'Position',positions(i,1:4), ...
		'String',' ' , ...
		'HorizontalAlignment','right',...
		'Style','text', ...
		'Tag','StaticText');
		UBCphase(i) = uicontrol('Parent',a, ...
		'Units','normalized', ...
		'BackgroundColor',[0.701961 0.701961 0.701961], ...
		'Position',positions(i,5:8), ...
		'String',' ', ...
		'HorizontalAlignment','left',...
		'Style','text', ...
		'Tag','StaticText');
		if i<=dimmin,
			valeur=yss(machines(i).output+1)/sqrt(2);  % Vrms	
			amplitude=abs(valeur);
			amplitude=sprintf('%0.5g',amplitude);
			phase=angle(valeur)*180/pi;
			phase=[sprintf('%3.2f',phase) setstr(176)];
			set(UBCampl(i),'String',amplitude);
			set(UBCphase(i),'String',phase);
		end	
	end
	positions=[	0.194145 0.5408 0.11094 0.0406321 0.328197 0.5408 0.112481 0.0406321;
			0.468413 0.5408 0.112481 0.0406321 0.607088 0.5408 0.11094 0.0406321;
			0.744222 0.5408 0.112481 0.0406321 0.882897 0.5408 0.11094 0.0406321];
	for i=1:3
		IAampl(i) = uicontrol('Parent',a, ...
		'Units','normalized', ...
		'BackgroundColor',[0.701961 0.701961 0.701961], ...
		'Position',positions(i,1:4), ...
		'String',' ', ...
		'HorizontalAlignment','right',...
		'Style','text', ...
		'Tag','StaticText');
		IAphase(i)= uicontrol('Parent',a, ...
		'Units','normalized', ...
		'BackgroundColor',[0.701961 0.701961 0.701961], ...
		'Position',positions(i,5:8), ...
		'String',' ', ...
		'HorizontalAlignment','left',...
		'Style','text', ...
		'Tag','StaticText');
		if i<=dimmin,
			valeur=uss(machines(i).input)/sqrt(2);  % Irms	
			amplitude=abs(valeur);
			amplitude=sprintf('%0.5g',amplitude);
			phase=angle(valeur)*180/pi;
			phase=[sprintf('%3.2f',phase) setstr(176)];
			set(IAampl(i),'String',amplitude);
			set(IAphase(i),'String',phase);
		end
	end
	
	positions=[	0.194145 0.476298 0.11094 0.0406321 0.328197 0.476298 0.112481 0.0406321;
			0.468413 0.476298 0.112481 0.0406321 0.607088 0.476298 0.11094 0.0406321;
			0.744222 0.476298 0.112481 0.0406321 0.882897 0.476298 0.11094 0.0406321];
	for i=1:3
		IBampl(i) = uicontrol('Parent',a, ...
		'Units','normalized', ...
		'BackgroundColor',[0.701961 0.701961 0.701961], ...
		'Position',positions(i,1:4), ...
		'String',' ', ...
		'HorizontalAlignment','right',...
		'Style','text', ...
		'Tag','StaticText');
		IBphase(i) = uicontrol('Parent',a, ...
		'Units','normalized', ...
		'BackgroundColor',[0.701961 0.701961 0.701961], ...
		'Position',positions(i,5:8), ...
		'String',' ', ...
		'HorizontalAlignment','left',...
		'Style','text', ...
		'Tag','StaticText');
		if i<=dimmin,
			valeur=uss(machines(i).input+1)/sqrt(2); % Irms	
			amplitude=abs(valeur);
			amplitude=sprintf('%0.5g',amplitude);
			phase=angle(valeur)*180/pi;
			phase=[sprintf('%3.2f',phase) setstr(176)];
			set(IBampl(i),'String',amplitude);
			set(IBphase(i),'String',phase);
		end
	end
	positions=[	0.194145 0.401806 0.115562 0.0496614;
			0.468413 0.401806 0.117103 0.0496614;
			0.744222 0.401806 0.118644 0.0496614];
	for i=1:3
		Pwatt(i) = uicontrol('Parent',a, ...
		'CallBack',['powergui_loadflow(',num2str(a),',5,[],' num2str(i+6) ' );'],...
		'Units','normalized', ...
		'BackgroundColor',[0.701961 0.701961 0.701961], ...
		'Position',positions(i,1:4), ...
		'String',' ', ...
		'HorizontalAlignment','right',...
		'Style','edit', ...
		'Tag',['Pwatt(',i,')']);
		if i<=dimmin,
			valeur=machines(i).P;
			valeur=sprintf('%0.5g',valeur);
			set(Pwatt(i),'String',valeur);
		else
			set(Pwatt(i),'visible','off');
		end
	end
	positions=[	0.194145 0.336343 0.11094 0.0406321;
			0.468413 0.336343 0.112481 0.0406321;
			0.744222 0.336343 0.112481 0.0406321];
	for i=1:3
		bQ(i) = uicontrol('Parent',a, ...
		'Units','normalized', ...
		'BackgroundColor',[0.701961 0.701961 0.701961], ...
		'Position',positions(i,1:4), ...
		'String',' ', ...
		'HorizontalAlignment','right',...
		'Style','text', ...
		'Tag','StaticText');
		if i<=dimmin,
			valeur=machines(i).Q;
			valeur=sprintf('%0.5g',valeur);
			set(bQ(i),'String',valeur);
		end
	end
	positions=[	0.194145 0.27088 0.11094  0.0496614;
			0.468413 0.27088 0.112481 0.0496614;
			0.744222 0.27088 0.112481 0.0496614];
	for i=1:3
		bPmec(i) = uicontrol('Parent',a, ...
		'CallBack',['powergui_loadflow(',num2str(a),',5,[],' num2str(i+9) ' );'],...
		'Units','normalized', ...
		'BackgroundColor',[0.701961 0.701961 0.701961], ...
		'Position',positions(i,1:4), ...
		'String',' ', ...
		'HorizontalAlignment','right',...
		'Style','text', ...
		'Tag','StaticText');
		if i<=dimmin,
			valeur=machines(i).Pmec;
			valeur=sprintf('%0.5g',valeur);
			set(bPmec(i),'String',valeur);
		end
	end
	positions=[	0.194145 0.205418 0.11094  0.0383747;
			0.468413 0.205418 0.112481 0.0383747;
			0.744222 0.205418 0.112481 0.0383747];
	for i=1:3
		bEf(i) = uicontrol('Parent',a, ...
		'Units','normalized', ...
		'BackgroundColor',[0.701961 0.701961 0.701961], ...
		'Position',positions(i,1:4), ...
		'String',' ', ...
		'HorizontalAlignment','right',...
		'Style','text', ...
		'Tag','StaticText');
		if i<=dimmin,
			valeur=machines(i).Ef;
			valeur=sprintf('%0.4g',valeur);
			set(bEf(i),'String',valeur);
		end
	end
	
	positions=[	0.194444 0.807692 0.111111+.04 0.0484615;
			0.469136 0.807692 0.112654+.04 0.0484615;
			0.746914 0.807692 0.112654+.04 0.0484615];
	for i=1:3
		chek(i) = uicontrol('Parent',a, ...
		'CallBack',['powergui_loadflow(',num2str(a),',4,[],' num2str(i) ');'],...
		'Units','normalized', ...
		'BackgroundColor',[0.701961 0.701961 0.701961], ...
		'String','PV generator|Swing generator', ...
		'Position',positions(i,1:4), ...
		'Value',1 ,...
		'Style','popup', ...
		'Tag','popup');
		if i<=dimmin,
			valeur=(machines(i).bustype);
			if valeur~=2, 
				set(UANphase(i),'style','text');
			end;
			if valeur<=2, set(chek(i),'Value',valeur);end
		else
			set(chek(i),'Visible','off');
		end
		if i<=dimmin,
			if machines(i).type==33 % PM motor
				set(chek(i),'String','Asynchronous motor','style','text');
				set(UABampl(i),'style','text');
				set(Pwatt(i),'style','text');
				set(bPmec(i),'style','edit');
			end
		end
	end
	
	bLoadF = uicontrol('Parent',a, ...
	'CallBack',['powergui_loadflow(',num2str(a),',1);'],...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961]+.05, ...
	'FontSize',12, ...
	'Position',[0.570988 0.0181406 0.154321 0.0612245], ...
	'String','Do load Flow', ...
	'UserData',systeme, ...
	'Tag','Pushbutton1');

	bREVERT = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.751961 0.751961 0.751961], ...
	'CallBack',['powergui_loadflow(',num2str(a),',6);'],...
	'FontSize',12, ...
	'Position',[0.729938 0.0181406 0.0848765 0.0612245], ...
	'String','revert', ...
	'Enable','on', ...
	'UserData',machines, ...
	'Tag','Pushbutton1');
		
	bClose = uicontrol('Parent',a, ...
	'CallBack',['powergui_loadflow(',num2str(a),',2);'],...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961]+.05, ...
	'FontSize',12, ...
	'Position',[0.817901 0.0181406 0.0848765 0.0612245], ...
	'String','Close', ...
	'UserData',machines, ...
	'Tag','Pushbutton1');
	
	shiftL = uicontrol('Parent',a, ...
	'CallBack',['powergui_loadflow(',num2str(a),',3,[],1);'],...
	'Units','normalized', ...
	'Position',[0.907407 0.0181406 0.0354938 0.0612245], ...
	'BackgroundColor',[0.701961 0.701961 0.701961]+.05, ...
	'String','<<', ...
	'visible','on',...
	'Tag','Pushbutton2');
	
	if dimmin<=3,set(shiftL,'visible','off');end
	set(shiftL,'UserData',0);  % offset de l'indice structure machines
	
	shiftR = uicontrol('Parent',a, ...
	'CallBack',['powergui_loadflow(',num2str(a),',3,[],2);'],...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961]+.05, ...
	'Position',[0.945988 0.0181406 0.037037 0.0612245], ...
	'String','>>', ...
	'visible','on',...
	'Tag','Pushbutton2');
	
	if dimmin<=3,set(shiftR,'visible','off');end
	
	txt = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'HorizontalAlignment','left', ...
	'FontSize',12, ...
	'Position',[0.0138889 0.927765 0.149461 0.0406321], ...
	'String','Machine :', ...
	'Style','text', ...
	'Tag','StaticText2');

	txt = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'FontSize',12, ...
	'HorizontalAlignment','left', ...
	'Position',[0.0138675 0.133183 0.149461 0.0383747], ...
	'String','Slip (pu):', ...
	'Style','text', ...
	'Tag','StaticText2');
	
	txt = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'HorizontalAlignment','left', ...
	'FontSize',12, ...
	'Position',[0.0123267 0.742664 0.149461 0.0406321], ...
	'String',['UAN phase',setstr(176),':'], ...
	'Style','text', ...
	'Tag','StaticText2');	

	txt = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'HorizontalAlignment','left', ...
	'FontSize',12, ...
	'Position',[0.0138675 0.677201 0.149461 0.0406321], ...
	'String','UAB (V rms):', ...
	'Style','text', ...
	'Tag','StaticText2');

	txt = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'HorizontalAlignment','left', ...
	'FontSize',12, ...
	'Position',[0.0138675 0.607223 0.149461 0.0406321], ...
	'String','UBC (V rms):', ...
	'Style','text', ...
	'Tag','StaticText2');
	
	txt = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'HorizontalAlignment','left', ...
	'FontSize',12, ...
	'Position',[0.0138675 0.541761 0.149461 0.0406321], ...
	'String','IA (A rms):', ...
	'Style','text', ...
	'Tag','StaticText2');
	
	txt = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'HorizontalAlignment','left', ...
	'FontSize',12, ...
	'Position',[0.0138675 0.474041 0.149461 0.0406321], ...
	'String','IB (A rms):', ...
	'Style','text', ...
	'Tag','StaticText2');

	txt = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'HorizontalAlignment','left', ...
	'FontSize',12, ...
	'Position',[0.0138675 0.406321 0.149461 0.0406321], ...
	'String','P (Watts):', ...
	'Style','text', ...
	'Tag','StaticText2');

	txt = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'HorizontalAlignment','left', ...
	'FontSize',12, ...
	'Position',[0.0138675 0.3386 0.149461 0.0406321], ...
	'String','Q (vars):', ...
	'Style','text', ...
	'Tag','StaticText2');

	txt = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'HorizontalAlignment','left', ...
	'FontSize',12, ...
	'Position',[0.0138675 0.27088 0.149461 0.0383747], ...
	'String','Pmec (watts):', ...
	'Style','text', ...
	'Tag','StaticText2');
	
	txt = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'HorizontalAlignment','left', ...
	'FontSize',12, ...
	'Position',[0.0138675 0.200903 0.149461 0.0406321], ...
	'String','Ef (pu):', ...
	'Style','text', ...
	'Tag','StaticText2');
	
	txt = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'HorizontalAlignment','left', ...
	'FontSize',12, ...
	'Position',[0.0138889 0.807692 0.149691 0.0384615], ...
	'String','Bus type:', ...
	'Style','text', ...
	'Tag','StaticText2');

	txt = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'Position',[0.226111 0.0181087 0.167346 0.0612245/1.3], ...
	'String','Initial conditions:', ...
	'Style','text', ...
	'Tag','StaticText8');
	
	popINIT = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.751961 0.751961 0.751961], ...
	'Max',2, ...
	'Min',1, ...
	'Position',[0.37037 0.0181087 0.132716 0.0612245], ...
	'String',['Auto    ';'Previous'], ...
	'Style','popupmenu', ...
	'Tag','PopupMenu1', ...
	'Value',1);
	
	txt = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'Position',[0.0308642 0.0181087 0.100309 0.0612245/1.3], ...
	'String','Frequency:', ...
	'Style','text', ...
	'Tag','StaticText8');
	
	texte=mat2str(freqyss);
	if isempty(findstr(texte,'[')),
		texte=[texte,' Hz'];
	else
		texte=strrep(texte,' ',' Hz|');
		texte=strrep(texte,'[','');
		texte=strrep(texte,']',' Hz');
	end

	indice=find(freqyss==60);
	if isempty(indice),
		indice=1;
	end
	
	popFREQ = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961]+0.05, ...
	'Min',1, ...
	'Position',[0.126543 0.0181087 0.111111 0.0612245], ...
	'String',texte, ...
	'Value',indice, ...
	'Style','popupmenu', ...
	'Tag','PopupMenu2');
	
	set(a,'UserData',[MN UABampl UABphase UBCampl UBCphase IAampl IAphase IBampl IBphase Pwatt bQ bPmec bEf chek shiftL shiftR bLoadF bClose UANphase popINIT popFREQ bREVERT]);
	hidegui
end
