function  powergui_state(numfig,flag,systeme,no_edit);
% POWERGUI_STATE  Graphical user interface for initial states setting.
%
%    POWERGUI_STATE opens a visual tool to set initial states of an electrical
%    model build with the Power System Blockset.
%
%    See also POWERGUI.

%   Patrice Brunelle (TEQSIM) 03-07-97,15-07-97
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.5 $
 
if nargin==0;return;end

if flag~=0  % initialization.

	objets=get(numfig,'UserData');
	b=objets(1:6);
	e=objets(7:8);
	f=objets(9);
	systeme=get(b(1),'UserData');
	z=loadsavedata(systeme,'load');
end
if flag==1  % Reset-to-zero button.
	
	lockstates='on';
	set(b(2),'UserData',lockstates);
	x0=abs(z.x0*0.0);
	texte=[];
	state_var=deblank(z.state_var);
	i=find(state_var==0);
	state_var(i)=' ';
	for i=1:size(x0,1);
		ligne=[ sprintf('%s %11.4g',state_var(i,:),x0(i,1))];
		texte=str2mat(texte,ligne);
	end	
	texte=texte(2:size(texte,1),:); 
	set(e(1),'String',texte, ...
		 'UserData',x0);   % memoriser la valeur affichee.
end
if flag==2  % Steady-state button.

	lockstates='off';
	set(b(2),'UserData',lockstates);
	x0=z.x0perm;
	texte=[];
	state_var=deblank(z.state_var);
	i=find(state_var==0);
	state_var(i)=' ';
	for i=1:size(x0,1);
		ligne=[ sprintf('%s %11.4g',state_var(i,:),x0(i,1))];
		texte=str2mat(texte,ligne);
	end	
	texte=texte(2:size(texte,1),:); 
	set(e(1),'String',texte, ...
		 'UserData',x0);   % memoriser la valeur affichee.
end
if flag==3  % Apply button.

	x0=get(e(1),'UserData');   % lis la valeur affichee
	% set(b(4),'UserData',x0);   % sauvegarde dans valeur accepte
	powerinit(systeme,'set',x0);  % ecrire dans loadsavedata
	z=loadsavedata(systeme,'load');
	lockstates=get(b(2),'UserData');
	z.lockstates=lockstates;
	loadsavedata(systeme,'save',z);

end
if flag==4  % Revert button.

	x0=get(b(4),'UserData');   % va chercher valeur a l'ouverture.
	if x0==z.x0perm
	   lockstates='off';
	else
	   lockstates='on';
	end
	set(b(2),'UserData',lockstates);
	powerinit(systeme,'set',x0);  % ecrire dans le fichier .mat
	z=loadsavedata(systeme,'load');
	lockstates=get(b(2),'UserData');
	z.lockstates=lockstates;
	loadsavedata(systeme,'save',z);
	texte=[];
	state_var=deblank(z.state_var);
	i=find(state_var==0);
	state_var(i)=' ';
	for i=1:size(x0,1);
		ligne=[ sprintf('%s %11.4g',state_var(i,:),x0(i,1))];
		texte=str2mat(texte,ligne);
	end	
	texte=texte(2:size(texte,1),:); 
	set(e(1),'String',texte, ...
		 'UserData',x0);   % memoriser la valeur affichee.
end
if flag==5  % Set-to edit.

	lockstates='on';
	set(b(2),'UserData',lockstates);
	x0=get(e(1),'UserData');   % lis le vecteur x0 actuel
	posit=get(e(1),'Value');   % lis la position de la barre
	strin=get(e(2),'String');  % la nouvelle valeur de x(n)
	x0(posit)=str2num(strin);
	texte=[];
	state_var=deblank(z.state_var);
	i=find(state_var==0);
	state_var(i)=' ';
	for i=1:size(x0,1);
		ligne=[ sprintf('%s %11.4g',state_var(i,:),x0(i,1))];
		texte=str2mat(texte,ligne);
	end	
	texte=texte(2:size(texte,1),:); 
	set(e(1),'String',texte, ...
		 'UserData',x0);   % Sauvegarder la valeur affichee.
end
if flag==6  % Help button.
	disp('Help window is not available');
end
if flag==7  % close button.
	nummaster=get(f(1),'UserData');
	listefig=get(0,'children');
	recherche=find(listefig==nummaster);
	if ~isempty(recherche)
		objmaster=get(nummaster,'UserData');
		stopmaster=objmaster(2);
		set(stopmaster,'UserData',-1);
	end
	close(numfig);
end



% Open the GUI: ..........................................................

if flag==0

	z=loadsavedata(systeme,'load');

	if isempty(z) % first time analysis.

		% get initial values.
		set(numfig,'Pointer','watch');pause(0.1);
		[A,B,C,D,x0,state_var,inputs,outputs,uss,xss,yss,freqyss,Hlin,rlc,source,switchns,nb_true_sensor,ans,ans,ans,ans,true_source,inoutinfo]=power2sys(systeme,'g');

   		% Data structure.
  		z.A=A;
   		z.B=B;
   		z.C=C;
   		z.D=D;
  		z.x0=x0;
   		z.uss=uss;
   		z.xss=xss;
   		z.yss=yss;
   		z.inputs=inputs;
   		z.outputs=outputs;
   		z.freqyss=freqyss;
   		z.phisat=[];
   		z.isat=[];
   		z.nb_points=[];
   		z.fluxinit=[];
   		z.Hlin=[];
   		z.true_source=true_source;
   		z.nb_true_sensor=nb_true_sensor; 
   		z.source=source;
   		z.switchns=switchns; 
   		z.rlsw=[]; 
   		z.unit=[]; 
   		z.line_dist=[];
   		z.simsensor=[]; 
   		z.machines=[]; 
   		z.inoutinfo=inoutinfo;

		z.x0=x0;
		z.state_var=state_var;
		z.x0perm=x0;
		z.ref_maskvalue=[];
		z.ref_lines=[];
		lockstates='off';
		z.lockstates='off';

		loadsavedata(systeme,'save',z);
		set(numfig,'Pointer','arrow');

	else
		lockstates=z.lockstates;
	end

	dimmin=size(z.state_var,1);
	if dimmin==0,warndlg(['There is no state variables in ',systeme],'State variables message');
		return;
	end
	
		
a = figure('Units','normalized', ...
	'Color',[0.701961 0.701961 0.701961], ... 
	'MenuBar','none', ... 
	'Name','State Variables', ... 
	'NumberTitle','off', ... 
	'Resize','off', ...
	'Position',[0.1797    0.2144    0.4444    0.4344], ...
	'Tag','Fig1');
	
	objmaster=get(numfig,'UserData');
	stopmaster=objmaster(2);
	set(stopmaster,'UserData',a);  % keep loadflowfigurenumber in mainwindowedit UI
	
f(1) = uicontrol('Parent',a, ... 
	'Units','normalized', ... 
	'BackgroundColor',[0.701961 0.701961 0.701961], ... 
	'Position',[0.0195312 0.126722 0.953125 0.812672], ...
	'Style','frame', ... 
	'Tag','Frame1');
	
	set(f(1),'UserData',numfig);
	
b(1) = uicontrol('Parent',a, ... 
	'Units','normalized', ... 
	'Fontsize',12, ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ... 
	'Callback',['powergui_state(',num2str(a),',1)'], ...
	'Position',[0.480469 0.168044 0.214844 0.0688705], ...
	'String','Reset to zero', ... 
	'UserData',systeme, ...
	'Tag','Pushbutton1');
b(2) = uicontrol('Parent',a, ... 
	'Units','normalized', ...
	'Fontsize',12, ... 
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'Callback',['powergui_state(',num2str(a),',2)'], ... 
	'Position',[0.740234 0.168044 0.205078 0.0688705], ...
	'String','Steady-state', ...
	'UserData',lockstates , ... 
	'Tag','Pushbutton1');
b(3) = uicontrol('Parent',a, ... 
	'Units','normalized', ... 
	'Fontsize',12, ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ... 
	'Callback',['powergui_state(',num2str(a),',3)'], ...
	'Position',[0.615234 0.0330579 0.111328 0.0716253], ...
	'String','Apply', ... 
	'Tag','Pushbutton2');
b(4) = uicontrol('Parent',a, ... 
	'Units','normalized', ...
	'Fontsize',12, ... 
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'Callback',['powergui_state(',num2str(a),',4)'], ... 
	'Position',[0.736328 0.0330579 0.113281 0.0716253], ...
	'String','Revert', ... 
	'Tag','Pushbutton2');	 
b(5) = uicontrol('Parent',a, ... 
	'Units','normalized', ... 
	'Fontsize',12, ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'Callback',['powergui_state(',num2str(a),',6)'], ... 
	'Position',[0.492188 0.0330579 0.111328 0.0716253], ...
	'String','Help', ...
	'visible','off', ...
	'Tag','Pushbutton2'); 
b(6) = uicontrol('Parent',a, ... 
	'Callback',['powergui_state(',num2str(a),',7)'], ... 
	'Units','normalized', ... 
	'Fontsize',12, ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ... 
	'Position',[0.859375 0.0330579 0.111328 0.0716253], ...
	'String','Close', ... 
	'Tag','Pushbutton2', ...
	'UserData',systeme);  
s = uicontrol('Parent',a, ... 
	'Units','normalized', ... 
	'Fontsize',12, ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ... 
	'Position',[0.0332031 0.903581 0.228516 0.0578512], ...
	'String','States variables:', ... 
	'Style','text', ... 
	'Tag','StaticText1'); 
e(1) = uicontrol('Parent',a, ... 
	'Units','normalized', ...
	'Fontsize',12, ... 
	'BackgroundColor',[1 1 1], ... 
	'Position',[0.0410156 0.280992 0.904297 0.614325], ...
	'String',' ', ... 
	'Style','listbox', ... 
	'FontName','Courrier',... 
	'Tag','Listbox1', ... 
	'Value',1);  
s = uicontrol('Parent',a, ... 
	'Units','normalized', ... 
	'Fontsize',12, ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ... 
	'Position',[0.0410156 0.176309 0.117188 0.0578512], ...
	'String','Set to:', ... 
	'Style','text', ... 
	'Tag','StaticText2'); 
e(2) = uicontrol('Parent',a, ... 
	'Units','normalized', ... 
	'Fontsize',12, ...
	'BackgroundColor',[1 1 1], ...
	'Callback',['powergui_state(',num2str(a),',5)'], ... 
	'Position',[0.189453 0.173554 0.236328 0.0716253], ...
	'Style','edit', ... 
	'Tag','EditText1'); 

	hidegui;
	set(a,'UserData',[b,e,f]);

% initial states  at the opening:

        x0=z.x0;
	texte=[];
	state_var=deblank(z.state_var);
	i=find(state_var==0);
	state_var(i)=' ';
	for i=1:size(x0,1);
		ligne=[ sprintf('%s %11.4g',state_var(i,:),x0(i,1))];
		texte=str2mat(texte,ligne);
	end	
	texte=texte(2:size(texte,1),:);	
	set(e(1),'String',texte,...
		 'UserData',z.x0); % memoriser la valeur affichee.
	set(b(4),'UserData',z.x0); % Sauvegarder pour le Revert button.
	
end

