function powergui_steady(numfig,flag,systeme,no_edit)
% POWERGUI_STEADY   Graphical user interface for steady-state informations.
%
%    POWERGUI_STEADY  opens a visual tool that displays steady-state
%    informations for an electrical model build with the Power System Blockset.
%
%    See also POWERGUI.

%   Patrice Brunelle (TEQSIM) 04-07-97,15-07-97
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.5 $  

%%%%%%%%%%%%%%%%   INITIALISATIONS  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if nargin==0; return; end
if flag~=0

	objets=get(numfig,'UserData');
	fr(1)=objets(1);
	AMPL=objets(2);
	PHAZ=objets(3);
	FREQ=objets(4);
	LB=objets(5:8);
	fr(2)=objets(9);
	fr(3)=objets(10);
	POP=objets(11);
	REVERT=objets(12);
	eds=[AMPL PHAZ FREQ];
	systeme=get(fr(1),'UserData');	
	
	z=loadsavedata(systeme,'load');
	uss=z.uss;
	yss=z.yss;

	% patch en attendant la structure inoutinfo:
		
	q         =size(z.true_source,1); 
	p         =size(z.outputs,1)-z.nb_true_sensor+1; 
	espaces   =setstr(32*ones(size(z.inputs,1),5)); 
	inputs    =[deblank(z.inputs(:,1:size(z.inputs,2))),espaces]; 
	espaces   =setstr(32*ones(size(z.outputs,1),5)); 
	outputs   =[deblank(z.outputs(:,1:size(z.outputs,2))),espaces]; 
	espaces   =setstr(32*ones(size(z.state_var,1),5)); 
	state_var =[deblank(z.state_var),espaces]; 
	
	inoutinfo=z.inoutinfo;
	inoutinfo(1).measurements=outputs(p:size(outputs,1),:); 
	inoutinfo(2).measurements=z.yss(p:size(outputs,1),:);
	 
	inoutinfo(1).sources=inputs(1:q,:); 
	inoutinfo(2).sources=z.uss(1:q,:);
	
	r=size(inputs,1);
	if q<r  %  nonlinear current sources exist
		inoutinfo(1).nonlinear=str2mat(inputs(q+1:r,:),outputs(1:p-1,:)); 
		inoutinfo(2).nonlinear=[uss(q+1:size(uss,1),:); yss(1:p-1,:)];
	else
		inoutinfo(1).nonlinear=[];
		inoutinfo(2).nonlinear=[];
	end

	
end

%%%%%%%%%%%%%%%%%%   Callback for EDITS   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if flag==1
	set(POP,'enable','off');
	set(LB(1),'ForeGRoundColor',[.6 .0 .6]);
	source=get(fr(2),'UserData'); % lire la matrice source actuelle
	posit=get(LB(1),'Value');   % lis la position de la barre
	valeur=get(eds(no_edit),'String');
	set(eds(no_edit),'String','');
	
	% modify mask entry & source matrix:
	truesrc=inoutinfo(1).inputs;
	bloc=nsdezero(truesrc(posit,3:size(truesrc,2)));
	type=get_param([systeme,'/',bloc],'Mask Type');
	
	if strcmp(type,'AC voltage source')|strcmp(type,'AC current source')
		source(posit,3+no_edit)=str2num(valeur);
		msk=[num2str(source(posit,4)),'|',num2str(source(posit,5)),'|',num2str(source(posit,6))];
		set_param([systeme,'/',bloc],'Mask entries',msk);
	else
		if no_edit==1
			source(posit,4)=str2num(valeur);
			msk=num2str(source(posit,4));
			set_param([systeme,'/',bloc],'Mask entries',msk);
		end
	end
	
	set(fr(2),'UserData',source); % sauvegarder matrice source

	variname=deblank(inoutinfo(1).inputs);
	texte=[];
	for i=1:size(inoutinfo(1).sources,1);
		type=get_param([systeme,'/',variname(i,3:size(variname,2))],'Mask Type'); % verify if AC or DC source
	        ii=find(variname(i,:)==0);
	        variname(i,ii)=' ';
	        ii=find(variname(i,:)==10);  %return char
	        variname(i,ii)=' ';
		if strcmp(type,'AC voltage source')|strcmp(type,'AC current source');
		    %ligne=[ sprintf('%s %10.1f %8.1f',variname(i,:),source(i,4),source(i,5)),setstr(176) '   ' num2str(source(i,6)) ' Hz'];
		    ligne=[ sprintf('%s %11.4g %8.2f',variname(i,:),source(i,4),source(i,5)),setstr(176) '   ' num2str(source(i,6)) ' Hz'];
		else
		    %ligne=sprintf('%s %10.1f',variname(i,:),source(i,4));
		    ligne=sprintf('%s %11.4g',variname(i,:),source(i,4));
		end
		texte=str2mat(texte,ligne);
	end
	texte=texte(2:size(texte,1),:);
	set(LB(1),'string',texte);	
end

%%%%%%%%%%%%%%%%%%   Callback for CLOSE   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if flag==2
	nummaster=get(fr(3),'UserData');
	listefig=get(0,'children');
	recherche=find(listefig==nummaster);
	if ~isempty(recherche)
		objmaster=get(nummaster,'UserData');
		startmaster=objmaster(1);
		set(startmaster,'UserData',-1);
	end
	close(numfig);
end

%%%%%%%%%%%%%%%%%%   Callback for FREQUENCY POPUP   %%%%%%%%%%%%%%%%%%%%%%%%%
if flag==3

	indice_freq=get(POP,'Value');
	variname=deblank(inoutinfo(1).inputs);
	texte=[];
	if ~isempty(variname)
	   for i=1:size(inoutinfo(1).sources,1);
	        type=get_param([systeme,'/',variname(i,3:size(variname,2))],'Mask Type'); % verify if AC or DC source
	        ii=find(variname(i,:)==0);
	        variname(i,ii)=' ';
	        ii=find(variname(i,:)==10);
	        variname(i,ii)=' ';
	  	if strcmp(type,'AC voltage source')|strcmp(type,'AC current source')
		    %ligne=[ sprintf('%s %10.1f %8.1f',variname(i,:),source(i,4),source(i,5)),setstr(176) '   ' num2str(source(i,6)) ' Hz'];
		    ligne=[ sprintf('%s %11.4g %8.2f',variname(i,:),source(i,4),source(i,5)),setstr(176) '   ' num2str(source(i,6)) ' Hz'];
		else
		    %ligne=sprintf('%s %10.1f',variname(i,:),z.source(i,4));
		    ligne=sprintf('%s %11.4g',variname(i,:),z.source(i,4));
		end 
		texte=str2mat(texte,ligne);
	   end
	   texte=texte(2:size(texte,1),:);
	end
	set(LB(1),'String',texte);
	
	variname=deblank(inoutinfo(1).measurements);
	texte=[];
	if ~isempty(variname)
	   varival=inoutinfo(2).measurements;
	   varival=varival(:,indice_freq);
	   i=find(variname==0);
	   variname(i)=' ';
	   for i=1:size(varival,1);
		%ligne=[ sprintf('%s %10.1f %8.1f',variname(i,:),abs(varival(i)),angle(varival(i))*180/pi) setstr(176)];
		ligne=[ sprintf('%s %11.4g %8.2f',variname(i,:),abs(varival(i)),angle(varival(i))*180/pi) setstr(176)];
		texte=str2mat(texte,ligne);
	   end
	   texte=texte(2:size(texte,1),:);
	end
	set(LB(2),'String',texte);

	state_var=deblank(z.state_var);
	texte=[];
	if ~isempty(state_var)
	   i=find(state_var==0);
	   state_var(i)=' ';
	   for i=1:size(z.xss,1);
		%ligne=[ sprintf('%s %10.1f %8.1f',state_var(i,:),abs(z.xss(i,indice_freq)),angle(z.xss(i,indice_freq))*180/pi) setstr(176)];
		ligne=[ sprintf('%s %11.4g %8.2f',state_var(i,:),abs(z.xss(i,indice_freq)),angle(z.xss(i,indice_freq))*180/pi) setstr(176)];
		texte=str2mat(texte,ligne);
	   end
	   texte=texte(2:size(texte,1),:);
	end
	set(LB(3),'String',texte);
	
	variname=deblank(inoutinfo(1).nonlinear);
	texte=[];
	if ~isempty(variname)
	   varival=inoutinfo(2).nonlinear;
	   varival=varival(:,indice_freq);
	   i=find(variname==0);
	   variname(i)=' ';
	   for i=1:size(varival,1);
		%ligne=[ sprintf('%s %10.1f %8.1f',variname(i,:),abs(varival(i)),angle(varival(i))*180/pi) setstr(176)];
		ligne=[ sprintf('%s %11.4g %8.2f',variname(i,:),abs(varival(i)),angle(varival(i))*180/pi) setstr(176)];
		texte=str2mat(texte,ligne);
	   end
	   texte=texte(2:size(texte,1),:);
	end
	set(LB(4),'String',texte);
	
end

%%%%%%%%%%%%%%%%%%   Callback for APPLY   %%%%%%%%%%%%%%%%%%%%%%%%%
if flag==4
	expr=['load ' systeme];
	eval(expr);
	source=get(fr(2),'UserData'); % lire la matrice source actuelle
	[uss,xss,yss,x0,x0sw,Asw,Bsw,Csw,Dsw,freqyss,H]=etass(A,B,C,D,switchns,source,rlsw,unit,60,line_dist);
	x0perm=x0;
	eval(['save ' systeme  ...
	' A B C D x0 uss xss yss state_var inputs outputs freqyss phisat isat nb_points fluxinit Hlin x0perm true_source nb_true_sensor source switchns rlsw unit line_dist simsensor machines inoutinfo']);
	
	texte=mat2str(freqyss);
	if isempty(findstr(texte,'[')),
		texte=['Display results at ',texte,' Hz'];
	else
		texte=strrep(texte,' ',' Hz|Display results at ');
		texte=strrep(texte,'[','');
		texte=strrep(texte,']',' Hz');
		texte=['Display results at ',texte];
	end
	indice=find(freqyss==60);
	if isempty(indice),
		indice=1;
	end
	set(POP,'Enable','on','String',texte,'Value',indice);
	set(LB(1),'ForeGroundColor','black');
	powergui_steady(numfig,3);
	


end

%%%%%%%%%%%%%%%%%%   Callback for REVERT   %%%%%%%%%%%%%%%%%%%%%%%%%
if flag==5
	expr=['load ' systeme];
	eval(expr);
	source=get(REVERT,'UserData'); % lire la matrice source a l'ouverture
	set(fr(2),'UserData',source); % devient la matrice source actuelle
	[uss,xss,yss,x0,x0sw,Asw,Bsw,Csw,Dsw,freqyss,H]=etass(A,B,C,D,switchns,source,rlsw,unit,60,line_dist);
	x0perm=x0;
	eval(['save ' systeme  ...
	' A B C D x0 uss xss yss state_var inputs outputs freqyss phisat isat nb_points fluxinit Hlin x0perm true_source nb_true_sensor source switchns rlsw unit line_dist simsensor machines inoutinfo']);
	texte=mat2str(freqyss);
	if isempty(findstr(texte,'[')),
		texte=['Display results at ',texte,' Hz'];
	else
		texte=strrep(texte,' ',' Hz|Display results at ');
		texte=strrep(texte,'[','');
		texte=strrep(texte,']',' Hz');
		texte=['Display results at ',texte];
	end
	indice=find(freqyss==60);
	if isempty(indice),
		indice=1;
	end
	set(POP,'Enable','on','String',texte,'Value',indice);
	set(LB(1),'ForeGroundColor','black');	
	% return to initial mask entry for all source blocks:	
	masksbl=get(LB(1),'UserData');	
	for i=1:size(masksbl,2);
		bloc=masksbl(i).name;
		mask=masksbl(i).entries;
		set_param(bloc,'Mask Entries',mask);
	end
	

	powergui_steady(numfig,3);
	
	
	

	

end

%%%%%%%%%%%%%%%%%%   OPEN the GUI   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if flag==0
	load powergui_steady 

	z=loadsavedata(systeme,'load');                          
	
	if isempty(z)
 
		set(numfig,'Pointer','watch');pause(0.1);	[A,B,C,D,x0,state_var,inputs,outputs,uss,xss,yss,freqyss,Hlin,rlc,source,switchns,nb_true_sensor,ans,ans,ans,ans,true_source,inoutinfo]=power2sys(systeme,'g');
  		z.A=A;
   		z.B=B;
   		z.C=C;
   		z.D=D;
  		z.x0=x0;
   		z.uss=uss;
   		z.xss=xss;
   		z.yss=yss;
  		z.state_var=state_var;
   		z.inputs=inputs;
   		z.outputs=outputs;
   		z.freqyss=freqyss;
   		z.phisat=[];
   		z.isat=[];
  		z.nb_points=[];
   		z.fluxinit=[];
   		z.Hlin=Hlin;
   		z.x0perm=x0;
   		z.true_source=true_source;
   		z.nb_true_sensor=nb_true_sensor; 
   		z.source=source;
   		z.switchns=switchns; 
   		z.rlsw=[]; 
   		z.unit=[]; 
   		z.line_dist=[];
   		z.simsensor=[]; 
   		z.machines=[]; 
   		z.inoutinfo=inoutinfo;
   		z.ref_maskvalue=[];
   		z.ref_lines=[];
		z.lockstates='off';

		loadsavedata(systeme,'save',z);
		set(numfig,'Pointer','arrow');

	end
	
	q         =size(z.true_source,1); 
	p         =size(z.outputs,1)-z.nb_true_sensor+1; 
	espaces   =setstr(32*ones(size(z.inputs,1),5)); 
	inputs    =[(z.inputs(:,1:size(z.inputs,2))),espaces]; 
	espaces   =setstr(32*ones(size(z.outputs,1),5)); 
	outputs   =[(z.outputs(:,1:size(z.outputs,2))),espaces]; 
	espaces   =setstr(32*ones(size(z.state_var,1),5)); 
	state_var =[(z.state_var),espaces]; 

	inoutinfo=z.inoutinfo;

	inoutinfo(1).measurements=outputs(p:size(outputs,1),:); 
	inoutinfo(2).measurements=z.yss(p:size(outputs,1),:);
	 
	inoutinfo(1).sources=inputs(1:q,:); 
	inoutinfo(2).sources=z.uss(1:q,:);
	
	r=size(inputs,1);
	if q<r  %  nonlinear current sources exist
		inoutinfo(1).nonlinear=str2mat(inputs(q+1:r,:),outputs(1:p-1,:)); 
		inoutinfo(2).nonlinear=[z.uss(q+1:size(z.uss,1),:); z.yss(1:p-1,:)];
	else
		inoutinfo(1).nonlinear=[];
		inoutinfo(2).nonlinear=[];
	end
	
	a = figure('Units','normalized', ...
	'Color',[0.701961 0.701961 0.701961], ...
	'Colormap',mat0, ...
	'MenuBar','none', ...
	'Name',['STEADY STATE COMPUTATIONS     system: ',systeme], ...
	'NumberTitle','off', ...
	'Position',[0.1814,0.1056,0.4444,0.6500], ...
	'Resize','off', ...
	'Tag','Fig1');
	fr(1) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'Position',[0.0175781 0.753846 0.960938 0.223932], ...
	'Style','frame', ...
	'UserData',systeme, ...
	'Tag','Frame2');
	fr(2) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'Position',[0.0165047 0.531955 0.963461 0.205689], ...
	'Style','frame', ...
	'UserData',z.source, ...	% garder source pour modifs eventuelles
	'Tag','Frame1');
	fr(3) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'Position',[0.0185678 0.310306 0.961398 0.205689], ...
	'Style','frame', ...
	'Tag','Frame1');
	fr(4) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'Position',[0.0185678 0.0833395 0.961398 0.205689], ...
	'Style','frame', ...
	'Tag','Frame1');

	set(fr(3),'UserData',numfig);
	objmaster=get(numfig,'UserData');
	editmaster=objmaster(1);
	set(editmaster,'UserData',a);  % keep steadyfigurenumber in mainwindowedit UI
	
	texte=mat2str(z.freqyss);
	if isempty(findstr(texte,'[')),
		texte=['Display results at ',texte,' Hz'];
	else
		texte=strrep(texte,' ',' Hz|Display results at ');
		texte=strrep(texte,'[','');
		texte=strrep(texte,']',' Hz');
		texte=['Display results at ',texte];
	end
	indice=find(z.freqyss==60);
	if isempty(indice),
		indice=1;
	end
	POP = uicontrol('Parent',a, ...
	'CallBack',['powergui_steady(',num2str(a),',3);'],...
	'Units','normalized', ...
	'FontSize',12, ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'Min',1, ...
	'Position',[0.0253906 0.0188034 0.369609 0.0461538], ...
	'String',texte, ...
	'Style','popupmenu', ...
	'Tag','PopupMenu1', ...
	'Value',indice);
	
	indice_freq=indice;
	
	variname=deblank(inoutinfo(1).inputs);
	texte=[];
	masksbl=[];
	if ~isempty(variname)
	  for i=1:size(inoutinfo(1).sources,1);
	  
	  	type=get_param([systeme,'/',variname(i,3:size(variname,2))],'Mask Type'); % verify if AC or DC source
	  	mask=get_param([systeme,'/',variname(i,3:size(variname,2))],'Mask Entries');
	  	masksbl(i).name=nsdezero([systeme,'/',variname(i,3:size(variname,2))]);
		masksbl(i).entries=mask;
		
	  	ii=find(variname(i,:)==0);
	  	variname(i,ii)=' ';
	  	ii=find(variname(i,:)==10); % return char
	  	variname(i,ii)=' ';
	  	if strcmp(type,'AC voltage source')|strcmp(type,'AC current source')
		   %ligne=[ sprintf('%s %10.1f %8.1f',variname(i,:),source(i,4),source(i,5)),setstr(176) '   ' num2str(source(i,6)) ' Hz'];
		   ligne=[ sprintf('%s %11.4g %8.2f',variname(i,:),source(i,4),source(i,5)),setstr(176) '   ' num2str(source(i,6)) ' Hz'];
		else
		   %ligne=sprintf('%s %10.1f',variname(i,:),z.source(i,4));
		   ligne=sprintf('%s %11.4g',variname(i,:),z.source(i,4));
		end
		texte=str2mat(texte,ligne);
	  end
	  texte=texte(2:size(texte,1),:);
	end
		
	LB(1) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'FontName','courrier', ...
	'BackgroundColor',[1 1 1], ...
	'Position',[0.0449219 0.811966 0.894531 0.138462], ...
	'String',texte, ...
	'Style','listbox', ...
	'Tag','Listbox2', ...
	'UserData',masksbl, ...
	'Value',1);
	
	AMPL = uicontrol('Parent',a, ...
	'CallBack',['powergui_steady(',num2str(a),',1,[],1);'],...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Position',[0.210938 0.762393 0.179688 0.034188], ...
	'String',' ', ...
	'Style','edit', ...
	'visible','off',...
	'Tag','EditText1');
	PHAZ = uicontrol('Parent',a, ...
	'CallBack',['powergui_steady(',num2str(a),',1,[],2);'],...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Position',[0.541016 0.762393 0.125 0.0324786], ...
	'String',' ', ...
	'Style','edit', ...
	'visible','off',...
	'Tag','EditText1');
	FREQ = uicontrol('Parent',a, ...
	'CallBack',['powergui_steady(',num2str(a),',1,[],3);'],...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Position',[0.851562 0.762393 0.0917969 0.0324786], ...
	'String',' ', ...
	'visible','off',...
	'Style','edit', ...
	'Tag','EditText1');

	if size(z.true_source,1)==0 
		set(AMPL,'Visible','off'); 
		set(PHAZ,'Visible','off');
		set(FREQ,'Visible','off');
	end
	
	variname=deblank(inoutinfo(1).measurements);
	varival=inoutinfo(2).measurements;
	texte=[];
	if ~isempty(variname)
	   varival=varival(:,indice_freq);
	   i=find(variname==0);
	   variname(i)=' ';
	   for i=1:size(varival,1);
		%ligne=[ sprintf('%s %10.1f %8.1f',variname(i,:),abs(varival(i)),angle(varival(i))*180/pi) setstr(176)];
		ligne=[ sprintf('%s %11.4g %8.2f',variname(i,:),abs(varival(i)),angle(varival(i))*180/pi) setstr(176)];
		texte=str2mat(texte,ligne);
	   end
	   texte=texte(2:size(texte,1),:);
	end
	
	LB(2) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'FontName','courrier', ...
	'BackgroundColor',[1 1 1], ...
	'Position',[0.0474511 0.555004 0.899507 0.15604], ...
	'String',texte, ...
	'Style','listbox', ...
	'Tag','Listbox1', ...
	'Value',1);

	texte=[];
	state_var=deblank(z.state_var);
	if ~isempty(state_var)
	   i=find(state_var==0);
	   state_var(i)=' ';
	   for i=1:size(z.xss,1);
		%ligne=[ sprintf('%s %10.1f %8.1f',state_var(i,:),abs(z.xss(i,indice_freq)),angle(z.xss(i,indice_freq))*180/pi) setstr(176)];
		ligne=[ sprintf('%s %11.4g %8.2f',state_var(i,:),abs(z.xss(i,indice_freq)),angle(z.xss(i,indice_freq))*180/pi) setstr(176)];
		texte=str2mat(texte,ligne);
	   end
	   texte=texte(2:size(texte,1),:);
	end

	LB(3) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'FontName','courrier', ...
	'BackgroundColor',[1 1 1], ...
	'Position',[0.0474511 0.326265 0.899507 0.15604], ...
	'String',texte, ...
	'Style','listbox', ...
	'Tag','Listbox1', ...
	'Value',1);
	
	texte=[];
	variname=deblank(inoutinfo(1).nonlinear);
	varival=inoutinfo(2).nonlinear;
	if ~isempty(variname)
	   varival=varival(:,indice_freq);
	   i=find(variname==0);
	   variname(i)=' ';
	   for i=1:size(varival,1);
		%ligne=[ sprintf('%s %10.1f %8.1f',variname(i,:),abs(varival(i)),angle(varival(i))*180/pi) setstr(176)];
		ligne=[ sprintf('%s %11.4g %8.2f',variname(i,:),abs(varival(i)),angle(varival(i))*180/pi) setstr(176)];
		texte=str2mat(texte,ligne);
	   end
	   texte=texte(2:size(texte,1),:);
	end

	LB(4) = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Position',[0.0515773 0.102844 0.897444 0.15604], ...
	'FontName','courrier', ...
	'String',texte, ...
	'Style','listbox', ...
	'Tag','Listbox1', ...
	'Value',1);

	APPLY = uicontrol('Parent',a, ...
	'CallBack',['powergui_steady(',num2str(a),',4);'],...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'FontSize',12, ...
	'Position',[0.621094 0.0188034 0.113281 0.042735], ...
	'String','Apply', ...
	'visible','off',...
	'Enable','on', ...
	'Tag','Pushbutton3');
	REVERT = uicontrol('Parent',a, ...
	'CallBack',['powergui_steady(',num2str(a),',5);'],...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'FontSize',12, ...
	'Position',[0.744141 0.0188034 0.113281 0.042735], ...
	'String','Revert', ...
	'visible','off',...
	'Enable','on', ...
	'UserData',z.source, ...
	'Tag','Pushbutton3');
	CLOSE = uicontrol('Parent',a, ...
	'CallBack',['powergui_steady(',num2str(a),',2);'],...
	'Units','normalized', ...
	'FontSize',12, ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'Position',[0.869141 0.0188034 0.113281 0.042735], ...
	'String','Close', ...
	'Tag','Pushbutton3');
	txt = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'Position',[0.0371094 0.762393 0.161641 0.0273504], ...
	'String','Amplitude(rms)', ...
	'Style','text', ...
	'visible','off',...
	'Tag','StaticText3');
	txt = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'Position',[0.392578 0.762393 0.142578 0.0273504], ...
	'String','phase(deg)', ...
	'Style','text', ...
	'visible','off',...
	'Tag','StaticText3');
	txt = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'Position',[0.681641 0.762393 0.15625 0.0273504], ...
	'String','Frequency(Hz)', ...
	'visible','off',...
	'Style','text', ...
	'Tag','StaticText3');
	txt = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'FontSize',12, ...
	'Position',[0.0410156 0.953846 0.244141 0.034188], ...
	'String','Electrical sources', ...
	'Style','text', ...
	'Tag','StaticText1');
	txt = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'FontSize',12, ...
	'Position',[0.0474511 0.714592 0.210435 0.0336904], ...
	'String','Measurements', ...
	'Style','text', ...
	'Tag','StaticText1');
	txt = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'FontSize',12, ...
	'Position',[0.0474511 0.492943 0.22075 0.0336904], ...
	'String','States variables', ...
	'Style','text', ...
	'Tag','StaticText1');
	txt = uicontrol('Parent',a, ...
	'Units','normalized', ...
	'BackgroundColor',[0.701961 0.701961 0.701961], ...
	'FontSize',12, ...
	'Position',[0.0433248 0.26775 0.245507 0.0336904], ...
	'String','Non linear blocks', ...
	'Style','text', ...
	'Tag','StaticText1');

	set(a,'UserData',[fr(1) AMPL PHAZ FREQ LB fr(2) fr(3) POP REVERT]);
	hidegui
end
