function varargout=powericon(varargin)
% POWERICON Gateway function to the private directory of Power System Blockset.
%

%   Patrice Brunelle (TEQSIM) 15-09-97
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.6 $

if isstr(varargin{1})
	masktype=varargin{1};
	maskflag=1;
else
	masktype=get_param(gcb,'MaskType');
	maskflag=0;
end

switch masktype


   % Icons for powerlib blocks:

   case 'Series RLC Branch' 
	[p{1:12}] = bl01icon(varargin{1:3});
   case 'Series RLC Load'
	[p{1:12}] = bl02icon(varargin{1:5});	
   case 'Parallel RLC Branch'
	[p{1:16}] = bl03icon(varargin{1:3});
   case 'Parallel RLC Load'
	[p{1:16}] = bl04icon(varargin{1:5});
   case 'Pi Section Line'
	[p{1:16}] = bl08icon(varargin{1:6});
   case 'Mutual Inductance'
	[p{1:14}] = bl09icon(varargin{1:4});
   case 'Linear Transformer'
	[p{1:14}] = bl10icon(varargin{1:5});
   case 'Saturable Transformer'
	[p{1:12}] = bl11icon(varargin{1:6});
   case 'Bus Bar'
	[p{1:27}] = bl14icon(varargin{1:2});
   case 'Voltage Measurement'
	[p{1:16}] = bl17icon(varargin{1});
   case 'Current Measurement'
	[p{1:10}] = bl18icon(varargin{1});
   case 'Distributed Parameters Line'
	[p{1:8}]  = bl34icon(varargin{1:5});
   case 'DC Voltage Source'
        [p{1}]    = blocinit(varargin{1:7});
   case 'AC Voltage Source'
        [p{1}]    = blocinit(varargin{1:7});
   case 'AC Current Source'
        [p{1}]    = blocinit(varargin{1:7});
   case 'Controlled Voltage Source'
        [p{1}]    = blocinit(varargin{1:7});
   case 'Controlled Current Source'
        [p{1}]    = blocinit(varargin{1:7});
   case 'Neutral'
        [p{1}]    = blocinit(varargin{1:7});
   case 'Diode'
        [p{1}]    = blocinit(varargin{1:7});
   case 'Ideal Switch'
        [p{1}]    = blocinit(varargin{1:7});
   case 'Mosfet'
        [p{1}]    = blocinit(varargin{1:7});
   case 'Gto'
        [p{1}]    = blocinit(varargin{1:7});
   case 'Surge Arrester'
        [p{1}]    = blocinit(varargin{1:7}); 
   case 'Breaker'
	blocinit(varargin{1:7});
	p{1}='';
   case 'Thyristor'
	if maskflag
	   bl20mask(varargin{2},varargin{3});
	   p{1}='';
	else
           [p{1}] = blocinit(varargin{1:7});
	end
   case 'Simplified Thyristor'
	if maskflag
	   bl20mask(varargin{2},varargin{3});
	   p{1}='';
	else
           [p{1}] = blocinit(varargin{1:7});
	end
   case 'Simplified Synchronous Machine'
	if maskflag
	   bl24mask(varargin{2},varargin{3});
	   p{1}='';
	else
	   [p{1:8}]  = bl24icon(varargin{1:4});
	end
   case 'Synchronous Machine'
	if maskflag
	   bl25mask(varargin{2},varargin{3});
	   p{1}='';
	else
	   [p{1:12}] = bl25icon(varargin{1:7});
	end
   case 'PM Synchronous Machine'
	[p{1:14}] = bl29icon(varargin{1:4});
   case 'Asynchronous Machine'
	if maskflag
	   bl30mask(varargin{2},varargin{3});
	   p{1}='';
	else
	   [p{1:16}] = bl30icon(varargin{1:5});
	end


   % Icons for the triphase library (powerlib_extras):

   case '3-phase parallel RLC element '
	[p{1:16}] = bl03icon(varargin{2:4});

   case '3-phase RLC series element'
	[p{1:12}] = bl01icon(varargin{2:4});

   case '3-phase parallel RLC load '
	[p{1:16}] = bl04icon(varargin{2:6});

   case '3-phase series RLC load '
	[p{1:12}] = bl02icon(varargin{2:6});

   case '3-phase RL  positive & zero-sequence impedance'
	[p{1:14}] = bl09icon(varargin{2:5});

   case '3-phase inductive source - Ungrounded neutral'
	[p{1:12}] = bl01icon(varargin{2:4});



   % Initialization commands for powerlib_models models:

   case 'Simplified Synchronous Machine Model'
	[p{1:17}] = bl24init(varargin{1:5});

   case 'Synchronous Machine Model'
	[p{1:31}] = bl25init(varargin{1:9});

   case 'Asynchronous Machine Model'
	[p{1:23}] = bl29init(varargin{1:7});

   case 'PM Synchronous Machine Model'
	[p{1:17}] = bl24init(varargin{1:5});

   case 'Distributed Parameter Line Model'
	[p{1:4}] = blmodlin(varargin{1:5});


   % link testsuite to private directory:

   case 'testlink'
        action=['[p{1:' num2str(nargout) '}]=' varargin{2} '(varargin{3:end});'];
	eval(action);


   
   % checksum mechanism called by initfcn:

   case 'checksum'
	psbchecksum(varargin{2});
	p{1}='';
   


   % loadFcm & CopyFcn fot the measurement blocks:

   case 'psblcfmeas'
	psblcfmeas(varargin{2});
	p{1}='';



   % loadFcn for blocks with goto and/or from blocks:

   case 'psblfblk'
	psblfblk(varargin{2:3})
	p{1}='';



   % Initialization command of State-Space block: loadsavedata.m

   case 'loadsavedata'
       p{1}=loadsavedata(varargin{2:3});


end



for i=1:nargout,varargout(i)={p{i}};end

