function powerinit(systeme,action,p1,p2)
% POWERINIT Set or reset x0 state-space initial values for an existing model
%
%    powerinit(system,'look')   : display current values of states variables,
%    powerinit(system,'reset')  : reset to zero x0 vector of system model,
%    powerinit(system,'steady') : set x0 vector for steady-state simulation,
%    powerinit(system,'set',P)  : set x0 vector equal to P vector, 
%    powerinit(system,'setb',StateVariableName,Value) 
%	                           : set StateVariableName to Value.
%
%    See also POWERGUI

%   Patrice Brunelle (TEQSIM) 26-02-97, 15-07-97
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.4 $

z=loadsavedata(systeme,'load');
if isempty(z),
	return
end
x0=z.x0;
x0perm=z.x0perm;
state_var=z.state_var;

switch action


case 'reset'
	x0=zeros(size(x0,1),size(x0,2));

case 'set'
	if length(p1)~=length(x0)
		error('Dimension mismatch')
	end
	x0=p1;
	if size(x0,2)>size(x0,1)
		x0=x0';
	end

case 'steady'
	x0=x0perm;

case 'setb'
	p1=[p1,zeros(1,size(state_var,2)-size(p1,2))];
	for i=1:size(state_var,1)
		if strcmp(p1,state_var(i,:));
			x0(i)=p2;
		end
	end

case 'look'
	disp('initial values x0:')
	for i=1:size(x0,1)
		disp([state_var(i,:),' = ',num2str(x0(i))]);
	end

end


z.x0=x0;	
loadsavedata(systeme,'save',z);
 
