function [s1,s2,s3,s4,r1,r2,l1,l2,c1,c2,c3,c4,x1,x2,x3,x4] = bl04icon(vb,f,p,ql,qc)
%B8ICON	Generate data for 'Load parallel RLC' block icon.
%
%	[S1,S2,S3,S4,R1,R2,L1,L2,C1,C2,C3,C4,X1,X2,X3,X4] = B8ICON(VB,F,P,QL,QC,DEFAUT)
%	generates data to plot block icon of 'Load parallelRLC' block.
%	B8ICON also test for valid entries in the mask block.  
%
%	This function is used by the 'Load parallel RLC' Mask block as an 
%	initialization command. It return 16 scalars and vectors variables to 
%	the drawing command.
%
%	VB,F,P,QL,QC : correspond to the nominal voltage, frequency
%	               power dissipation, capacitive and reactive power,
  
%   Patrice Brunelle 12-01-95, 04-09-96
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.2 $

% initial values:
s1=0;s2=0;s3=0;s4=0;r1=0;r2=0;l1=0;l2=0;c1=0;c2=0;c3=0;c4=0;x1=0;x2=0;x3=0;x4=0;

% Tests for entries in the Mask Block:

blocinit(vb,f,p,ql,qc,0,4);

% Generate data icon:

if sum([p,ql,qc]&[1,1,1])<2

	[s1,s2,s3,s4,r1,r2,l1,l2,c1,c2,c3,c4] = bl02icon(vb,f,p,ql,qc);
	return;

else

% general data:

x = [7,15,30,45,60,75,90,97]+23;
y = [0,25,-25,25,-25,25,-25,0];
rx=[0 30,x,120,150];
ry=[0,0,y,0,0];

x=round(50*sin(-pi:0.4:pi));
y=round(50*cos(-pi:0.4:pi));
x1 = x(5:15);
y1 = 2*y(5:15);
x1(11) = 34;
y1(11) = -70;
x2 = x(3:15)+70;
y2 = 2*y(3:15);
x2(13) = 104;
y2(13) =  -70;
x3 = x(3:15)+140;
y3 = 2*y(3:15);
x3(13) = 174;
y3(13) =-70;
x4 = x(3:13)+210;
y4 = 2*y(3:13);
y4(11)=0;
x =(([x1,x2,x3,x4]+73)./3)+15;
y =[y1,y2,y3,y4]./2;
lx =round([0,23,x,126,150]);
ly =round([0,0,y,0,0]./2);

cx1 = [0,60,60,57,55,57,60,60,57,55];
cy1 = [0,0,8,16,25,16,8,-8,-16,-25];
cx2 = [90,90,90,150];
cy2 = [25,-25,0,0];

c2el1x = [0,25,25,25];
c2el1y = [0,0,-50,50];
c2el2x = [175,175,175,200];
c2el2y = [-50,50,0,0];

c3el1y = [0,0,-100,100];   %3 elements
c3el2y = [-100,100,0,0];


if (p&ql)&(qc==0)

%  R//L,

r1=rx+25;
r2=ry+50;
l1=lx+25;
l2=ly-50;
x1=c2el1x;
x2=c2el1y;
x3=c2el2x;
x4=c2el2y;
s1 = 0;
s2 = -100;
s3 = 200;
s4 = 100;

end



if (p&qc)&(ql==0)

%  R//C,

r1=rx+25;
r2=ry+50;
c1=cx1+25;
c2=cy1-50;
c3=cx2+25;
c4=cy2-50;
x1=c2el1x;
x2=c2el1y;
x3=c2el2x;
x4=c2el2y;
s1 = 0;
s2 = -100;
s3 = 200;
s4 = 100;

end


if p&ql&qc

%  R//L//C

r1=rx+25;
r2=ry+100;
l1=lx+25;
l2=ly;
c1=cx1+25;
c2=cy1-100;
c3=cx2+25;
c4=cy2-100;

x1=c2el1x;
x2=c3el1y;
x3=c2el2x;
x4=c3el2y;

s1 = 0;
s2 = -175;
s3 = 200;
s4 = 175;

end


if (ql&qc)&(p==0)

%  L//C

l1=lx+25;
l2=ly+50;
c1=cx1+25;
c2=cy1-50;
c3=cx2+25;
c4=cy2-50;

x1=c2el1x;
x2=c2el1y;
x3=c2el2x;
x4=c2el2y;

s1 = 0;
s2 = -100;
s3 = 200;
s4 = 100;

end


end

