function [s,c1,c2,m1,m2,m3,m4,m5,m6,n1,n2,n3,n4,n5,n6,p1,p2,p3,p4,p5,p6,q1,q2,q3,q4,q5,q6] = bl14icon(entrees,sorties)
%BL14ICON Update the number of inputs and outputs of 'Bus bar' block.
%
%	S = BL14ICON(ENTREES,SORTIES,IN,OUT) Update the number of inputs
%	ports and output ports for the 'Bus bar' block according to the values
%	specified by the user in the Mask dialog.
%	B13ICON also test for valid entries in the mask dialog block.
%
%	This function is used by the 'Bus bar' Mask block as an initialization 
%	command. It return one scalar variable to the drawing command: this is
%	to force execution of BL14ICON each time the block is activated.
%
%	ENTREES  : is the desired number of input ports,
%	SORTIES  : is the desired number of outputs port,
 
%   Patrice Brunelle 12-01-95, 09-04-96
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.2 $

% fractional entries protection:
entrees = floor(entrees(1));
sorties = floor(sorties(1));
if entrees>6,entrees=6;end
if sorties>6,sorties=6;end


s=0;c1=0;c2=0;
n=zeros(6,2);
m=zeros(6,2);
p=zeros(6,2);
q=zeros(6,2);
m1=m(1,1:2);
m2=m(2,1:2);
m3=m(3,1:2);
m4=m(4,1:2);
m5=m(5,1:2);
m6=m(6,1:2);
n1=n(1,1:2);
n2=n(2,1:2);
n3=n(3,1:2);
n4=n(4,1:2);
n5=n(5,1:2);
n6=n(6,1:2);
p1=p(1,1:2);
p2=p(2,1:2);
p3=p(3,1:2);
p4=p(4,1:2);
p5=p(5,1:2);
p6=p(6,1:2);
q1=q(1,1:2);
q2=q(2,1:2);
q3=q(3,1:2);
q4=q(4,1:2);
q5=q(5,1:2);
q6=q(6,1:2);

sys=get_param(0,'CurrentSystem');
block=get_param(sys,'CurrentBlock');
gg = get_param([sys,'/',block],'Selected');
type = get_param([sys,'/',block],'mask type');
objet=[sys,'/',block];



ori=get_param(objet,'orientation');
posi=get_param(objet,'position');
if strcmp(ori,'left')|strcmp(ori,'right')
   upperleft=posi(2);
   s=posi(4)-posi(2);
   isop=get_param(objet,'InputPorts');
   branches_in=isop(:,2)-upperleft;
   isop=get_param(objet,'OutputPorts');
   branches_out=isop(:,2)-upperleft;
else
   upperleft=posi(3);
   s=posi(3)-posi(1);
   isop=get_param(objet,'InputPorts');
   branches_in=isop(:,1)-upperleft;
   isop=get_param(objet,'OutputPorts');
   branches_out=isop(:,1)-upperleft;
end

flag=0;
if isempty(branches_in)&isempty(branches_out),
	s=156;
branches={[78],[38;118],[28;78;128],[18;58;98;138],[23;53;83;113;143],[18;43;68;93;118;143]};
	if entrees>0
		branches_in=branches{entrees};
	else
		branches_in=[];
	end
	if sorties>0
		branches_out=branches{sorties};
	else
		branches_out=[];
	end
	flag=1;
end

% Add or remove input and output ports:
if flag==0

in=size(branches_in,1);
ou=size(branches_out,1);
if entrees>in,
   for i=in+1:entrees
	Y1 = (i-1)*50+25;
	add_block('built-in/Inport',[objet,'/in_',num2str(i)])
       	set_param([objet,'/in_',num2str(i)],...
	   'position',[25,Y1,45,Y1+20],'Port',num2str(i))
	add_block('built-in/Terminator',[objet,'/t',num2str(i)])
	set_param([objet,'/t',num2str(i)],...
	    'position',[80,Y1-5,105,Y1+25]);
        add_line(objet,['in_',num2str(i),'/1'],['t',num2str(i),'/1'])
   end
end
if sorties>ou
  for i=ou+1:sorties
     Y1=(i-1)*50+25;
     add_block('built-in/Outport',[objet,'/out_',num2str(i)])
     set_param([objet,'/out_',num2str(i)],...
	   'position',[185,Y1,205,Y1+20],'Port',num2str(i))
     add_block('built-in/constant',[objet,'/g',num2str(i)])
     set_param([objet,'/g',num2str(i)],...
	   'position',[130,Y1-5,155,Y1+25]);
     add_line(objet,['g',num2str(i),'/1'],['out_',num2str(i),'/1']);
  end
end	
if entrees<in
   for i=in:-1:entrees+1
      delete_line(objet,['in_',num2str(i),'/1'],['t',num2str(i),'/1']);
      delete_block([objet,'/in_',num2str(i)]);
      delete_block([objet,'/t',num2str(i)]);
   end
end	
if sorties<ou
   for i=ou:-1:sorties+1
      delete_line(objet,['g',num2str(i),'/1'],['out_',num2str(i),'/1']);
      delete_block([objet,'/out_',num2str(i)]);
      delete_block([objet,'/g',num2str(i)]);
   end
end

end
% icone:

if flag==0

if strcmp(ori,'left')|strcmp(ori,'right')
	isop=get_param(objet,'InputPorts');
	branches_in=abs(isop(:,2)-upperleft);
	isop=get_param(objet,'OutputPorts');
	branches_out=abs(isop(:,2)-upperleft);
else
	isop=get_param(objet,'InputPorts');
	branches_in=abs(isop(:,1)-upperleft);
	isop=get_param(objet,'OutputPorts');
	branches_out=abs(isop(:,1)-upperleft);
end

end

% entrees:
if entrees~=0
   for j=1:entrees
	m(j,1:2) = [0 5];	
	n(j,1:2) = [branches_in(j) branches_in(j)];
   end
end
m1=m(1,1:2);
m2=m(2,1:2);
m3=m(3,1:2);
m4=m(4,1:2);
m5=m(5,1:2);
m6=m(6,1:2);
n1=n(1,1:2);
n2=n(2,1:2);
n3=n(3,1:2);
n4=n(4,1:2);
n5=n(5,1:2);
n6=n(6,1:2);
   
% sorties:
if sorties~=0
  for j=1:sorties
	p(j,1:2) = [5 10];	
	q(j,1:2) = [branches_out(j) branches_out(j)];
  end
end
p1=p(1,1:2);
p2=p(2,1:2);
p3=p(3,1:2);
p4=p(4,1:2);
p5=p(5,1:2);
p6=p(6,1:2);
q1=q(1,1:2);
q2=q(2,1:2);
q3=q(3,1:2);
q4=q(4,1:2);
q5=q(5,1:2);
q6=q(6,1:2);

% main segment:
dep=max([branches_in;branches_out]);
arr=min([branches_in;branches_out]);
c1 = [5 5];
c2 = [dep arr];

