function [params] = bl24conv(nom,mec,Z,init)

%BL24CONV
%
% Converts Simplified Synchronous Machine block parameters before simulation
% from SI fundamental to pu fundamental parameters.
% Created 1997-Jul-16
% Last update: 1997-Jul-17
%
% Simplified Synchronous Machine model by:
% Louis-A. Dessaint, Ph.D., and Roger Champagne, ing.
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.2 $

% Nominal and base values ----------------------------------------------------
Pn=nom(1);
Vn=nom(2);
fn=nom(3);
wen=fn*2*pi;
ib=sqrt(2/3)*Pn/Vn;
Zb=Vn^2/Pn;

% Mechanical values ----------------------------------------------------------
p=mec(3);
mecpu=[ (wen/p)^2*mec(1)/(2*Pn), mec(2), p];

% Impedance values -----------------------------------------------------------
Zpu=[ Z(1)/Zb, Z(2)/Zb*wen];

% Initial condition values ---------------------------------------------------
initpu=[ init(1), init(2), init(3:5)/ib, init(6:8) ];

iounits='on';		% necessarily SI units if this function is called

params=['[',...
         num2str(nom),']|[',...
         num2str(mecpu),']|[',...
         num2str(Zpu),']|[',...
         num2str(initpu),']|',...
         iounits,...
       ];
       
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%				END OF BL24CONV
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
