function [Pb,Nb,Vb,Vb2,Vb3,ib,ib2,web,H,Kd,p,pi23,R,X,io,dwo,tho] = ...
          bl24init(nom,mec,Z,init,iounits)

%BL24INIT
%
% Initializes Simplified Synchronous Machine block parameters before simulation

% Created 1997-Jul-16
% Last update: 1997-Aug-14
%
%   Simplified Synchronous Machine model by:
%   Louis-A. Dessaint, Ph.D., and Roger Champagne, ing.
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.2 $

% Nominal and base values ----------------------------------------------------
Pn=nom(1);
Vn=nom(2);
fn=nom(3);
kd=mec(2);
R=Z(1); X=Z(2);
p=mec(3);
Nn=60*fn/p;
wmn=Nn*pi/30;
pi23=2*pi/3;

Vb=sqrt(2/3)*Vn;
ib=sqrt(2/3)*Pn/Vn;
web=fn*2*pi;

dwo=init(1)/100;
tho=init(2)*pi/180;
H=mec(1);

if iounits	% SI units selected for I/O
    Pb=Pn;
    Nb=Nn;
    Vb2=Vn;
    Vb3=Vb;
    ib2=ib;
else
    Pb=1;
    Nb=1;
    Vb2=1;
    Vb3=1;
    ib2=1;
end
    
if H ~= inf
   Kd=4*kd*sqrt(wmn*H/2);
else
   Kd=0;
end

d2r=pi/180;	% degrees to radians
iao=init(3); ibo=init(4); ico=init(5);
phao=init(6)*d2r; phbo=init(7)*d2r; phco=init(8)*d2r;

[scrap,iao] = pol2cart(phao,iao);
[scrap,ibo] = pol2cart(phbo,ibo);
[scrap,ico] = pol2cart(phco,ico);

io=[iao ibo ico];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%				END OF BL24INIT
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
