function [Rs,Ll,Lad,Laq,Rf,Llfd,Rkd,Llkd,Rkq,Llkq,H,F,p,dwo,tho,phido,phikdo,...
	  phifdo,phiqo,phikqo,phib,Pb,Vb,Vb2,Ib,Ib2,Nb,Vfnp,N2,phis,psat] = ...
	  bl25init(nom,sta,rot,dam,mec,ini,sat,dispvfd,choice)

%BL25INIT
%
%   Initializes the Synchronous Machine block before simulation.
%   Revised 1997-Aug-14
%

%   Synchronous Machine model by:
%   Louis-A. Dessaint, Ph.D., and Roger Champagne, ing.
%
%   Standard to fundamental conversion part of this program by:
%   I. Kamwa, IREQ (Hydro-Quebec), Varennes, Quebec
%
%   Polynomial approximation of exponential part of this program by:
%   M. Gavrilovic, IREQ (Hydro-Quebec), Varennes, Quebec
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.2 $

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Parameters read from dialog box
Pn=nom(1); Vn=nom(2); fn=nom(3);	% Nominal parameters
Rs=sta(1); Ll=sta(2);			% Stator parameters
Lmd=sta(3); Lmq=sta(4);
Rf=rot(1); Llfd=rot(2);			% Rotor parameters
Rkd=dam(1); Llkd=dam(2);		% Damper parameters
Rkq=dam(3); Llkq=dam(4);
H=mec(1); F=mec(2); p=mec(3);		% Inertia constant,friction and poles	
dwo=ini(1)/100;				% init. speed deviation
tho=ini(2)*pi/180;			% init. angle
iao=ini(3); ibo=ini(4); ico=ini(5);	% init. current amplitudes
phao=ini(6); phbo=ini(7); phco=ini(8);	% init. current angles

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Misc. inductances
Ld=Ll+Lmd; Lq=Ll+Lmq; Lfd=Llfd+Lmd;
L1=Lmq*(Ll+Llkq)+Ll*Llkq; L2=(Lmd*Ll*(Llfd+Llkd))+(Llfd*Llkd*(Ll+Lmd));
Lad=Lmd*Ll*Llfd*Llkd/L2; Laq=Lmq*Ll*Llkq/L1;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Base values
Vb=sqrt(2/3)*Vn;			% base voltage
Ib=sqrt(2/3)*Pn/Vn;			% base current

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Parameters which are the same for both p.u. dialog boxes
if (choice==0)			% parameters in pu
   Vfopu=ini(9);		% init. field voltage (pu)
   Ib2=1;			% current will output in p.u. in model
   Vb2=1;			% voltage will output in p.u. in model
   Pb=1;			% power will output in p.u. in model
   Nb=1;			% speed will output in p.u. in model
   phib=1;			% fluxes will output in p.u. in model

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Code unique to fundamental parameters expressed in S.I. units
else				% fundamental parameters in SI
   Pb=Pn;			% power will output in watts in model
   Nb=60*fn/p;			% speed will output in rpm in model
   phib=Vb/(fn*2*pi);		% fluxes will output in Wb in model
   Ib2=Ib;			% current will output in amps in model
   Vb2=Vb;			% voltage will output in volts in model

   if length(nom)<4
      Ifn=0;
   elseif nom(4)==0
      Ifn=0;
   else
      Ifn=nom(4);		% Ifd producing 1 pu no-load term. voltage
      Ifb=Ifn*Lmd;	        % base field current
   end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% No saturation
if isempty(sat)
   del=0;
   psat=[0,0,0,0,0,0];
   phis=1e6;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Saturation
% Polynomial approximation of no-load saturation curve.
else
   ifsat=sat(1,:);
   vtpu=sat(2,:);
   slope=vtpu(1)/ifsat(1);
   iagpu=1/slope;
   ifpu=ifsat/iagpu;		      % saturated values of ifd in p.u.

   phis=vtpu(1);
   phimax=vtpu(length(vtpu));
   psat1=polyfit(ifpu,vtpu,5);	      % sat. curve fitted by 5th order polyn.
   psat2=polyfit(vtpu,ifpu,5);	      % sat. curve fitted by 5th order polyn.
   nb_points=100;		      % number of points
   delta=(phimax-phis)/(nb_points-1); % interval between points
   phisat=phis:delta:phimax;	      % saturated mutual flux
   f_phi=polyval(psat2,phisat)-phisat;
   phi=phisat+f_phi*Lad/Lmd;	      % air-gap line
   psat=polyfit(phi,phisat,5);	      % 5th-order polyn. app. of sat. function
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Transformation ratio and initial Vfd
% Parameters in p.u., stator base quantities used
if (choice==0)
   Vfnp=Rf/Lmd;	    	    % nominal field voltage viewed from stator
   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   % No saturation
   if isempty(sat)
      Vfo=Vfopu*Vfnp;	    % initial field voltage
      N2=Lmd;
   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   % Saturation
   else
      N2=Lmd*iagpu;	    % ifd will output in p.u.
      Vfo=Vfopu*Vfnp/iagpu; % initial field voltage
      Vfnp=Vfnp/iagpu;
      Vfopu=Vfopu/iagpu;
   end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Parameters in S.I. units, nominal field current unknown
elseif Ifn==0		    % if no value specified for Ifn
   Vfnp=1/Vb;		    % user must supply Vf in volts viewed from stator
   N2=Ib;		    % ifd will output in A viewed from stator
   Vfo=ini(9)*Rf/Lmd;	    % initial field voltage (stator base voltage)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Nominal field current known, fundamental parameters in S.I. units
else			    % parameters in SI
   Vfnp=Ifb/Ib;		    % 1.5 * transformation ratio
   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   % No saturation
   if isempty(sat)
      N2=Ifb;		    % ifd will output in A viewed from rotor
      Vfnp=2/3*Vfnp/Vb;	    % transformation ratio
      Vfopu=ini(9);	    % initial field voltage (rotor base voltage)
   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   % Saturation
   else
      N2=Ifb*iagpu;	    % ifd will output in A viewed from rotor
      Vfnp=Ifb/Pn/iagpu;
      Vfopu=ini(9)/iagpu;   % initial field voltage (rotor base voltage)
   end
   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   % Update of initial Vf
   Vfo=Vfopu*Rf/Lmd;	    % initial field voltage (stator base voltage)
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Initial conditions adjustment for saturation
%
% Knowing the saturation polynomial and excitation voltage, the terminal
% voltage is found. The difference between the field voltage and the 
% corresponding terminal voltage (in pu) is equal to the loss of flux (in pu)
% caused by saturation. The result (del) is used to adjust initial conditions.
if ~isempty(sat)
   if Vfopu>phis		   	% if above non-sat. limit
      vts=polyval(psat1,Vfopu);
      del=Vfopu-vts;
   else
      del=0;
   end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Conversion of initial current phasors to instantaneous values
[scrap,iao] = pol2cart(phao*pi/180,iao);
[scrap,ibo] = pol2cart(phbo*pi/180,ibo);
[scrap,ico] = pol2cart(phco*pi/180,ico);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Initial id, iq and ifd current components
ifdo=Vfo/Rf;
i2=[iao ibo ico]'; dpt=2*pi/3;
iqo=2/3*[cos(tho) cos(tho-dpt) cos(tho+dpt)]*i2;
ido=2/3*[sin(tho) sin(tho-dpt) sin(tho+dpt)]*i2;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Initial fluxes
phiqo=-Lq*iqo;
phikqo=-Lmq*iqo;
phido=(-Ld*ido+Lmd*ifdo)-del;
phikdo=(Lmd*(-ido+ifdo))-del;
phifdo=(Lfd*ifdo+Lmd*(-ido))-del;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Display Vfd producing nominal Vt if required by user
if dispvfd
   if choice == 1
      if ~isempty(sat)
         vfn=Rf/Lmd/Vfnp/iagpu;
      else
         if Ifn==0
	     vfn=Rf*Vb/Lmd;
         else
             vfn=Rf/Lmd/Vfnp;
         end
      end
   else
      vfn=1;
   end
   msgbox(['Vfd producing nominal Vt: ',num2str(vfn)],gcb)
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%				END OF BL25INIT
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
