function [params] = bl29conv(nom,sta,rot,mut,mec,ini)

%BL29CONV
%
% Converts Asynchronous Machine block parameters before simulation from
% SI fundamental to pu fundamental parameters.

% Created 1997-Jul-25
% Last update: 1997-Aug-14
%
%   Asynchronous Machine model by:
%   Louis-A. Dessaint, Ph.D., and Roger Champagne, ing.
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.2 $

% Nominal and base values ----------------------------------------------------
Pn=nom(1);
Vn=nom(2);
fn=nom(3);
wen=fn*2*pi;
ib=sqrt(2/3)*Pn/Vn;
Zb=Vn^2/Pn; Lb=Zb/wen;

% Mechanical values ----------------------------------------------------------
p=mec(3);
mecpu=[ (wen/p)^2*mec(1)/(2*Pn), mec(2), p];

% Impedance values -----------------------------------------------------------
stapu=sta./[Zb Lb];
rotpu=rot./[Zb Lb];
mutpu=mut/Lb;

% Initial condition values ---------------------------------------------------
inipu=ini./[1,1,ib,ib,ib,1,1,1];

iounits='on';		% necessarily SI units if this function is called

params=['[',...
         num2str(nom),']|[',...
         num2str(stapu),']|[',...
         num2str(rotpu),']|',...
         num2str(mutpu),'|[',...
         num2str(mecpu),']|[',...
         num2str(inipu),']|',...
         iounits,...
       ];
       
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%				END OF BL29CONV
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
