function [Rs,Lls,Rr,Llr,H,F,p,Laq,Lad,web,vb,vb2,ib,ib2,phib2,Nb2,Tb2,...
	  phisqo,phisdo,phirqo,phirdo,wmo,tho] = bl29init(nom,sta,rot,mut,...
	  mec,ini,iounits)

%BL29INIT
%
% Initializes the Asynchronous Machine block before simulation.
%

% Asynchronous Machine model by:
%
%   Louis-A. Dessaint, Ph.D., and Roger Champagne, M.ing,ing.
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.2 $

% Nominal and base values -------------------------------------------------
Pn=nom(1); Vn=nom(2);
Pb=Pn; vb=sqrt(2/3)*Vn;
ib=sqrt(2/3)*Pn/Vn;
web=nom(3)*2*pi; wmb=web/mec(3); Tb=Pb/wmb;
Zb=Vn^2/Pn; Lb=Zb/web;
phib=vb/web;

Rs=sta(1); Lls=sta(2);		% stator resistance and leakage inductance
Rr=rot(1); Llr=rot(2);		% rotor resistance and leakage inductance
Lm=mut(1);			% mutual inductance
H=mec(1); F=mec(2); p=mec(3);	% inertia, friction and pole pairs
s=ini(1);			% initial slip
wmo=1-s;			% initial speed
tho=ini(2)*pi/180;		% initial rotor angle

isao_mag=ini(3)*ib; isao_ph=ini(6)*pi/180; % init. stator current, phase A
isbo_mag=ini(4)*ib; isbo_ph=ini(7)*pi/180; % init. stator current, phase B
isco_mag=ini(5)*ib; isco_ph=ini(8)*pi/180; % init. stator current, phase C

% conversion of initial stator current (phase A) from polar to rectangular
% coordinates
[isao_real,isao_imag]=pol2cart(isao_ph,isao_mag);
isao=isao_real+j*isao_imag;

% p.u. reactances and resistances converted to ohms
rr=Rr*Zb; xlr=Llr*Zb; xm=Lm*Zb;

% computation of instantaneous initial rotor currents. Operator a is
% a vector of unity length, phase of -120 degrees
a_mag=1; a_ph=-2*pi/3;
[a_real,a_imag]=pol2cart(a_ph,a_mag);
a=a_real+j*a_imag;
A=-j*xm/(rr/s+j*(xlr+xm));
irao=imag(A*isao);
irbo=imag(A*isao*a);
irco=imag(A*isao*a^2);

% conversion of initial stator current phasors to instantaneous values
[scrap,isao] = pol2cart(isao_ph,isao_mag);
[scrap,isbo] = pol2cart(isbo_ph,isbo_mag);
[scrap,isco] = pol2cart(isco_ph,isco_mag);

% Initial id and iq current components
isabc=[isao isbo isco]'; dpt=2*pi/3;
isqo=2/3*[cos(tho) cos(tho-dpt) cos(tho+dpt)]*isabc;
isdo=2/3*[sin(tho) sin(tho-dpt) sin(tho+dpt)]*isabc;
irabc=[irao irbo irco]';
irqo=2/3*[1 -0.5 -0.5]*irabc;
irdo=2/3*[0 -sqrt(3)/2 sqrt(3)/2]*irabc;

% Initial fluxes (p.u.): inductances in pu, currents in A, which accounts
% for multiplicator "mult"
mult=sqrt(1.5)*Vn/Pn;
phisqo=((Lls+Lm)*isqo+Lm*irqo)*mult;
phisdo=((Lls+Lm)*isdo+Lm*irdo)*mult;
phirqo=((Llr+Lm)*irqo+Lm*isqo)*mult;
phirdo=((Llr+Lm)*irdo+Lm*isdo)*mult;

if iounits	% I/O in SI units
    ib2=ib;
    vb2=vb;
    phib2=Vn*sqrt(2/3)/web;
    Nb2=wmb;
    Tb2=Tb;
else
    ib2=1;
    vb2=1;
    phib2=1;
    Nb2=1;
    Tb2=1;
end

% Other inductances -------------------------------------------------------

Laq=1/(1/Lm+1/Lls+1/Llr);
Lad=Laq;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%				END OF BL29INIT
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
