function [expr_c,expr_d,vec_c,vec_d,vec_u]=etacd(chaine,sortie,...
         rlcm,rlc1,source,var_nom,var_branche,nbvar1,...
		 liste_neu,Ti,L_combi,C_combi,Il_relat,Uc_relat,nb_ldep,nb_cdep,...
		 c_ligne,debug_etat)
%
%   ETACD is a utility function used by ETATFUN to compute C and D matrices
%     
%  Input arguments
%  ===============
%    chaine :  string = output expression corresponding to one line of the 
%              YOUT string matrix described in input arguments of ETATFUN
%    sortie :  string containing 'y_uxx' or 'y_ixx'for voltage or current output
%              where xx = output number = line number of YOUT
%      rlcm :  modified rlc matrix with tranformer and mutual winding branches
%              replaced by series R-L branch
%      rlc1 :  Matrix (nbr,3) of values of branch parameters
%              converted in Ohms, Henries and Farads
%    source : source matrix (nsrc,5) or (nsrc,6) 
%   var_nom :  String matrix containing the names of the state variables
%var_branche:  Matrix (nstate,2) of branch numbers of the different state
%              variables (Uc or Il) corresponding to line number in rlc matrix.
%              var_branche(n,1)= ib =branch number of state variable n
%              var_branche(n,2)= 0  if Uc or Il is independant
%                              = iline if Uc or Il is dependant
%                                (iline = line number of Uc_relat or Il_relat)
%    nbvar1 :  number of independant state variables 
%  liste_neu : Vector of modified node numbers (includinf intermediate
%              node numbers of transformers and mutuals)
%        Ti  : Transformation matrix relating node and branch currents
%              and such that: [In]=[Ti].[Ib]
%   L_combi :  Vector of numbers of dependant and independant inductor
%              current state variables; The nb_ldep last values are 
%              dependant currents.
%   C_combi :  Vector of numbers of dependant and independant capacitor
%              voltage state variables; The nb_cdep last values are
%              dependant voltages.
%  Il_relat :  Matrix (nb_ldep,nb_lcombi) of coefficients ki of relations
%              k1*I1+k2*I2, ...,+kn*Inb_lcombi=0 between
%              dependant and independant currents; 1 line/dependant current
%  Uc_relat  : Matrix (nb_cdep,nb_ccombi) of coefficients ki of relations
%              k1*U1+k2*U2, ...,+kn*Unb_ccombi=0 between
%              dependant and independant voltages; 1 line/dependant voltage
%    nb_ldep : Number of dependant inductor currents in vector L_combi
%    nb_cdep : Number of dependant capacitor voltages in vector C_combi
%    c_ligne : Shunt capacitance (Farads) at both end of each
%              equivalent pi section of transmission lines 
%  debug_etat: flag used for debugging; normal value=0
%
%  Output arguments
%  ================
% expr_c expr_d : String containing the matlab expression to be evaluated
%                 to compute a line of matrix C and matrix D.
%                 This expression is the CHAINE input expression where
%                 the state-variable names,their derivatives,
%                 node voltages and branch currents are replaced by a 
%                 combination of lines of the following:
%                        - matrices A B 
%                        - matrices Cn Dn (defined in ETATAB) 
%                        - matrices vec_c, vec_d , vec_u (defined below).  
%   vec_c vec_d : Matrices of 0 and 1 vec_c(nbvar,nbvar1) vec_d(nbvar,nbsrc)
%   vec_u                             vec_u(nbrsrc,nbsrc)
%

%                       G. Sybille April 1995
%
% ==============================================================================
%
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.2 $

[nbr,n]=size(rlcm);
[nbr_src,n]=size(source);
[nbvar,n]=size(var_nom);
nb_lcombi=length(L_combi);
nb_ccombi=length(C_combi);
nbneu=length(liste_neu);
vec_c=zeros(nbvar,nbvar1);
vec_d=zeros(nbvar,nbr_src);
vec_u=zeros(nbr_src,nbr_src);
%
%
clear var_index var_type var_neu ;
long_chaine=length(chaine);
%
%  Modify expression:
%  Replace each branch current (type I_bxx )
%  by a function of branch voltages and impedances
%  ===============================================
i=0;  n=0;
%
while i<long_chaine-3 , 
	i=i+1;
	if strcmp(chaine(i:i+2),'I_b'),
	% Decoder la variable ..
		i1=i;
		i=i+3; % begining of branch no.
		str1=[]; 
		while i<=long_chaine & (chaine(i)>='0' & chaine(i)<='9'),
			str1=[str1,chaine(i)];
			i=i+1;
			if i>long_chaine, break; end
		end
		i2=i; %fin de I_bxx   
		ib=str2num(str1);
		if ib<=0 | ib>nbr,
			error(sprintf('Branch %g does not exist!',ib)); end
		neu1=rlcm(ib,1); neu2=rlcm(ib,2);
		n=n+1;
		str='(';
		%
		% Transmission line Branch
		% ========================
		if rlcm(ib,3)<0,
			if i+2>long_chaine,
				error(sprintf(['Line current (branch %g); ',...
				               'expected format : I_b%g_nxx'],ib,ib));
			end
			if strcmp(chaine(i:i+1),'_n'),
				i=i+2;
				str1=[]; 
				while i<=long_chaine & ((chaine(i)>='0' & chaine(i)<='9')|...,
					chaine(i)=='.'),
					str1=[str1,chaine(i)];
					i=i+1;
					if i>long_chaine, break; end
				end
				i2=i; %fin de I_bxx_nxx   
				neu1=str2num(str1);
				if rlcm(ib,1)==neu1, 
					str_signe='+';
					ib1=rlcm(ib,9);
				elseif rlcm(ib,2)==neu1;
					str_signe='-';
					ib1=rlcm(ib,10);
				else
					error(sprintf(['Line current I_b%g_n%g :',...
			        'branch %g is not connected to node %g'],...
					ib,neu1,ib,neu1));
				end
				str=[str,'+','Il_b',num2str(ib),str_signe,...
				sprintf('%.8g',c_ligne(ib)),'*dUc_b',num2str(ib1)];
			else
				error(sprintf(['Line current (branch %g); ',...
				               'expected format: I_b%g_nxx'],ib,ib));
			end
		%
		% Series Branch
		% =============
		elseif rlcm(ib,3)==0,
			%
			% Purely resistive branch : I=U/R
			if rlc1(ib,2)==0 & rlc1(ib,3)==0,
				str=[str,'U_n',num2str(neu1),'_',num2str(neu2),'/',...
			         sprintf('%.8g',rlc1(ib,1))];
			%
			% Inductive branch : I=Il_bxx
			elseif rlc1(ib,2)~=0, 
				str=[str,'Il_b',num2str(ib)];
			%
			% Capacitive branch : I=C*dUc_bxx
			else,  
				str=[str,sprintf('%.8g',rlc1(ib,3)),'*dUc_b',num2str(ib)];
			end    
		%
		% Parallel Branch I=IR+ Il +IC
		% ===============
		else,
			if rlc1(ib,1)~=0,
				str=[str,'U_n',num2str(neu1),'_',num2str(neu2),'/',...
			         sprintf('%.8g',rlc1(ib,1))];
			end
			%
			if rlc1(ib,2)~=0,
				str=[str,'+','Il_b',num2str(ib)];
			end
			%
			if rlc1(ib,3)~=0,
				str=[str,'+',sprintf('%.8g',rlc1(ib,3)),'*dUc_b',num2str(ib)];
			end
		end
		%
		str=[str,')'];
		chaine=[chaine(1:i1-1),str,chaine(i2:length(chaine))];
		i=i+length(str)-(i2-i1);
		long_chaine=length(chaine);
	end
end
% Print modified expression
if n>0 & debug_etat, fprintf([sortie,'=',chaine,'\n']); end
%
%
nvary=0; i=0;
str='  ';
while i<long_chaine-1,
	% Find begining of variable names
	%--------------------------------
	i=i+1;
	str=chaine(i:i+1);
	if strcmp(str,'Il') | strcmp(str,'Uc')  | ...
	   ((str(1)=='U' | str(1)=='I')&(str(2)>='0' & str(2)<='9') | ...
	   strcmp(str,'U_')),
		nvary=nvary+1;
		var_index(nvary,1)=i;
		var_type(nvary)=0; 
		if i>1,
			if chaine(i-1)=='d',
				var_type(nvary)=-1;
			end
		end
		%
		if str(2)~='c' & str(2)~='l' & str(2)~='_',
		% Decode  input variables (U1, U2, I4...) number
		% ----------------------------------------------
			i=i+1;
			i1=i;
			while i~=long_chaine & (chaine(i)>='0' & chaine(i)<='9'),
			  i=i+1;
			end
			if i==long_chaine & (chaine(i)>='0' & chaine(i)<='9'),
				i2=i;
			else
				i2=i-1;
			end
			var_type(nvary)=eval(chaine(i1:i2));
			var_index(nvary,2)=i2;
		%
		elseif str(2)=='c' | str(2)=='l',
		%Find end of variable names Il.... ou Uc....
		%--------------------------------------------------------
			while i~=long_chaine-1 & ~strcmp(str,'_b'),
				i=i+1;
				str=chaine(i:i+1);
			end
			if str~='_b',error(['Format error in the string :',...
			             chaine(var_index(nvary,1):i),'...']); end
			i=i+2;
			while i~=long_chaine & ((chaine(i)>='0'& chaine(i)<='9')...
			      | chaine(i)=='_'  | chaine(i)=='n'),
				i=i+1; 
			end
			if i==long_chaine & (chaine(i)>='0' & chaine(i)<='9'),
				var_index(nvary,2)=i;
			else
				var_index(nvary,2)=i-1;
			end
		%
		else,
		%Find end of variable names  U_nx1_x2 
		%---------------------------------------------
			if strcmp(chaine(i:i+2),'U_n'),
			% Decode variable ..
				i=i+3; % beginning of node1
				str1=[]; str2=[];
				while i<=long_chaine & ((chaine(i)>='0' & chaine(i)<='9')|...
				      chaine(i)=='.'),
					str1=[str1,chaine(i)];
					i=i+1;
				end
				i=i+1; % beginning of node2
				while i<=long_chaine & ((chaine(i)>='0' & chaine(i)<='9')|...
				      chaine(i)=='.'),
					str2=[str2,chaine(i)];
					i=i+1;
					if i>long_chaine, break; end
				end
				%fin de U_n11_22
				var_neu(nvary,1)=str2num(str1);
				var_neu(nvary,2)=str2num(str2);
				var_index(nvary,2)=i-1;
			else
				error(['Format error in the string:',chaine(i:i+2),'...']);
			end
		end
	end
end
%
% Build two expressions expr_c et expr_d to be evaluated
% for computation of line i_sortie of matrices [C] and [D]
% ===========================================================
expr_c=[]; expr_d=[];
i=1;
for ivary=1:nvary,
	i1=var_index(ivary,1); i2=var_index(ivary,2);
	var_existe=0;
	str=chaine(i1:i2);
	ncar=length(str);
	% cas du format complet type : Il_bxx_n11_22; 
	% considerer seulement la chaine Il_bxx
	n=find(str=='_'); if length(n)==3, ncar=n(2)-1; end
	%
	if var_type(ivary)>0,
		% Contribution of input variables type U1 I2 I3 U4 ... 
		% ----------------------------------------------------
		isrc=var_type(ivary);
		if isrc>nbr_src 
			error(['La source ',str,' n''existe pas']);
		end
		if	(source(isrc,3)==0 & chaine(i1)~='U') | ...
			(source(isrc,3)==1 & chaine(i1)~='I'),
			error(['La source ',str,' n''existe pas']);
		end
		eval(['vec_u(',int2str(isrc),',',int2str(isrc),')=1;'])
		str2=['vec_u(',int2str(isrc),',:)'];
		i3=i1-1;
		expr_c=[expr_c,chaine(i:i3),'vec_c0'];
		expr_d=[expr_d,chaine(i:i3),str2];
	%
	% Contribution of voltages type U_nx1_x2 
	% ---------------------------------------
	elseif var_type(ivary)==0 & strcmp(str(1:3),'U_n'),
	%
		neu1=var_neu(ivary,1);
		neu2=var_neu(ivary,2);
		%
		str1='('; str2='(';
		ineu=find(liste_neu==neu1);
		if isempty(ineu), error(sprintf('Node %g does not exist!',neu1)); end
		if ineu<nbneu,
			if nbvar1>0, str1=[str1,'Cvn(',num2str(ineu),',:)']; end
			str2=[str2,'Dvn(',int2str(ineu),',:)'];
		end
		%
		ineu=find(liste_neu==neu2);
		if isempty(ineu), error(sprintf('Node %g does not exist!',neu2)); end
		if ineu<nbneu,
			if nbvar1 >0, str1=[str1,'-Cvn(',num2str(ineu),',:)']; end
			str2=[str2,'-Dvn(',int2str(ineu),',:)'];
		end
		%
		% Voltage between two identical nodes 
		if neu1==neu2,
			str1=['(vec_c0'];
			str2=['(vec_d0'];
		end
		%
		str1=[str1,')']; str2=[str2,')'];
		i3=i1-1;
		expr_c=[expr_c,chaine(i:i3),str1];
		expr_d=[expr_d,chaine(i:i3),str2];
	%
	else
		% Contribution of variables type dUc..., dIl..., Uc..., Il....
		% ----------------------------------------------------------------
		for ivar=1:nbvar,
			if strcmp(str(1:ncar),var_nom(ivar,1:ncar)) &...
					 var_nom(ivar,ncar+1)=='_',
				if var_branche(ivar,2)~=0 ,
				% Find variable no to be used in place of ivar
					ib1=var_branche(ivar,2);
					if var_nom(ivar,1)=='I',
						nobr=-L_combi.*sign(Il_relat(ib1,:));
						n=find(nobr(1:nb_lcombi-nb_ldep)~=0); nobr=nobr(n);
						if length(find(Il_relat(ib1,:)~=0))==1,
							n=[]; nobr=[]; novar=[];
						end
					else,
						nobr=-C_combi.*sign(Uc_relat(ib1,:));
						n=find(nobr(1:nb_ccombi-nb_cdep)~=0); nobr=nobr(n);
					end
					str_signe=[]; novar=[];
					for ib=1:length(nobr),
						ib1=abs(nobr(ib));
						novar(ib)=find(var_branche(:,1)==abs(ib1) & ...
							           var_nom(:,1)==var_nom(ivar,1));
						if sign(nobr(ib))>0, 
							str_signe(ib)='+';
						else
							str_signe(ib)='-';
						end
					end
				else,
					novar=ivar;
					str_signe=' ';
					nobr=+1;
				end
				% Derivative of a voltage or current
				% ----------------------------------
				if var_type(ivary)==-1,
					i3=i1-2;
					str1='('; str2='(';
					if isempty(novar),
						str1=[str1,'vec_c0']; str2=[str2,'vec_d0']; end
					for n=1:length(novar),
						str1=[str1,str_signe(n),'A(',int2str(novar(n)),',:)'];
						str2=[str2,str_signe(n),'B(',int2str(novar(n)),',:)'];
					end
					str1=[str1,')']; str2=[str2,')'];
					%if length(novar)==0, str1='([])'; str2='([])'; end
				%
				else,
				% Voltage or current
				% ------------------
					i3=i1-1; 
					vecc=zeros(1,nbvar1);
					for n=1:length(novar),
						vecc(novar(n))=sign(nobr(n));
						vecd(novar(n))=sign(nobr(n));
					end
					eval(['vec_c(',int2str(ivar),',:)=vecc;']);
					str1=['vec_c(',int2str(ivar),',:)'];
					if nbr_src,
						eval(['vec_d(',int2str(ivar),',:)=zeros(1,nbr_src);']);
						str2=['vec_d(',int2str(ivar),',:)'];
					else
						str2='';
					end
				end
				%
				expr_c=[expr_c,chaine(i:i3),str1];
				expr_d=[expr_d,chaine(i:i3),str2];
				var_existe=1;
			end
		end
		if ~var_existe,
			error(['Expression: ',chaine,'; Variable ',str,...
			' does not exist']);
		end
	end
	i=i2+1;
end
% complete the string     
if i<=long_chaine, expr_c=[expr_c,chaine(i:long_chaine)]; end
if i<=long_chaine, expr_d=[expr_d,chaine(i:long_chaine)]; end
if nbr_src==0, expr_d=[]; end
%
if debug_etat,
	fprintf(['expr_c=',expr_c,'\n']);
	fprintf(['expr_d=',expr_d,'\n']);
end
