function [nores,niles] =  etaisole(Y)
%
%  ETAISOLE finds isolated networks from the admittance Y bus matrix
%
%  Input argument
%  ==============
%      Y  : Admittance matrix of the network 
%
%  Output arguments
%  ================
%   nores : Vector containing the sub-network number of each node
%   niles : numer of isolated sub-networks 
%
%           Example: 6 node network;
%           -------- nodes 1 2 4 and 6 are in sub-network #1
%                    nodes 3 and 5 are in sub-network #2
%
%           ISOLE returns:
%                    nores=[ 1 1 2 1 2 1]
%                    niles=2

%                      R. Belhomme;   G. Sybille April 1995
%===============================================================================
%
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.2 $

nbneu=max(size(Y));
nores=-1*ones(1,nbneu);
niles=0;
for iligne=1:nbneu
   if nores(iligne)==-1
	niles=niles+1;
	nores(iligne)=iligne;
   end
   for icol=iligne+1:nbneu
	if Y(iligne,icol)~=0
		if nores(icol)==-1
		   nores(icol)=nores(iligne);
		else
		   if nores(icol) ~= nores(iligne)	
			index=find(nores == nores(iligne));
			nores(index)=nores(icol)*ones(1,max(size(index)));
			niles=niles-1;
		   end
		end
	end
   end
end
% Process non classified nodes (isolated nodes)
% ----------------------------------------------
index=find(nores==-1);
j=nbneu;
for icol=1:length(index),
	niles=niles+1;
	j=j+1;
	nores(index(icol))=j;
end
%
% Give consecutive sub-network (island) numbers
% ---------------------------------------------
for icol=1:niles,
	if ~any(nores==icol),
		% changer les nos d'ile superieurs a niles
		index=find(nores>niles);
		index=find(nores==nores(index(1)));
		nores(index)=icol*ones(1,max(size(index)));
	end
end
