function[lignes]=nscnline(lignes)
%NSCNLINE Convert indirect connections to direct
% 	Note: Internal netsim function. 
%	May not work properly when used elsewhere.
% 
%	[LIGNES]=NSCNLINE(LIGNES)
% 	input arguments:
%		LIGNES: (integer matrix) block connection matrix
% 	output arguments:
%		LIGNES: (integer matrix) Modified block connection matrix
% 	NSCNLINE converts all indirect connections to direct ones.
% 	Specially marked lines of LIGNES by NSCNPORT are removed
% 	Lines that have no destination block are systematically removed.
% 	Lines that have no origin block AND that have no other lines
%	connected to them are also removed.

%   Christian Dufour 11-22-95 , 04-17-96
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.2 $
 
if isempty(lignes)
	return
end
 
while sum((lignes(:,1)==0) & (lignes(:,2)==1))>0
    for i=1:1:size(lignes,1)
	if (lignes(i,1)>0)
		;
	elseif (lignes(i,1)==0)
		if (lignes(i,2)==0)
			error('nscnline err:1');
 		else
 			lignes(i,1:2)=lignes(lignes(i,5),1:2);
			lignes(i,5)=lignes(lignes(i,5),5);
		end
	else
		;		
	end
    end
end
 
lignesP=[];

 
% ELIMINATION OF -NEGATIVE LINES LEFT BY NSCNPORT
%		 -OPEN ENDED SIMULINK LINES
j=1;
for i=1:size(lignes,1)
	if lignes(i,1)<0
		;
	elseif lignes(i,3)==0 & lignes(i,4)==0
		;
	else		
		lignesP(j,:)=lignes(i,:);
		j=j+1;
	end
end
lignes=lignesP;
if isempty(lignes)
	return
end

% ELIMINATION OF UNNECESSARY GHOST BLOCKS :
%  elimination des lignes originant de blocs fantomes
%  de facon unique les blocs fantomes se reconnaissent a lignes(1:2)=[x 0] 
%  where x>0

% IDENTIFICATION :
badbloc=[];
flagfant=(lignes(:,1)>0) & (lignes(:,2)==0);
blocfant=lignes(find(flagfant==1),:);
for i=1:size(blocfant,1)
	loc=find(blocfant(:,1)==blocfant(i,1));
	if length(loc)==1
		badbloc=[badbloc blocfant(i,1)];
	end
end

% ELIMINATION :
lignesP=[];
j=1;
if isempty(badbloc),badbloc=[-123456];end % bloc bidon pour passer le test find
for i=1:size(lignes,1)
	if ~isempty(find(badbloc==lignes(i,1)))
		;
 	else
		if lignes(i,2)==0
			lignes(i,2)=1;
		end		
		lignesP(j,:)=lignes(i,:);
		j=j+1;
	end
end
lignes=lignesP;
		



 
    
 



