function[lignes]=nscnport(lignes,blocs,CustomBlocNumber,ParentBloc,ParamNumber)
%NSCNPORT Connect simulink subsystem and in/out ports
% 	Note: Internal netsim function. 
%	May not work properly when used elsewhere.
% 
%	[LIGNES]=NSCNPORT(LIGNES,BLOCS,CUSTOMBLOCNUMBER,PARENTBLOC,PARAMNUMBER)
% 	input arguments:
%		LIGNES: (integer matrix) block connection matrix
%		BLOCS: (string matrix) block name matrix
%		CUSTOMBLOCNUMBER: (integer vector) Toolbox block 
%	                                           identification number
%		PARENTBLOC: (integer vector) Parent block number vector
%		PARAMNUMBER:(integer vector) Block special parameter vector
% 	output arguments:
%		LIGNES: (integer matrix) modified block connection matrix
%
% 	NSCNPORT connects internally degroup all subsystems in a Simulink window
% 	At the end, subsystem blocks and in/out ports are eliminated, but
% 	connectivity remains the same. For each input port, the corresponding 
%	entry to the subsystem is found and connected to the output of the input
% 	port. For each output port, the corresponding output from the subsystem 
%	is found and connected to the input of the output port.

%   Christian Dufour 11-22-95 ,04-17-96
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.2 $
 
for i=1:size(blocs,1)
   % CASE:INPORT :
   if(CustomBlocNumber(i)==999)   
 	flag=0;
	flaga=0;
   	for k=1:size(lignes,1)
		% LOOK FOR INPORT OUTPUT :
		if( lignes(k,1)==i )   
 			old_ref=k;
			flag=1;
		end
		% LOOK FOR PARENT SYSTEM CORRESPONDING INPUT :
		if( lignes(k,3)==ParentBloc(i) & lignes(k,4)==ParamNumber(i))
			new_ref=k; 
			flaga=1;
		end
	end
	if (flag==1 & flaga==1)
 
		% CASE: CONNECTED INPORT AND CONNECTED PARENT SYSTEM
		% CONNECT INPORT LINE TO PARENT LINE
		lignes(new_ref,3:4)=lignes(old_ref,3:4); 
		% ELIMINATE INPORT LINE
		lignes(old_ref,1:5)=[-1 -1 -1 -1 -1];
	elseif (flaga==1)
		% CASE: NO CONNECTION AT THE INPORT LEVEL
		% PUT UNCONNECTED LINE AT THE PARENT LEVEL
		lignes(new_ref,3:4)=[0 0];
	elseif (flag==1)
		% CASE: NO CONNECTION AT THE PARENT LEVEL
		% PUT UNCONNECTED LINE AT THE INPORT LEVEL
		lignes(old_ref,1:2)=[0 0];
	else
		;
	end		

	% CHANGE INDIRECT REFERENCES TO LINE JUST ELIMINATED :
	if (flag==1 & flaga==1)
		for m=1:size(lignes,1)
			if( lignes(m,5)==old_ref )
				lignes(m,5)=new_ref;
 			end
		end
	end
   end
 
 % CASE: OUTPORT
   if (CustomBlocNumber(i)==1001)
 	flag=0;
	flaga=0;
   	for k=1:size(lignes,1)
		% LOOK FOR INPUT TO OUTPORT			 
		if( lignes(k,3)==i )
 			old_ref=k;
 			flag=1;
		end
		% LOOK FOR CORRESPONDING OUTPUT AT THE BLOCK PARENT LEVEL   
		if( lignes(k,1)==ParentBloc(i) & lignes(k,2)==ParamNumber(i))
			new_ref=k;
			flaga=1;
		end
	end
 	if (flag==1 & flaga==1)
		% CASE: OUTPORT & PARENT BOTH CONNECTED
		% CONNECT 
		lignes(new_ref,1:2)=lignes(old_ref,1:2);
		lignes(new_ref,5)=lignes(old_ref,5);
		% MARK FOR LATER DELETION OUTPORT LINE
		lignes(old_ref,1:5)=[-2 -2 -2 -2 -2];
 	elseif (flaga==1)
		% CASE: NO CONNECTION AT THE OUTPORT LEVEL
		% PUT UNCONNECTED LINE AT THE PARENT LEVEL
		lignes(new_ref,1:2)=[0 0];
	elseif (flag==1)
		% CASE: NO CONNECTION AT THE PARENT LEVEL
		% PUT UNCONNECTED LINE AT THE OUTPORT LEVEL
		lignes(old_ref,3:4)=[0 0];
	else
		;
	end

	% CHANGE REFERENCES POINTING TO LINE JUST ELIMINATED
	if (flag==1 & flaga==1)
		for m=1:size(lignes,1)
			if( lignes(m,5)==old_ref )
				lignes(m,5)=new_ref;
 			end
		end
	end
   end
end
 

