function [rlc,BrancheRef,y_type,yout,capteurindice,outputs]=nscoeran(blocs,blocswo,lignes,Noeuds,rlc,source,others,BrancheRef,CustomBlocNumber,capteurindice,capteurlist,y_type,yout,srcstr,outputs,allneu,nores,nsflag)
%NSCOERANS Coherence checker for netsim
%	[RLC,BRANCHEREF,Y_TYPE,YOUT,CAPTEURINDICE,OUTPUTS]=NSCOERANS(BLOCS,
%	BLOCSWO,LIGNES,NOEUDS,RLC,SOURCE,OTHERS,BRANCHEREF,CUSTOMBLOCNUMBER,
%	CAPTEURINDICE,CAPTEURLIST,Y_TYPE,YOUT,SRCSTR,OUTPUTS,NSFLAG)
%	Parameters:
%		BLOCS:		list of the names of the blocks in the network
%		BLOCSWO:	list of the names of the blocks in the network
%				without the window name at the beginning
%		LIGNES:		Line matrix of the circuit
%			Format of LIGNES:
%			LIGNES(1): Block number at the origin of the line
%			LIGNES(2): Output number of the block at the origin
%			LIGNES(3): Block number at the destination of the line
%			LIGNES(4): Input number of the block at the destin.
%			LIGNES(5): not used 			
%		NOEUDS:		Node allocation for each line of the circuit
%				Each lines of LIGNES has a node
%		RLC:		rlc matrice *
%		SOURCE:		source matrice *
%		OTHERS:		matrix of simulink connection to electrical
%				blocks
%			Format of OTHERS (each line):
%			OTHERS(1): node number
%			OTHERS(2): block number (index in BLOCS) 
%			OTHERS(3): input/output number in block
%			OTHERS(4): =1:input  =2:output
%		BRANCHEREF:	Block number referencing matrice for the RLC 
%				matrice. 
%			1e col:	For the corresponding line in RLC,
%				indicates the number of the block from which
%				the line comes from 
%			2e col: special number used in multi state variable 
%				blocks
%				Line:	Capacity or inductance number
%				Mutual inductance: coil number
%				Linear transformer: coil number
%				Saturable transformer: coil number
%		CUSTOMBLOCNUMBER:vector that indicates the number of the 
%				blocks in reference to the CustomBlocs matrice.
%				In addition, special values indicates special
%				blocks: 
%				=666666	non-drawn block created in the case
%					of unconnected lines
%				=999	in-port block (in subsystems)
%				=1001	out-port block (in subsystems)
%		CAPTEURINDICE:	Indice of the captor with respect to its output
%				rank in yout or outstr vectors.
%				Negative value for unconnected sensors.
%		CAPTEURLIST:	vector of the indices of the sensors in BLOCS
%		Y_TYPE:		vector of the type of the output value *
%		YOUT:		string matrice of the output values *
%		SRCSTR:		matrix containing the block names of the 
%				sources of the network corresponding to the
%				source matrice
%		OUTPUTS:	matrix containing the names of the outputs 
%				of the system
%		NSFLAG:		netsim flags
%
%	* see etat.m or etatfun.m for more details
%
%	See also ETATFUN, NETSIM

%   Christian Dufour 11-28-95, Patrice Brunelle 06-13-97
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.3 $
 
% modifications suite a la revision 1.1:
% 1. modif dans les messages d'erreurpour les measurements mal connectes.

%% Patrice Brunelle


 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%  COHERENCE       %%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Parameters

MINBLOC=1;	% minimum number of EPSD toolbox block
MAXBLOC=36;	% maximum number of EPSD toolbox block

LIGHTSPEED=299792.458;	% speed of light. units: km/s 
errstr=[];
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 1st Coherence test: 	Check if Cacacity block is shorted                  %
%				-check if rlc entries have different nodes  %
%	if yes: fatal error                                                 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% 1- Si les deux extremites d'un bloc C sont au meme noeuds, 
%   --> Erreur fatale

%% etat3.6 suporte maintenant les blocs rlc court-circuites
%% sauf Capacite court-circuitee
if ~isempty(rlc)
	loc=find((rlc(:,1)==rlc(:,2))~=1);
	locnot=find(( (rlc(:,1)==rlc(:,2)) & ...
			rlc(:,4)<100*eps   & ...
			rlc(:,5)<100*eps   & ...
			rlc(:,6)>100*eps    ));
	if ~isempty(locnot) & nsflag(1)==1 
		nserror(errstr,'',-1); % display warnings
	end	
 	errstr='';
	for i=1:length(locnot)
		errstr=str2mat(errstr,['FATAL! Shorted capacitive block: ' ...
		 deblank(blocswo(BrancheRef(locnot(i),1),:)) ]);
	end 
	errstr=errstr(2:size(errstr,1),:);
	if length(locnot)>0
		nserror(errstr,'',15);
	end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 2e coherence test :	Check for open ended blocks                         %
%	if yes: warning, continue                                           %
%									    %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% 2- S'il y a des connections ouvertes, donner avertissement
if isempty(source)
	sourceMod=[-1 -1 -1 -1 -1];
else
	sourceMod=source;
end
if isempty(rlc)
	rlcMod=[-1 -1 -1 -1 -1];
else
	rlcMod=rlc;
end

% TEMPORARY MODIFICATION OF RLC TO HIDE MAGNETISATION BRANCHES :

flag=0;
for i=1:size(rlcMod,1)
	if flag==0
		if rlcMod(i,3)==2 | rlcMod(i,3)==3
			flag=1;
		end
	end
	if flag==1
		if rlcMod(i,3)==1 | rlcMod(i,3)==0
			rlcMod(i,2)=rlcMod(i,1);
			flag=0;
		end
	end
end
 
listnoeuds=[rlcMod(:,1)' rlcMod(:,2)' sourceMod(:,1)' sourceMod(:,2)'];
listtype=[rlcMod(:,3)' rlcMod(:,3)' 0*sourceMod(:,3)' 0*sourceMod(:,3)'];
nbrnoeuds=zeros(1,length(listnoeuds));
for i=1:length(listnoeuds)
	loc=find(listnoeuds==listnoeuds(i));
	nbrnoeuds(i)=length(loc);
end

locunique=find(nbrnoeuds==1);

for i=1:length(locunique)
 	if locunique(i)<=size(rlcMod,1)		
		errmess=['WARNING! Open ended block: ' ...
		 deblank(blocswo(BrancheRef(locunique(i),1),:)) ];
		errstr=nserror(errstr,errmess);
	elseif locunique(i)<=(2*size(rlcMod,1))
		errmess=['WARNING! Open ended block: ' ...
	        deblank(blocswo(BrancheRef(locunique(i)-size(rlcMod,1),1),:)) ];
		errstr=nserror(errstr,errmess);
	elseif locunique(i)<=(2*size(rlcMod,1) + size(source,1))
		errmess=['WARNING! Open ended block: ' ...
	       deblank(srcstr(locunique(i)-2*size(rlcMod,1),3:size(srcstr,2)))];
		errstr=nserror(errstr,errmess);
	elseif locunique(i)<=(2*size(rlcMod,1) + 2*size(source,1))
		errmess=['WARNING! Open ended block: ' ...
 		deblank(srcstr(locunique(i)-2*size(rlcMod,1)-size(source,1), ...
		3:size(srcstr,2))) ];
		errstr=nserror(errstr,errmess);
	else
		error('nscoeran  err:1');
	end
end

%  LINE BLOCK: MUST BE CHECK FROM THE 'lignes' MATRIX
%  BECAUSE OF  INTERNAL CONNECTION OF PI MODEL
%  CHECK ALSO PROPAGATION SPEED

%  cas speciaux: Line
%  ces blocs ont des connections internes
%  il faut donc analyser au niveau des blocs
%  L'analyse suivante tient compte du fait que les lignes non-branchees 
%  superflues ont ete eliminees dans nsgrafx.m
%  On verifie aussi la constante de propagation pour voir si elle tombe dans
%  les normes

% modifs PB 13-06-97  : bloc a 1 in 1 out:

for i=1:length(CustomBlocNumber)
	if CustomBlocNumber(i)==3   % Pi Line
		flag=[0 1 0 1];  % <-- plus de 2e in/out    
		for j=1:size(lignes,1)
			if lignes(j,1)==i
				if lignes(j,2)==1	% 1re sortie
 					flag(1)=1;
				end
			end
			if lignes(j,3)==i
				if lignes(j,4)==1	% 1re entree
 					flag(3)=1;
				end
			end
		end
		if sum(flag)<4
			if flag(2)==0 & flag(4)==0
				flagflag=1;
			else
				flagflag=0;
			end
			str='(';
			if flag(1)==0 | flag(2)==0
				str=[str 'outputs: '];
				if flag(1)==0
					str=[str '#1,'];
				end
				if flag(2)==0 & flagflag==1
					str=[str '#2,'];
				end
			end
			if flag(3)==0 | flag(4)==0
				str=[str 'inputs: '];
				if flag(3)==0
					str=[str '#1,'];
				end
				if flag(4)==0 & flagflag==1
					str=[str '#2,'];
				end
			end
			str=[str ')'];			
			errmess=['WARNING! Open ended block: ' ...
				deblank(blocswo(i,:)) ' ' str ];
			errstr=nserror(errstr,errmess);
		end

		% Coherence: constante de propagation
		str=get_param(nsdezero(blocs(i,:)),'Mask Entries');
		loc=findstr('|',str);
		eval(['R=' str(1:loc(1)-1) ';' ]);
		eval(['L=' str(loc(1)+1:loc(2)-1) ';' ]);
		eval(['C=' str(loc(2)+1:loc(3)-1) ';' ]);
		vitesse=1/sqrt(L*C);
			flag=0;
		if vitesse> LIGHTSPEED 
			flag=1;
			str='superior to speed of light!';
		elseif vitesse < 0.25*LIGHTSPEED
			flag=1;
			str='inferior to  of the speed of light!';
		else
			flag=0;
		end
		if flag==1
		    if nsflag(1)==1		    
		errmess=['WARNING! Questionable parameters for Line block: ' ...
				 deblank(blocswo(i,:)) ];
			errstr=nserror(errstr,errmess);

	     errmess=['                    Computed speed of propagation, '  ...
				 num2str(vitesse)  ' km/sec, ' str  ];
			errstr=nserror(errstr,errmess);
		    end
		end
  	end
 end

% CHECK FOR OPEN CONNECTION OF SIMULINK I/0 TO EPSD BLOCK

for i=1:size(others,1)
	tmp=find(Noeuds==others(i,1));
	if length(tmp)==0&others(i,2)~=0&others(i,3)~=0
		if others(i,4)==1
			str='input';
		else
			str='output';
		end
		errmess=['WARNING! Open ended block: ' ...
 			deblank(blocswo(others(i,2),:)) ...
		 	' (Simulink ' str  ' #' num2str(others(i,3)) ')' ];
		errstr=nserror(errstr,errmess);
	end
end


% CHECK FOR BADLY CONNECTED SENSORS :

for i=1:length(capteurindice)
	% VOLTAGE SENSOR :
	if y_type(capteurindice(i))==0		
		str=yout(capteurindice(i),:);
		loc=findstr(str,'_');
		neu1=str2num(str(loc(1)+2:loc(2)-1));
		neu2=str2num(str(loc(2)+1:length(str)));

		% capteur branche a un noeud unique :
 		if isempty(find(listnoeuds==neu1)) | ...
 		   isempty(find(listnoeuds==neu2)) 
			y_type(capteurindice(i))=-1;
			capteurindice(i)=-1;
			errmess=['FATAL! Badly connected voltage sensor: ' ...
				deblank(blocswo(capteurlist(i),:)) ];
			errstr=nserror(errmess,'',11);

		% capteur branche entre 2 reseaux isoles :
		elseif nores(find(neu1==allneu))~=nores(find(neu2==allneu))   
			y_type(capteurindice(i))=-1;
			capteurindice(i)=-1;
			errmess=['FATAL! Voltage sensor: ' ...
				deblank(blocswo(capteurlist(i),:)) ' connected between 2 isolated networks!'];
			errstr=nserror(errmess,'',11);
		end	
	% CURRENT SENSOR :
	elseif y_type(capteurindice(i))==1		
		str=yout(capteurindice(i),:);
		%cas speciaux prevu par nsfb10a.m
 		if sum(str(4:5)=='-1')==2
			y_type(capteurindice(i))=-1;
			capteurindice(i)=-1;
			errmess=['FATAL! Current sensor named: ' ...
				deblank(blocswo(capteurlist(i),:)) ' connected across a null impedance branch or network'];
			errstr=nserror(errmess,'',11);
		end
		if sum(str(4:5)=='-2')==2
			y_type(capteurindice(i))=-1;
			capteurindice(i)=-1;
			errmess=['FATAL! Current sensor named: ' ...
				deblank(blocswo(capteurlist(i),:)) ' connected between 2 nodes that have null impedance to ground '];
			errstr=nserror(errmess,'',11);
		end
		if sum(str(4:5)=='-3')==2
			y_type(capteurindice(i))=-1;
			capteurindice(i)=-1;
			errmess=['FATAL! Current sensor named: ' ...
				deblank(blocswo(capteurlist(i),:)) ' has a open end (input side)  '];
			errstr=nserror(errmess,'',11);
 		end
		if sum(str(4:5)=='-4')==2
			y_type(capteurindice(i))=-1;
			capteurindice(i)=-1;
			errmess=['FATAL! Current sensor named: ' ...
				deblank(blocswo(capteurlist(i),:)) ' has a open end (output side)  '];
			errstr=nserror(errmess,'',11);
 		end
	else
		error('nscoeran  err:2');
	end
end
 
if length(y_type)>0
	loc=find(y_type~=-1);
	% MODIFY  'capteurindice' :
	decr=0;
	for i=1:length(capteurindice)
		if capteurindice(i)<0
			decr=decr+1;
		end
		capteurindice(i)=capteurindice(i)-decr;
	end
	outputs=outputs(loc,:);
 	y_type=y_type(loc);
	yout=yout(loc,:);
end

% CHECK FOR CORRECT CONNECTIONS BETWEEN SIMULINK AND EPSD BLOCKS :

%  Verifier les branchements selon les types de blocs
%		Simulink<->Electrique
%		Simulink<->Simulink
%		Electrique<->Electrique
%  Description InOutType[]
%  chaque ligne correspond a un type de bloc
%  ainsi la ligne 2 correspond au bloc Parallel RLC
%
%	InOutType(1:5) = [numero des entrees electrique] 
%	InOutType(6:10)= [numero des entrees simulink]
%	InOutType(11:15)=[numero des sorties electrique]
%	InOutType(16:20)=[numero des sorties simulink]
 
InOutType=[
1 0 0 0 0	0 0 0 0 0	1 0 0 0 0	0 0 0 0 0    %Series RLC
1 0 0 0 0	0 0 0 0 0	1 0 0 0 0	0 0 0 0 0    %Parallel RLC
1 0 0 0 0	0 0 0 0 0 	1 0 0 0 0 	0 0 0 0 0    %Line
1 2 3 0 0	0 0 0 0 0	1 2 3 0 0 	0 0 0 0 0    %Mutual inductance
1 2 0 0 0	0 0 0 0 0	1 2 3 4 0	0 0 0 0 0    %Linear transformer
1 2 0 0 0	0 0 0 0 0	1 2 3 4 0	0 0 0 0 0    %Saturable transfor
1 0 0 0 0	0 0 0 0 0	1 0 0 0 0	0 0 0 0 0    %Load series RLC
1 0 0 0 0	0 0 0 0 0	1 0 0 0 0	0 0 0 0 0    %Load parallel RLC
1 2 0 0 0	0 0 0 0 0	0 0 0 0 0	1 0 0 0 0    %Voltage measuremen
1 0 0 0 0 	0 0 0 0 0	2 0 0 0 0	1 0 0 0 0    %Current measuremen
1 0 0 0 0	0 0 0 0 0	1 0 0 0 0	0 0 0 0 0    %AC voltage source
1 0 0 0 0	0 0 0 0 0	1 0 0 0 0	0 0 0 0 0    %AC current source
999 0 0 0 0	0 0 0 0 0	999 0 0 0 0	0 0 0 0 0    %Bus bar
1 0 0 0 0	0 0 0 0 0	1 0 0 0 0	0 0 0 0 0    %Ground
1 0 0 0 0	0 0 0 0 0	1 0 0 0 0	0 0 0 0 0    %Neutral
0 0 0 0 0	1 2 0 0 0	1 2 3 0 0	4 0 0 0 0    %Simplified altern.
0 0 0 0 0	1 2 0 0 0	1 2 3 0 0	4 0 0 0 0    %Synchronous machin
1 2 3 0 0	4 0 0 0 0	0 0 0 0 0	1 0 0 0 0    %PM Synchro. motor
1 0 0 0 0	2 0 0 0 0	1 0 0 0 0	2 0 0 0 0    %Gto
1 2 3 0 0	4 0 0 0 0	1 2 3 0 0	4 0 0 0 0    %Asynchronous mach.
1 0 0 0 0	2 0 0 0 0	1 0 0 0 0	2 0 0 0 0    %Ideal switch
1 0 0 0 0	2 0 0 0 0	1 0 0 0 0	2 0 0 0 0    %Mosfet
1 0 0 0 0	2 0 0 0 0	1 0 0 0 0	2 0 0 0 0    %Simplified thyris
1 0 0 0 0	0 0 0 0 0	1 0 0 0 0	2 0 0 0 0    %Diode
1 0 0 0 0	2 0 0 0 0	1 0 0 0 0	2 0 0 0 0    %Thyristor
1 0 0 0 0	2 0 0 0 0	1 0 0 0 0	0 0 0 0 0    %Breaker
0 0 0 0 0	0 0 0 0 0	0 0 0 0 0	0 0 0 0 0    %
1 0 0 0 0	0 0 0 0 0	1 0 0 0 0	0 0 0 0 0    %Surge arrester
0 0 0 0 0	0 0 0 0 0	0 0 0 0 0	0 0 0 0 0    %
0 0 0 0 0	0 0 0 0 0	0 0 0 0 0	0 0 0 0 0    %
0 0 0 0 0	0 0 0 0 0	0 0 0 0 0	0 0 0 0 0    %
1 0 0 0 0	0 0 0 0 0	1 0 0 0 0	0 0 0 0 0    %DC voltage source
0 0 0 0 0	0 0 0 0 0	0 0 0 0 0	0 0 0 0 0    %
1 2 3 4 5	0 0 0 0 0	1 2 3 4 5	0 0 0 0 0    %Dist. param. line
0 0 0 0 0	1 0 0 0 0	1 2 0 0 0	0 0 0 0 0    %Variable voltage
0 0 0 0 0	1 0 0 0 0	1 2 0 0 0	0 0 0 0 0    %Variable current
 ];



if size(InOutType,1)~=MAXBLOC
	error('nscoeran err:3');
end

typestr=[	'Electrical         ';
		'Simulink           ';
		'Don"t care         ';
		'(null)             ';
		'Not used (reserved)'];

for i=1:size(lignes,1)
	bloc_out=CustomBlocNumber(lignes(i,1));
	bloc_in =CustomBlocNumber(lignes(i,3));
	wire_out=[]; % 1:electrique 2:Simulink 3:don't care 
		     % 4: special(out from bloc fantome) 5: not used
	wire_in=[];
	if bloc_out==666666
		wire_out=4; % cas special: plusieurs blocs peuvent etre branches
			    % a une sortie de bloc fantome
		indice_special=[];
		for j=1:size(lignes,1)
			if lignes(i,1)==lignes(j,1) 
				% les blocs fantomes n'ont que 1 sortie! 
				indice_special=[indice_special j];
			end
		end	
	elseif bloc_out>MAXBLOC
		wire_out=3;
	elseif bloc_out==13
		wire_out=1;
	elseif bloc_out>=MINBLOC
		if  ~isempty(find(InOutType(bloc_out,11:15)==lignes(i,2)))
			wire_out=1;
		elseif ~isempty(find(InOutType(bloc_out,16:20)==lignes(i,2)))
			wire_out=2;
		else
			wire_out=5;
		end
	else
		wire_out=2;
	end
	if bloc_in>MAXBLOC
		wire_in=3;
	elseif bloc_in==13
		wire_in=1;
	elseif bloc_in>=MINBLOC
		if  ~isempty(find(InOutType(bloc_in,1:5)==lignes(i,4)))
			wire_in=1;
		elseif ~isempty(find(InOutType(bloc_in,6:10)==lignes(i,4)))
			wire_in=2;
		else
			wire_in=5;
		end
	else
		wire_in=2;
	end
	if wire_out==4   % verifier que toutes les entrees  sont du meme type
		wire_in_sp=[];
		for j=1:length(indice_special)
		       bloc_in_sp=CustomBlocNumber(lignes(indice_special(j),3));
			if bloc_in_sp>MAXBLOC
				wire_in_sp(j)=3;
			elseif bloc_in_sp==13
				wire_in_sp(j)=1;
			elseif bloc_in_sp>=MINBLOC
				if  ~isempty(find(InOutType(bloc_in_sp,1:5) ...
				   ==lignes(indice_special(j),4)))
					wire_in_sp(j)=1;
				elseif ...
				    ~isempty(find(InOutType(bloc_in_sp,6:10) ...
				    ==lignes(indice_special(j),4)))
					wire_in_sp(j)=2;
				else
					wire_in_sp(j)=5;
				end
			else
				wire_in_sp(j)=2;
			end
		end

		nbr1=length(find(wire_in_sp==1));
		nbr2=length(find(wire_in_sp==2));
		nbr5=length(find(wire_in_sp==5));

		if nbr1*nbr2>0 | nbr5~=0
		    if nsflag(1)==1
			nserror(errstr,'',-1); % display warnings
		    end
			errstr=str2mat([ 'FATAL! Incompatible connection '...
			' type between two of the following blocks:'],'');
			for j=1:length(indice_special)
			    if CustomBlocNumber(lignes(indice_special(j),3))...
			     <=MAXBLOC
				  if wire_in_sp(j)==1
					str=' (type: Electrical)';
				  elseif wire_in_sp(j)==2
					str=' (type: Simulink)';
				  elseif wire_in_sp(j)==5
					str=' (type: Not Used)';
				  else
					error('nscoeran err:4');
				  end
				  errstr=str2mat(errstr, ['block: ' ...
			     deblank(blocswo(lignes(indice_special(j),3),:)) ...
		 '  ->input #' num2str(lignes(indice_special(j),4)) '  ' str ]);
			    end
			end
  			nserror(errstr,'',11);
		end
	elseif wire_in==3 | wire_out==3
		;
	elseif wire_in==5 | wire_out==5

	     if bloc_in==34|bloc_out==34 % P.B. modif 6-nov-96
		;
	     else
		if nsflag(1)==1
		    nserror(errstr,'',-1); % display warnings
		end
		errstr=str2mat([ 'FATAL! Connection of a reserved block ' ...
			' input/output between: '],'');
		errstr=str2mat(errstr, ...
		['block: ' deblank(blocswo(lignes(i,1),:)) '  ->output #' ...
		 num2str(lignes(i,2)) ' (' deblank(typestr(wire_out,:))  ')']);
		errstr=str2mat(errstr, ...
		['block: ' deblank(blocswo(lignes(i,3),:)) '  ->input #' ...
		 num2str(lignes(i,4)) '  (' deblank(typestr(wire_in,:))  ')']);
		nserror(errstr,'',11);
	      end

	elseif (wire_in==1 & wire_out==2) | (wire_in==2 & wire_out==1) 
		if nsflag(1)==1 
		    nserror(errstr,'',-1); % display warnings
		end
		errstr= ...
		  str2mat(['FATAL! Incompatible connection type between: '],'');
		errstr=str2mat(errstr,['block: ' ...
		  deblank(blocswo(lignes(i,1),:)) '  ->output #' ...
		  num2str(lignes(i,2)) ' (' deblank(typestr(wire_out,:))  ')']);
		errstr=str2mat(errstr,['block: ' ...
		  deblank(blocswo(lignes(i,3),:)) '  ->input #' ...
		  num2str(lignes(i,4)) '  (' deblank(typestr(wire_in,:))  ')']);
		nserror(errstr,'',11);
	elseif wire_in==wire_out
		; %OK
	else
		error('nscoeran err:5');
	end
 end	
if nsflag(1)==1		
	nserror(errstr,'',-1);
end

