function nserrwin(command,str,titre,errno) 
%NSERRWIN  produce error window use by netsim to display warnigs and errors. 
% 	Note: Internal netsim function. 
%	May not work properly when used elsewhere.
%
%	NSERRWIN(COMMAND,STR,TITRE,ERRNO) 
% 	input arguments:
%		COMMAND: (integer) action setting flag
%			=0 warning window
%			=1 error window
%			=2 suggestion window construction
%		STR: (string) string to be printed in the pop-up window
%		TITRE: (string) pop-up window title
%		ERRNO: (integer) error number  for which nserrwin is called
%			<1 : warnings 
%			>=1: errors
% 	output arguments:
%		NONE
%	            

%   Christian Dufour 11-28-95 , 04-17-96
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.2 $

% list of errors

% erreur 1: line not connected to ground  **OBSOLETE**
% erreur 2: Source de tension  en parallele avec un condensateur 
%		ou un court-circuit
% erreur 3: Source de courant %g-%g en serie avec inductance, 
%		circuit ouvert ou autre source de courant
% erreur 4:  Source de tension en parallele avec un circuit de condensateurs 
%		et/ou sources de tension 
% erreur 5: circuits isoles
% erreur 6: Circuit isole par la matrice A cas 1  
% erreur 7: Circuit isole par la matrice A cas 2
% erreur 8: Cicuit capacitif en parallel avec source tension
% erreur 9: circuit isole par la matrice B
% erreur 10: inductance en serie avec autre inductance ou source courant
% erreur 11 : connection incompatible entres blocs
% erreur 12 : vitesse de propagation incorrecte pour ligne de transmission
% erreur 13 : caractere '/' dans nom de bloc
% erreur 14 : pas de matrice rlc ni source
% erreur 15 : bloc Capacite pure court-circuite


% string for each error 
% format: strX where X is the number of the error

str1=[
'Error: Line not connected to ground                                                ';
'                                                                                   ';
'Suggestion: Connect lower sides of Line block to Ground                            ';];
 
str2=[
'Error: Voltage source in parallele with a capacitor or a short-circuit             ';
'                                                                                   ';
'Suggestion: If the topology cannot be changed, add a resistor with                 ';
'                    a low value in series with the voltage source.                 ';];

str3=[
'Error: Current source in serie with an inductance, an open circuit                 ';
'          or another current source.                                               ';
'                                                                                   ';
'Suggestion: If the topology cannot be change, add a resistor with                  ';
'                    a high value in parallel with the current source.              ';];
   
str4=[
'Error: Voltage source in parallel with a group of capacitors and/or voltage sources';
'                                                                                   ';
'Suggestion: If the topology cannot be changed, add a resistor with                 ';
'                    a low value in series with the voltage source.                 ';];

str5=[
'Error: Isolated networks.                                                          ';
'                                                                                   ';
'Suggestion: Topologically separated subnetwoks are not allowed by Netsim.          ';
'                    Consequently, all electrical elements must have an electrical  ';
'                    path to all others. If that''s not the case for a subnetwork    ';
'                    in the currently analysed Simulink window, connect it to the   ';
'                    the main network with a Simulink line or an RLC branch.        ';];
 
str6=[
'Error: Isolated network after computation of the A matrix of                       ';
'          the equivalent the state-space system                                    ';
'                                                                                   ';
'Suggestion: None                                                                   ';];

str7=[
'Error: Isolated network after computation of the A matrix of                       ';
'          the equivalent the state-space system                                    ';
'                                                                                   ';
'Suggestion: None                                                                   ';];
 
str8=[
'Error: Capacitive network in parallel with a voltage source                        ';
'                                                                                   ';
'Suggestion: None                                                                   ';];
 
str9=[
'Error: Isolated network found during the computation of the B matrix               ';
'                                                                                   ';
'Suggestion: None                                                                   ';];
 
str10=[
'Error: Inductance in series with another inductance or a current source            ';
'                                                                                   ';
'Suggestion: If the topology cannot be change, add a resistor with                  ';
'                    a high value in parallel with the inductance.                  ';];

str11=[
'Error: Incompatible bloc connection                                                           ';
'                                                                                              ';
'Suggestion: Check for correct I/O interconnection between standard Simulink blocks            ';
'                    and EPSD toolbox blocks. EPSD blocks have special I/O                     ';
'                    designed to be connected to standard Simulink blocks.                     ';
'                    Press EPSD block "Help" button or see documentation for more information. ';];

str12=[
'Error: Unrealistic speed of propagation for Line Block                                                 ';
'                                                                                                       ';
'Suggestion: Speed of propagation is computed from the following equation:                              ';
'                    speed=1/(sqrt(Lline*Cline)) speed in [km/s], Cline in [F/km], Lline in [H/km]      ';
'                    The computed value must be inferior to the speed of light (~3e+5 km/s)             ';
'                    and must be reasonably high for coherent computing of the equivalent pi            ';
'                    model parameters. The lower limit is set to  the speed of light                   ';
'                    Adjust inductance and capacitance parameters to fall in this range                 ';
'                    of speed to run Netsim.                                                            ';  
'                    Exemple: L=1e-3H/km C=5e-8F/km -> speed=2.23e+5 km/s                               ';];

str13=[
'Error: "/" caracter found in block name                                            ';
'                                                                                   ';
'Suggestion: Remove "/" caracters from block names                                  ';];

%% erreur 14 n'est plus une erreur
str14=[
'Error: No RLC or source componants found in network                                ';
'                                                                                   ';
'Suggestion: Use netsim to analyse Simulink window constructed with EPDS blocs      ';];

%% erreur 15
str15=[
'Error: Purely capacitive block short-circuited                                     ';
'                                                                                   ';
'Suggestion: add a small resistance or inductance in the short-circuit path         ';];
  

% construct different windows for warnings and errors 
if command==0	% case for Warnings
	posit=[173 557 732 200];
	winname='Netsim WARNING window';
elseif command==1		% case for ERRORS
	posit=[173 326 732 200];
	winname='Netsim  ERROR  window';
elseif command==2
	posit=[173 95 732 200]; %case for suggestions
	winname='Netsim suggestion window';		
end

SHOW=8;

% suggestion string

if command==2&errno~=99
	eval(['str=str' num2str(errno) ';']);
end
 
if command==0 | command==1 | command==2

	fig = figure('position',posit,... 
		'resize','on',...
		'menu','none',... 
		'numbertitle','off',...
		'Color',[0.7 0.7 0.7], ...
		'name',winname,'visible','off');

	suggestcommand=['nserrwin(2,0,0,' num2str(errno) ')' ];

	%  Uicontrol Object Creation

 	b1 = uicontrol(...
		'Parent',fig,... 
 		'Max',[ 10 ],...
		'FontSize',[14],... 
		'Units','normalized',... 
		'Position',[ 0.01 0.30 0.98 0.69 ],... 
 		'String',str(1:min([SHOW size(str,1)]),:),...
		'Style','edit',...
		'BackGroundColor',[0.8 0.8 0.8],...
		'HorizontalAlignment','left',... 
 		'UserData',str);
 
	b2 = uicontrol(... 
		'Parent',fig,...
		'Units','normalized',...  
 		'Position',[ 0.01 0.04 0.98 0.25 ],... 
		'Style','frame',... 
		'Tag','b2',... 
		'UserData','');

	s1=1;
	if size(str,1)>SHOW   %add the slider
		 
		sliderposition=-1;
		s1 = uicontrol(... 
			'Parent',fig,... 
			'CallBack','nserrwin(3,0,0,0)',... 
			'Max', -1,... 
			'Min', 0-size(str,1)+SHOW-1,...
			'Units','normalized',...  
			'Position',[ 0.97 0.30 0.02 0.69 ],... 
			'Value',sliderposition,... 
			'Style','slider',...
			'Tag','h_slider1',... 
			'UserData',sliderposition);
	end 
 
    if command==1
	b4 = uicontrol(... 
		'Parent',fig,... 
		'CallBack',suggestcommand,...
		'Units','normalized',...  
		'Position',[ 0.24 0.09 0.20 0.15 ],... 
		'String','SUGGESTIONS',... 
		'Style','pushbutton',... 
		'Tag','b4',... 
		'UserData','');
	OKpos=[ 0.64 0.09 0.11 0.15 ];
    else
	OKpos=[ 0.44 0.09 0.11 0.15 ];
    end
	b3 = uicontrol(... 
		'Parent',fig,... 
		'CallBack','close',...
		'Units','normalized',...  
		'Position',OKpos,... 
		'String','OK',... 
		'Style','pushbutton',... 
		'Tag','b3',... 
		'UserData','');

	set(gcf,'Visible','on','UserData',[s1 b1]);

elseif command==3

	objects=get(gcf,'UserData');
	s1=objects(1);
	b1=objects(2);
 	old_sp=get(s1 ,'UserData');
	str   =get(b1,'UserData');
 	
	new_sp=get(s1,'Value');
	if new_sp>old_sp	%mettre position slider en valeur entiere
				%^& SET SLIDER TO INTEGER VALUE
		sliderposition=ceil(new_sp);
	elseif new_sp<old_sp
		sliderposition=floor(new_sp);
	else
		sliderposition=old_sp;
	end

	set(s1,'Value',sliderposition);    	
	set(s1,'UserData',sliderposition); % sauver donnees	
	set(b1,'String',str((0-sliderposition):(0-sliderposition)+SHOW-1,:) );

else
	;     	 
                                        	 	
end 

% modifcations in GUI, if exist.

gui=get(0,'UserData');
if ~isempty(gui)
  if size(gui)==[1 1]
   set(gui,'Pointer','arrow');
   ingui=get(gui,'UserData');
   message=ingui(6);
   set(message,'String',' ');
  end
end
