function[param,NoeudAlloc]=nsfb09(blocs,lignes,i,Noeuds,NoeudAlloc)
%NSFB09 Block 4 (Mutual inductance) function
% 	Note: Internal netsim function. 
%	May not work properly when used elsewhere.
%
% 	[PARAM,NOEUDALLOC]=NSFB4(BLOCS,LIGNES,I,NOEUDS,NOEUDALLOC)
% 	input arguments:
%		BLOCS: (string matrix) block name matrix
%		LIGNES: (integer matrix) block connection matrix
%		I: index of the block in BLOCS
%		NOEUDS: (integer vector) node assignment
%		NOEUDALLOC: (integer) node number for allocation
% 	output arguments:
%		PARAM: (float matrix) parameters of the block in the
%	               format required by ETATFUN
%		NOEUDALLOC: (integer) node number for allocation
%		format of PARAM (all line expect the last one):
%			PARAM(1): input node of coil
%			PARAM(2): output node of coil
%			PARAM(3): =3 for mutual componant
%			PARAM(4): value of R in ohms
%			PARAM(5): value of L in mH
%			PARAM(6): =0 
%			PARAM(7): I
%			PARAM(8): coil number
%
%		format of PARAM (last line only):
%			PARAM(1): input node of core 
%			PARAM(2): output node of core
%			PARAM(3): =0 for serial RL
%			PARAM(4): value of R in ohms
%			PARAM(5): value of L in mH
%			PARAM(6): =0 
%			PARAM(7): I
%			PARAM(8): total coil number +1
%
%	See also ETATFUN.
	
%   Christian Dufour 11-22-95 , Patrice Brunelle 04-17-96
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.2 $

% ETATFUN'S RLC MATRIX CONTRIBUTION BY 'Mutual inductance' BLOCK

% on considere que l'entree 1 et la sortie 1 sont la self primaire
% et l'entree 2 et la sortie 2 sont la self secondaire
% et l'entree 3 et la sortie 3 sont la self tertiaire si presente
%^& 1ST INPUT & OUTPUT: PRIMARY SELF
%^& 2E INPUT & OUTPUT: SECONDARY SELF
%^& 3E INPUT & OUTPUT: 3E SELF IF ANY


TYPE=3;
str=get_param(nsdezero(blocs(i,:)),'Mask Entries');
retvar=nsparm(str,nsdezero(blocs(i,:)));
brpri=retvar{1};
brsec=retvar{2};
brter=retvar{3};
brmutu=retvar{4};
  
% NOTE: format choisi pour brpri,brsec,brter,brmutu
% 	[R(ohms),L(H)]
%^& CHOSEN FORMAT FOR R L INPUTS
%^& [R(ohms),L(H)]

 
 

% determination du nombre d'enroulement a partir du vecteur
%^& DETERMINATION OF NUMBER OF COILS 
if brter(1)<1000*eps;
 	ncoils=2;
else
	ncoils=3;
end

 
 	
neup1=NaN;	% noeud d'entree du primaire
		%^& INPUT NODE 1ST COIL
neup2=NaN;	% noeud de sortie du primaire
		%^& OUTPUT NODE 1ST COIL
neus1=NaN;	%^& INPUT NODE 2ND COIL
neus2=NaN;	%^& OUTPUT NODE 2ND COIL
neut1=NaN;	%^& INPUT NODE 3RD COIL
neut2=NaN;	%^& OUTPUT NODE 3RD COIL

 
for j=1:size(lignes,1)
	if ( lignes(j,3)==i & lignes(j,4)==1)
		neup1=Noeuds(j);
	end
	if ( lignes(j,3)==i & lignes(j,4)==2)
		neus1=Noeuds(j);
	end
	if ( lignes(j,3)==i & lignes(j,4)==3)
		neut1=Noeuds(j);
	end

	if ( lignes(j,1)==i & lignes(j,2)==1)
		neup2=Noeuds(j);
	end
	if ( lignes(j,1)==i & lignes(j,2)==2)
		neus2=Noeuds(j);
	end
	if ( lignes(j,1)==i & lignes(j,2)==3)
		neut2=Noeuds(j);
	end

end


% allocation du noeud neup2 si non-branche
%^& neup2 ALLOCATION IF NOT ALREADY MADE
if  isnan(neup2)  
	neup2=NoeudAlloc;
	NoeudAlloc=NoeudAlloc+1;
end

%% adaptation selon orientation de l'icone:
n1=neup1;
n2=neup2;
n3=neus1;
n4=neus2;
n5=neut1;
n6=neut2;
o=get_param(nsdezero(blocs(i,:)),'Orientation');
if strcmp(o,'down')|strcmp(o,'left')
	neup1=n2;
	neup2=n1;
	if ncoils==2
		neus1=n4;
		neus2=n3;
	else
		neus1=n6;
		neus2=n5;
		neut1=n4;
		neut2=n3;
	end
end
%%

  
k=1;
R=brpri(1);
L=brpri(2)*1e3;
param(k,:)=[neup1 neup2 TYPE  R L 0 i 1];
k=2;
R=brsec(1);
L=brsec(2)*1e3; 
param(k,:)=[neus1 neus2 TYPE  R L 0 i 2];
 

if ncoils==3
	k=3;
	R=brter(1);
	L=brter(2)*1e3;
	param(k,:)=[neut1 neut2 TYPE  R L 0 i 3];
	 
end


% derniere ligne: mutuelle
%^& LAST 'rlc' LINE: MUTUAL INDUCTANCE ITSELF (SERIAL RL BRANCH)
 
R=brmutu(1); 
L=brmutu(2)*1e3;
param(ncoils+1,:)=[NoeudAlloc neup2  0  R L 0 i 4];
 
NoeudAlloc=NoeudAlloc+1;



