function[param,NoeudAlloc]=nsfb10(blocs,lignes,i,Noeuds,NoeudAlloc)
%NSFB10 Block 5 (Linear transformer) function
% 	Note: Internal netsim function. 
%	May not work properly when used elsewhere.
%
% 	[PARAM,NOEUDALLOC]=NSFB10(BLOCS,LIGNES,I,NOEUDS,NOEUDALLOC)
% 	input arguments:
%		BLOCS: (string matrix) block name matrix
%		LIGNES: (integer matrix) block connection matrix
%		I: index of the block in BLOCS
%		NOEUDS: (integer vector) node assignment
%		NOEUDALLOC: (integer) node number for node allocation
% 	output arguments:
%		PARAM: (float matrix) parameters of the block in the
%	               format required by ETATFUN
%		NOEUDALLOC: (integer) node number for allocation
%		format of PARAM (all line expect the last one):
%			PARAM(1): input node of coil
%			PARAM(2): output node of coil
%			PARAM(3): =2 for transformer componant
%			PARAM(4): value of R in ohms
%			PARAM(5): value of L in mH
%			PARAM(6): nominal voltage of the coil 
%			PARAM(7): I
%			PARAM(8): coil number
%
%		format of PARAM (last line only):
%			PARAM(1): input node of core 
%			PARAM(2): output node of core
%			PARAM(3): =1 for parallel RL
%			PARAM(4): value of R in ohms
%			PARAM(5): value of L in mH
%			PARAM(6): =0 
%			PARAM(7): I
%			PARAM(8): total coil number +1
%
%	See also ETATFUN.
	
%   Christian Dufour 11-22-95, Patrice Brunelle 26-02-97
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.2 $

% ETATFUN'S RLC MATRIX CONTRIBUTION BY 'Linear transformer' BLOCK

% on considere que le bloc a deux entrees qui correspondent
% au primaire et a 2 ou 4 sorties qui correspondent aux enroulements
% secondaire
%^& BLOCK INPUT #1,#2 : 1ST WINDING
%^& BLOCK OUTPUT #1,#2 : 2ND WINDING
%^& BLOCK OUTP #3,#4 (IF PRESENT) :3RD WINDING
 
TYPE=2;
str=get_param(nsdezero(blocs(i,:)),'Mask Entries');
retvar=nsparm(str,nsdezero(blocs(i,:)));
Pnomfreq=retvar{1};
bpri=retvar{2};
bsec1=retvar{3};
bsec2=retvar{4};
bmag=retvar{5};

% NOTE: format choisi pour bpri,bsec1,bsec2
% 	[Vnom(V),R(pu),X(pu)]
%	format choisi pour bmag
% 	[R(pu),X(pu)]
%^& ALL RESISTANCE & REACTANCE IN PU UNITS

Pnom=Pnomfreq(1);
freq=Pnomfreq(2);
 

%^& DETERMINATION OF NUMBER OF COILS
% determination du nombre d'enroulement a partir du vecteur 
if bsec2(1)<1000*eps;
 	ncoils=2;
else
	ncoils=3;
end

 	
neup1=NaN;	% INPUT NODE 1ST COIL
neup2=NaN;	% OUTPUT NODE 1ST COIL
neus1=NaN;	% INPUT NODE 2E COIL
neus2=NaN;	% OUTPUT NODE 2E COIL
neut1=NaN;	% INPUT NODE 3E COIL
neut2=NaN;	% OUTPUT NODE 3E COIL

for j=1:size(lignes,1)
	if ( lignes(j,3)==i & lignes(j,4)==1)
		neup1=Noeuds(j);
	end
	if ( lignes(j,3)==i & lignes(j,4)==2)
		neup2=Noeuds(j);
	end
	if ( lignes(j,1)==i & lignes(j,2)==1)
		neus1=Noeuds(j);
	end
	if ( lignes(j,1)==i & lignes(j,2)==2)
		neus2=Noeuds(j);
	end
	if ( lignes(j,1)==i & lignes(j,2)==3)
		neut1=Noeuds(j);
	end
	if ( lignes(j,1)==i & lignes(j,2)==4)
		neut2=Noeuds(j);
	end

end

%^& neup2 ALLOCATION IF NOT ALREADY MADE  
% allocation du noeud neup2 si non-branche
if  isnan(neup2)  
	neup2=NoeudAlloc;
	NoeudAlloc=NoeudAlloc+1;
end

 
%Pb=VbIb
%Rb=Vb/Ib=Vb^2/Pb
k=1;
Vbase2=bpri(1)^2;
R=bpri(2)*Vbase2/Pnom;
L=bpri(3)*Vbase2/Pnom/(2*pi*freq)*1e3; 
param(k,:)=[neup1 neup2 TYPE  R L bpri(1) i 1];
k=2;
Vbase2=bsec1(1)^2;
R=bsec1(2)*Vbase2/Pnom;
L=bsec1(3)*Vbase2/Pnom/(2*pi*freq)*1e3;
param(k,:)=[neus1 neus2 TYPE  R L bsec1(1) i 2];
 

if ncoils==3
	k=3;
	Vbase2=bsec2(1)^2;
	R=bsec2(2)*Vbase2/Pnom;
	L=bsec2(3)*Vbase2/Pnom/(2*pi*freq)*1e3;
	param(k,:)=[neut1 neut2 TYPE  R L bsec2(1) i 3];
	 
end

% derniere ligne: branche magnetisation
%^& LAST 'rlc' LINE: MAGNETISATION BRANCH (PARALLEL RL BRANCH)

Vbase2=bpri(1)^2;
R=bmag(1)*Vbase2/Pnom;
L=bmag(2)*Vbase2/Pnom/(2*pi*freq)*1e3;
if L==inf
	L=0;
end
param(ncoils+1,:)=[NoeudAlloc neup2 1  R L 0 i 4];
 
NoeudAlloc=NoeudAlloc+1;

