function[param,param_src,str,NoeudAlloc,ParamNumber]=nsfb11(blocs,lignes,i,Noeuds,NoeudAlloc,nb_sortie,rlc,ParamNumber,flagLin)
%NSFB11 Block 6 (Saturated transformer) function
% 	Note: Internal netsim function. 
%	May not work properly when used elsewhere.
%
% 	[PARAM,PARAM_SRC,STR,NOEUDALLOC,PARAMNUMBER]=NSFB11(BLOCS,LIGNES,I, ... 
%	NOEUDS,NOEUDALLOC,NB_SORTIE,RLC,PARAMNUMBER,FLAGLIN)
% 	input arguments:
%		BLOCS: (string matrix) block name matrix
%		LIGNES: (integer matrix) block connection matrix
%		I: index of the block in BLOCS
%		NOEUDS: (integer vector) node assignment
%		NOEUDALLOC: (integer) node number for allocation
%		NB_SORTIE: (integer) output number in the equiv. state-space
%		           system for the block
%		RLC: (float matrix) rlc matrix for ETATFUN
%		PARAMNUMBER: (integer vector) Blocks special parameter vector
%		FLAGLIN: (integer)
%		         =1: computation of linear part of block
%		         i.e. only PARAM is computed. PARAMNUMBER is modified
%			 to memorize the core node number
%		         =0: computation of non-linear part of block
%		         i.e. only PARAM_SRC and STR are computed		
% 	output arguments:
%		PARAM: (float matrix) RLC parameters of the block in the
%	               format required by ETATFUN
%		PARAM_SRC:(float vector) current source parametres in the
%	               format required by ETATFUN
%		STR: (char vector) voltage output string parameters in the
%	               format required by ETATFUN
%		NOEUDALLOC: (integer) node number for allocation
%		PARAMNUMBER: (integer vector) Blocks special parameter vector
%		format of PARAM (all line expect the last one):
%			PARAM(1): input node of coil
%			PARAM(2): output node of coil
%			PARAM(3): =2 for transformer componant
%			PARAM(4): value of R in ohms
%			PARAM(5): value of L in mH
%			PARAM(6): nominal voltage of the coil 
%			PARAM(7): I
%			PARAM(8): coil number
%
%		format of PARAM (last line only):
%			PARAM(1): input node of core 
%			PARAM(2): output node of core
%			PARAM(3): =1 for R
%			PARAM(4): value of R in ohms
%			PARAM(5): =0 (non-linear element)
%			PARAM(6): =0 
%			PARAM(7): I
%			PARAM(8): total coil number +1
%
%	See also ETATFUN.
	
%   Christian Dufour 11-22-95 , Patrice Brunelle 04-17-96
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.2 $
%
% 10-12-95 Allocation of neup2 if necessary   

% Ecriture des lignes de la matrice rlc correspondant
% a un bloc de type 'Saturated transformer'
%^& ETATFUN'S RLC MATRIX CONTRIBUTION BY 'Saturable transformer' BLOCK

% on considere que le bloc a deux entrees qui correspondent
% au primaire et a 2 ou 4 sorties qui correspondent aux enroulements
% secondaire
%^& BLOCK INPUT #1,#2 : 1ST WINDING
%^& BLOCK OUTPUT #1,#2 : 2ND WINDING
%^& BLOCK OUTP #3,#4 (IF PRESENT) :3RD WINDING

param=[];param_src=[];str=[];

if flagLin==1
 
  TYPE=2;
  str=get_param(nsdezero(blocs(i,:)),'Mask Entries');
  retvar=nsparm(str,nsdezero(blocs(i,:)));
  Pnfn=retvar{1};
  bpri=retvar{2};
  bsec=retvar{3};
  bter=retvar{4};
  isatphisat=retvar{5};
  RmagPhiinit=retvar{6};
  Pnom = Pnfn(1);
  freq = Pnfn(2);
  Rmag = RmagPhiinit(1);


  % NOTE: format choisi pour bpri,bsec,bter
  % 	[Vnom(V),R(pu),X(pu)]
  %	format choisi pour bmag
  % 	[R(pu),X(pu)]
  %^& ALL RESISTANCE & REACTANCE IN PU UNITS

 
  %^& DETERMINATION OF NUMBER OF COILS
  % determination du nombre d'enroulement a partir du vecteur 
  if bter(1)<1000*eps;
   	ncoils=2;
  else
	ncoils=3;
  end

 	
  neup1=NaN;	% noeud d'entree du primaire
		%^& INPUT NODE 1ST COIL
  neup2=NaN;	% noeud de sortie du primaire
		%^& OUTPUT NODE 1ST COIL
  neus1=NaN;	%^& INPUT NODE 2E COIL
  neus2=NaN;	%^& OUTPUT NODE 2E COIL
  neut1=NaN;	%^& INPUT NODE 3E COIL
  neut2=NaN;	%^& OUTPUT NODE 3E COIL


  for j=1:size(lignes,1)
	if ( lignes(j,3)==i & lignes(j,4)==1)
		neup1=Noeuds(j);
	end
	if ( lignes(j,3)==i & lignes(j,4)==2)
		neup2=Noeuds(j);
	end
	if ( lignes(j,1)==i & lignes(j,2)==1)
		neus1=Noeuds(j);
	end
	if ( lignes(j,1)==i & lignes(j,2)==2)
		neus2=Noeuds(j);
	end
	if ( lignes(j,1)==i & lignes(j,2)==3)
		neut1=Noeuds(j);
	end
	if ( lignes(j,1)==i & lignes(j,2)==4)
		neut2=Noeuds(j);
	end

  end

%^& neup2 ALLOCATION IF NOT ALREADY MADE  
  % allocation du noeud neup2 si non-branche
  if  isnan(neup2)  
	neup2=NoeudAlloc;
	NoeudAlloc=NoeudAlloc+1;
  end



  %Pb=VbIb
  %Rb=Vb/Ib=Vb^2/Pb
  k=1;
  R=bpri(2)*(bpri(1)^2)/Pnom;
  L=bpri(3)*(bpri(1)^2)/Pnom/(2*pi*freq)*1e3; 
  param(k,:)=[neup1 neup2 TYPE  R L bpri(1) i 1];
  k=2;
  R=bsec(2)*(bsec(1)^2)/Pnom;
  L=bsec(3)*(bsec(1)^2)/Pnom/(2*pi*freq)*1e3;
  param(k,:)=[neus1 neus2 TYPE  R L bsec(1) i 2];
   

  if ncoils==3
	k=3;
	R=bter(2)*(bter(1)^2)/Pnom;
	L=bter(3)*(bter(1)^2)/Pnom/(2*pi*freq)*1e3;
	param(k,:)=[neut1 neut2 TYPE  R L bter(1) i 3];
  end

  % derniere ligne: branche magnetisation
  R=Rmag(1)*(bpri(1)^2)/Pnom;
  neustar=NoeudAlloc;
  NoeudAlloc=NoeudAlloc+1;
  param(ncoils+1,:)=[neustar neup2 1  R 0 0 i 4];
  ParamNumber(i)=size(rlc,1)+ncoils+1;  % ParamNumber(i)(TransfoSat):indice dans
 					% rlc de la branche perte Fer
  str=[];
  source=[];

else    
  param=[];
  % recherche des noeuds
  %^& NODE RETRIVAL
  neup2=rlc(ParamNumber(i),2);
  neustar=rlc(ParamNumber(i),1);

  param_src=[neustar neup2 1 0 0 0 14];

  % specification de lecture de tension
  %^& VOLTAGE OUTPUT REQUEST
  str=['y_u' num2str(nb_sortie+1) '=' '''' 'U_n' num2str(neustar)  '_'      num2str(neup2) ''''  ';' ];

end


