function[str,capteurnoeuds,NoeudAlloc]=nsfb18(blocs,lignes,i,Noeuds,CustomBlocNumber,nb_sortie,BrancheREF,rlc,source,NoeudAlloc)
%NSFB18 Block 10 (Current sensor version Shunt) function
% 	Note: Internal netsim function. 
%	May not work properly when used elsewhere.
%
% 	[STR,CAPTEURNOEUDS,NOEUDALLOC]=NSFB18(BLOCS,LIGNES,I,NOEUDS, ...
%	CUSTOMBLOCNUMBER,NB_SORTIE,BRANCHEREF,RLC,SOURCE,NOEUDALLOC)
% 	input arguments:
%		BLOCS: (string matrix) block name matrix
%		LIGNES: (integer matrix) block connection matrix
%		I: index of the block in BLOCS
%		NOEUDS: (integer vector) node assignment
%		CUSTOMBLOCNUMBER: (integer vector) Toolbox block identification 
%				                   number
%		NB_SORTIE: (integer) output number in the equiv. state-space
%		           system for the block
%		BRANCHEREF: (integer matrix) 
%			1 col.: number indicating the block number from which
%			        comes the rlc componant
%			        ex: the 5th line of RLC matrix comes from
%			        the block BRANCHEREF(5,1)
%			2 col.: special number for blocks which produces
%			        more than 1 RLC line
%		RLC: (float matrix) ETATFUN rlc componant matrix
%		SOURCE: (float matrix) ETATFUN source componant matrix
%		NOEUDALLOC: (integer) node number for allocation
% 	output arguments:
%		STR: (char vector) voltage output string parameters in the
%	               format required by ETATFUN
%		CAPTEURNOEUDS: (integer vector) nodes at which the current
%		               sensor is connected. Those nodes will be fused
%                               together in an other function.
%		NOEUDALLOC: (integer) node number for allocation
% 
%	See also ETATFUN.
	
%   Christian Dufour 11-28-95, Patrice Brunelle 26-02-97
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.2 $
 
neuin=NaN;	% noeud d'entree du capteur
		%^& INPUT NODE		
neuout=NaN;	% noeud de sortie du capteur
		%^& OUTPUT NODE

capteurnoeuds=[];

% trouver les noeuds ou le senseur est connecte
%^& FIND NODES WHERE SENSOR IS CONNECTED


for j=1:size(lignes,1)
 	if ( lignes(j,3)==i )		
		neuin=Noeuds(j); 
	end
	if ( lignes(j,1)==i )
		if (lignes(j,2)==2)
			neuout=Noeuds(j);
		end
	end		
end


% verifier si le senseur est bien connecte
%^& ALLOCATE NODE IF NECESSARY
if isnan(neuin)
	neuin=NoeudAlloc;
	NoeudAlloc=NoeudAlloc+1;
end
if isnan(neuout)
	neuin=NoeudAlloc;
	NoeudAlloc=NoeudAlloc+1;
end


	


capteurnoeuds=[min([neuin neuout]) max([neuin neuout])];


Noeudsback=Noeuds;
rlcback=rlc;
sourceback=source;

% fusionner les noeuds separes par des sources tensions type 11 
% (impedance nulle)
%^& FUSE NODES SEPARATED BY VOLTAGE SOURCES 
%^& (VOLTAGE SOURCES HAVE NULL IMPEDANCE)
neu=[NaN NaN];
 
for j=1:size(source,1)
	if source(j,3)==0
		neu=source(j,1:2);
 		newneu=min(neu);
		oldneu=max(neu);
  		% changer les no de noeuds dans 'source'
		%^& CHANGE NODE NUMBER IN 'source'
		for k=1:size(source,1)
			if source(k,1)==oldneu
				source(k,1)=newneu;
			end
			if source(k,2)==oldneu
				source(k,2)=newneu;
			end
		end
		% inverser les no de noeuds de la source
		% de facon a les reconnaitre plus tard
		%^& MARK 'source' LINES FOR LATER USE
		source(j,1)=0-source(j,1);
		source(j,2)=0-source(j,2);

		% changer les no de noeuds dans 'rlc'
		%^& CHANGE 'rlc' NODE NUMBER
		for k=1:size(rlc,1)
			if rlc(k,1)==oldneu
				rlc(k,1)=newneu;
			end
			if rlc(k,2)==oldneu
				rlc(k,2)=newneu;
			end
		end

		% changer les no de noeuds dans 'Noeuds' aussi
		%^& CHANGE 'Noeuds' ALSO
		for k=1:length(Noeuds)
			if Noeuds(k)==oldneu
				Noeuds(k)=newneu;
			end
 		end

	end 
end

% fusionner les noeuds separes par les capteurs de courants
% a l'exeption de celui-ci (impedance nulle)
%^& FUSE NODE SEPARATED BY CURRENT SENSORS
%^& EXCEPT THIS ONE
neu=[NaN NaN];
for j=1:size(blocs,1)
	if CustomBlocNumber(j)==10
	    if j~=i	
		for k=1:size(lignes,1)
			if ( lignes(k,1)==j & lignes(k,2)==2)
				neu(1)=Noeuds(k);
			end
			if ( lignes(k,3)==j & lignes(k,4)==1)
				neu(2)=Noeuds(k);
			end
		end
		newneu=min(neu);
		oldneu=max(neu);
		if isnan(newneu)==1
			% si un des Noeuds est NaN
			% pas de changement des numero de noeuds a faire
			%^& UNCONNECTED SENSOR: NO CHANGE
		    ;
 		else
 			% changer les no de noeuds dans 'source'
			%^& CHANGE 'source' NODE ENTRIES
			for k=1:size(source,1)
				if source(k,1)==oldneu
					source(k,1)=newneu;
				end
				if source(k,2)==oldneu
					source(k,2)=newneu;
				end
			end
			% changer les no de noeuds dans 'rlc'
			%^& CHANGE 'rlc' NODE ENTRIES
			for k=1:size(rlc,1)
				if rlc(k,1)==oldneu
					rlc(k,1)=newneu;
				end
				if rlc(k,2)==oldneu
					rlc(k,2)=newneu;
				end
			end
			% changer les no de noeuds dans Noeuds aussi
			%^& CHANGE 'Noeuds' NODE ENTRIES
			for k=1:length(Noeuds)
				if Noeuds(k)==oldneu
					Noeuds(k)=newneu;
				end
 			end		
		end
	    end
	end 
end

 


neuin=NaN;	% noeud d'entree du capteur
neuout=NaN;	% noeud de sortie du capteur

% trouver les noeuds ou le senseur est connecte apres fusion 
%^& FIND SENSOR NODES AFTER FUSION

for j=1:size(lignes,1)
 	if ( lignes(j,3)==i )		
		neuin=Noeuds(j); 
	end
	if ( lignes(j,1)==i )
		if (lignes(j,2)==2)
			neuout=Noeuds(j);
		end
	end		
end
% verifier si le capteur n'est pas shorte
%^& CHECK IF SENSOR IS NOT SHORTED
 
if neuin==0 & neuout==0
 	str=['y_i' num2str(nb_sortie+1) '=' '''' 'I_b-2'   '''' ';'];
 	return;
end

if neuin==neuout
 	str=['y_i' num2str(nb_sortie+1) '=' '''' 'I_b-1'   '''' ';'];
 	return;
end

if isempty(source)
	source1=[];
	source2=[];
else
	source1=source(:,1);
	source2=source(:,2);
end
	

if isempty(rlc)
	rlc1=[];
	rlc2=[];
else
	rlc1=rlc(:,1);
	rlc2=rlc(:,2);
end


listnoeud=[rlc1' rlc2' source1' source2'];

% verifier si le capteur est branche a des noeuds electriques
%^& CHECK IF SENSOR IS CONNECTED TO ELECTRICAL NODES

if isempty(find(listnoeud==neuin))
 	str=['y_i' num2str(nb_sortie+1) '=' '''' 'I_b-3'  ''''  ';'];
 	return;
end

if isempty(find(listnoeud==neuout))
 	str=['y_i' num2str(nb_sortie+1) '=' '''' 'I_b-4'   '''' ';'];
 	return;	
end

	

% choisir le cote du capteur ou le moins d'elements sont branches
%^& CHOOSE SENSOR SIDE WHICH HAVE THE MINIMUM NUMBER OF ELEMENTS CONNECTED TO IT

cotein=0;
coteout=0;

if ~isempty(rlc1)
    cotein=length(find(rlc1==neuin))+length(find(rlc2==neuin));
    coteout=length(find(rlc1==neuout))+length(find(rlc2==neuout));
end

if ~isempty(source1)
    cotein=cotein+length(find(source1==neuin))+length(find(source2==neuin));
    coteout=coteout+length(find(source1==neuout))+length(find(source2==neuout));
end
  
if neuout~=0 & neuin==0
 	capcote='+';	% cote sortie choisi
			%^& OUTPUT SIDE CHOSEN
	capneu=neuout;
elseif neuout==0 & neuin~=0
	capcote='-';	% cote entree choisi
			%^& INPUT SIDE CHOSEN
	capneu=neuin;
elseif coteout>=cotein
	capcote='-';
	capneu=neuin;
elseif coteout<cotein
 	capcote='+';
	capneu=neuout;
else
	error('nsfb18 err:1');
	% cas neuin==neuout==0 deja teste!
end


%%%ecriture de la string de sortie pour etat
%^& OUTPUT STRING FOR etatfun.m
str=['y_i' num2str(nb_sortie+1) '=' ''''];
% contribution de rlc
%^& 'rlc' CONTRIBUTION
for j=1:size(rlc,1)
	if rlc(j,1)==capneu	
 		if capcote=='+'	
			str=[str '+I_b' num2str(j)];
		else
			str=[str '-I_b' num2str(j)];
		end
	end
	if rlc(j,2)==capneu
		if j==1 | rlc(j,3)==2 | rlc(j,3)==3
 		   	if capcote=='+'	
			  	str=[str '-I_b' num2str(j)];
		   	else
			  	str=[str '+I_b' num2str(j)];
		   	end
		else
	    		if (rlc(j-1,3)==2 | rlc(j-1,3)==3)	
						% ne pas considerer les branches magnetisante
						% des transfo et mutuelle
						%^& DON'T CONSIDER MAGNETISATION BRANCHES
				;
	   		else
		   		if capcote=='+'	
			  		str=[str '-I_b' num2str(j)];
		   		else
			  		str=[str '+I_b' num2str(j)];
		   		end
			end
 	    	end
	end
end
% Inclusion des sources courants dans la string de sortie
%^& 'source' CONTRIBUTION
for j=1:size(source,1)
	if source(j,1)==capneu
		if source(j,3)==1
			if capcote=='+'
				str=[str '+I' num2str(j)];
			end
			if capcote=='-'
				str=[str '-I' num2str(j)];
			end
		end
	end
	if source(j,2)==capneu
		if source(j,3)==1
			if capcote=='+'
				str=[str '-I' num2str(j)];
			end
			if capcote=='-'
				str=[str '+I' num2str(j)];
			end
		end
	end
end

% terminaison de la string de sortie
%^& LAST CONTRIBUTION TO OUTPUT STRING
spc5='     ';
str=[str spc5 ''''  ';' ]; %modif 28/11/95 ajout de 5 space char
 
