function[param,param_src,param_other,NoeudAlloc]= ...
		nsfb19(blocs,lignes,i,Noeuds,NoeudAlloc,rlc,flagLin)
%NSFB19 Block (Diode) function
% 	Note: Internal netsim function. 
%	May not work properly when used elsewhere.
%
% 	[PARAM_SRC,NOEUDALLOC]=NSFB19(BLOCS,LIGNES,I,NOEUDS,NOEUDALLOC)
% 	input arguments:
%		BLOCS: (string matrix) block name matrix
%		LIGNES: (integer matrix) block connection matrix
%		I: index of the block in BLOCS
%		NOEUDS: (integer vector) node assignment
%		NOEUDALLOC: (integer) node number for node allocation 
% 	output arguments:
%		PARAM_SRC: (float vector) parameters of the block in the
%	               format required by ETATFUN 
%		NOEUDALLOC: (integer) node number for node allocation 		
%		format of PARAM_SRC :
%			PARAM_SRC(1): anode (+) (input) node of diode 
%			PARAM_SRC(2): cathode (-) (output) node of diode 
%			PARAM_SRC(3): =1 for current source
%			PARAM_SRC(4): =0 
%			PARAM_SRC(5): =0 
%			PARAM_SRC(6): =0 
%
%	See also ETATFUN.
	
%   Christian Dufour 11-22-95 , Patrice Brunelle 06-17-96
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.2 $

param=[];param_src=[];param_other=[];

if flagLin==1
	neuin=NaN;	
	neuout=NaN;
	neumes=NaN;	
	TYPE=0;
	% read snubber values :
	str=get_param(nsdezero(blocs(i,:)),'Mask Entries');
	retvar=nsparm(str,nsdezero(blocs(i,:)));
	RC=[retvar{5},retvar{6}];

	if RC(1)==inf,RC=[0,0];end   % no snubber
	if RC(2)==0,  RC=[0,0];end   % no snubber
	if RC(2)==inf,RC(2)=0 ;end;  

	if sum(RC)>0 % snubber exist
		for j=1:size(lignes,1)
 			if ( lignes(j,3)==i & lignes(j,4)==1 )
				neuin=Noeuds(j);		
			end
 			if ( lignes(j,1)==i & lignes(j,2)==1 )
				neuout=Noeuds(j);		
			end
		end
		if isnan(neuin) 
			neuin=NoeudAlloc;
			NoeudAlloc=NoeudAlloc+1;
		end
		if isnan(neuout) 
			neuout=NoeudAlloc;
			NoeudAlloc=NoeudAlloc+1;
		end
    		param=[	neuin neuout TYPE RC(1) 0 RC(2)*1e6 i 0];
	else
		param=[];
	end

else
	neumes=NaN;
	for j=1:size(lignes,1)
		if ( lignes(j,1)==i & lignes(j,2)==2 )
			neumes=Noeuds(j);		
		end
	end
	if isnan(neumes) 
		neumes=NoeudAlloc;
		NoeudAlloc=NoeudAlloc+1;
	end	
	param_other=[neumes i 2 2];

	str=get_param(nsdezero(blocs(i,:)),'Mask Entries');
	retvar=nsparm(str,nsdezero(blocs(i,:)));
	condit=retvar{4};
	R=retvar{1};
	L=retvar{2};

	loc=find(rlc(:,7)==i);
	if ~isempty(loc)  % Noeuds deja alloues
		neuin=rlc(loc,1);
		neuout=rlc(loc,2);
		param_src=[neuin neuout 0 R L*1e3 0 condit];
	else	   % pas de snubber: noeuds non-alloues
		for j=1:size(lignes,1)
 			if ( lignes(j,3)==i & lignes(j,4)==1 )
				neuin=Noeuds(j);		
			end
  			if ( lignes(j,1)==i & lignes(j,2)==1 )
				neuout=Noeuds(j);		
			end
		end
		if isnan(neuin) 
			neuin=NoeudAlloc;
			NoeudAlloc=NoeudAlloc+1;
		end
		if isnan(neuout) 
			neuout=NoeudAlloc;
			NoeudAlloc=NoeudAlloc+1;
		end
 		param_src=[neuin neuout 0 R L*1e3 0 condit];
	end
end
