 function[param_src,other,NoeudAlloc,type]=nsfb24(blocs,lignes,i,Noeuds,NoeudAlloc)
%NSFB24 Block 16 (Simplified alternator) function
% 	Note: Internal netsim function. 
%	May not work properly when used elsewhere.
%
% 	[PARAM_SRC,OTHER,NOEUDALLOC,TYPE]=NSFB24(BLOCS,LIGNES,I,NOEUDS,NOEUDALLOC)
% 	input arguments:
%		BLOCS: (string matrix) block name matrix
%		LIGNES: (integer matrix) block connection matrix
%		I: index of the block in BLOCS
%		NOEUDS: (integer vector) node assignment
%		NOEUDALLOC: (integer) node number for node allocation 
% 	output arguments:
%		PARAM_SRC: (float matrix) parameters of the block in the
%	               format required by ETATFUN
%		OTHER: (float matrix) parameters of simulink input/output
%		NOEUDALLOC: (integer) node number for node allocation 		
%		format of PARAM_SRC (each line):
%			PARAM_SRC(1): Ua, Ub
%			PARAM_SRC(2): Ub, Uc
%			PARAM_SRC(3): =1 for current source
%			PARAM_SRC(4): =0 
%			PARAM_SRC(5): =0 
%			PARAM_SRC(6): =0 
%		format of OTHER (each line):
%			OTHER(1): node number
%			OTHER(2): I 
%			OTHER(3): input/output number in block
%			OTHER(4): =1:input  =2:output
%		TYPE: (integer)  0:normal 1:floating neutral
%
%	See also ETATFUN.
	
%   Christian Dufour 11-22-95   Patrice Brunelle 05-17-96
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.2 $

neupower=NaN;
neuvolt=NaN;
neumes=NaN;
neuA=NaN;	 
neuB=NaN;	 
neuC=NaN;	

param_src=[];
n_out=0;


for j=1:size(lignes,1)
 	if ( lignes(j,3)==i & lignes(j,4)==1 )
		neupower=Noeuds(j);		
	end
 
 	if ( lignes(j,3)==i & lignes(j,4)==2 )
		neuvolt=Noeuds(j);		
	end

 	if ( lignes(j,1)==i & lignes(j,2)==1)
		neuA=Noeuds(j);		
	end
 	if ( lignes(j,1)==i & lignes(j,2)==2)
		neuB=Noeuds(j);		
	end
 	if ( lignes(j,1)==i & lignes(j,2)==3)
		neuC=Noeuds(j);		
	end
 	if ( lignes(j,1)==i & lignes(j,2)==4 )
		neumes=Noeuds(j);		
	end
end

if  isnan(neuA) 
	neuA=NoeudAlloc;
	NoeudAlloc=NoeudAlloc+1;
end	
if  isnan(neuB)
	neuB=NoeudAlloc;
	NoeudAlloc=NoeudAlloc+1;
end
if  isnan(neuC)
	neuC=NoeudAlloc;
	NoeudAlloc=NoeudAlloc+1;
end
if  isnan(neupower)
	neupower=NoeudAlloc;
	NoeudAlloc=NoeudAlloc+1;
end
if  isnan(neuvolt)
	neuvolt=NoeudAlloc;
	NoeudAlloc=NoeudAlloc+1;
end
if  isnan(neumes)
	neumes=NoeudAlloc;
	NoeudAlloc=NoeudAlloc+1;
end

% read initial current values ia,ib :

str=get_param(nsdezero(blocs(i,:)),'Mask Entries');
retvar=nsparm(str,nsdezero(blocs(i,:)));
mod=get_param([nsdezero(blocs(i,:)),'/data/type'],'Mask Entries');
line1=retvar{1};
line4=retvar{4};
if mod=='2' %pu
	Pn=line1(1);
	Vn=line1(2);
	ibase=sqrt(2/3)*Pn/Vn;
	Ia0=line4(3)*ibase;
	Ib0=line4(4)*ibase;
else  %SI
	Ia0=line4(3);
	Ib0=line4(4);
end
phiIa0=line4(6);
phiIb0=line4(7);
freq=line1(3);

type=1;
param_src=[ neuC   neuA 1 Ia0 phiIa0 freq 31;
 	    neuC   neuB 1 Ib0 phiIb0 freq 31;];

other=[ neupower i 1 1;
	neuvolt  i 2 1;
	neumes   i 4 2];


