function[param,param_src,param_other,NoeudAlloc]=nsfb32(blocs,lignes,i,Noeuds,NoeudAlloc,rlc,flagLin) 
%NSFB32 Block (Ideal switch) function
% 	Note: Internal netsim function. 
%	May not work properly when used elsewhere.
%
% 	[PARAM,PARAM_SRC,STR,NOEUDALLOC,PARAMNUMBER]=NSFB20(BLOCS,LIGNES,I, ... 
%	NOEUDS,NOEUDALLOC,NB_SORTIE,RLC,PARAMNUMBER,FLAGLIN)
% 	input arguments:
%		BLOCS: (string matrix) block name matrix
%		LIGNES: (integer matrix) block connection matrix
%		I: index of the block in BLOCS
%		NOEUDS: (integer vector) node assignment
%		NOEUDALLOC: (integer) node number for allocation
%		RLC: (float matrix) rlc matrix for ETATFUN
%		FLAGLIN: (integer)
%		         =1: computation of linear part of block
%		         i.e. only PARAM is computed. PARAMNUMBER is modified
%			 to memorize the core node number
%		         =0: computation of non-linear part of block
%		         i.e. only PARAM_SRC and STR are computed		
% 	output arguments:
%		PARAM: (float matrix) RLC parameters of the block in the
%	               format required by ETATFUN
%		PARAM_SRC:(float vector) current source parametres in the
%	               format required by ETATFUN
%		NOEUDALLOC: (integer) node number for allocation
%
%	See also ETATFUN.
	
%   Patrice Brunelle 05-23-96 , 06-17-96 
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.2 $

param=[];param_src=[];param_other=[];

if flagLin==1
	neuin=NaN;	
	neuout=NaN;	
	TYPE=0;
	% read snubber values :
	str=get_param(nsdezero(blocs(i,:)),'Mask Entries');
	retvar=nsparm(str,nsdezero(blocs(i,:)));
	RC=[retvar{4},retvar{5}];

	if RC(1)==inf,RC=[0,0];end   % no snubber
	if RC(2)==0,  RC=[0,0];end   % no snubber
	if RC(2)==inf,RC(2)=0 ;end;  

	if sum(RC)>0 % snubber exist
		for j=1:size(lignes,1)
 			if ( lignes(j,3)==i & lignes(j,4)==1 )
				neuin=Noeuds(j);		
			end
 			if ( lignes(j,1)==i & lignes(j,2)==1 )
				neuout=Noeuds(j);		
			end
		end
		if isnan(neuin) 
			neuin=NoeudAlloc;
			NoeudAlloc=NoeudAlloc+1;
		end
		if isnan(neuout) 
			neuout=NoeudAlloc;
			NoeudAlloc=NoeudAlloc+1;
		end
    		param=[neuin neuout TYPE RC(1) 0 RC(2)*1e6 i 0];
	else
		param=[];
	end
else
	neugachette=NaN;
	neumesure=NaN;
	for j=1:size(lignes,1)
		if ( lignes(j,3)==i & lignes(j,4)==2 )
			neugachette=Noeuds(j);		
		end
		if ( lignes(j,1)==i & lignes(j,3)==2 )
			neumesure=Noeuds(j);		
		end
	end
	if isnan(neugachette) 
		neugachette=NoeudAlloc;
		NoeudAlloc=NoeudAlloc+1;
	end
	if isnan(neumesure) 
		neumesure=NoeudAlloc;
		NoeudAlloc=NoeudAlloc+1;
	end	
	param_other=[neugachette i 2 1; neumesure i 2 2];

	str=get_param(nsdezero(blocs(i,:)),'Mask Entries');
	retvar=nsparm(str,nsdezero(blocs(i,:)));
	condit=retvar{3};
	R=retvar{1};
	L=retvar{2};

	loc=find(rlc(:,7)==i);
	if ~isempty(loc)  % Noeuds deja alloues
		neuin=rlc(loc,1);
		neuout=rlc(loc,2);
		param_src=[neuin neuout condit&1 R L*1e3 0 condit];
	else	   % pas de snubber: noeuds non-alloues
		for j=1:size(lignes,1)
 			if ( lignes(j,3)==i & lignes(j,4)==1 )
				neuin=Noeuds(j);		
			end
  			if ( lignes(j,1)==i & lignes(j,2)==1 )
				neuout=Noeuds(j);		
			end
		end
		if isnan(neuin) 
			neuin=NoeudAlloc;
			NoeudAlloc=NoeudAlloc+1;
		end
		if isnan(neuout) 
			neuout=NoeudAlloc;
			NoeudAlloc=NoeudAlloc+1;
		end
 		param_src=[neuin neuout condit&1 R L*1e3 0 condit];
	end
end

