function[param,param_src,NoeudAlloc,ParamNumber,nphase,long,Zm,Rm,Smode,Ti]=...
nsfb34(blocs,lignes,i,Noeuds,NoeudAlloc,nb_sortie,rlc,ParamNumber,flagLin)
%NSFB34 Block 34 (3PDP line) function
% 	Note: Internal netsim function. 
%	May not work properly when used elsewhere.
%
% 	[PARAM,PARAM_SRC,STR,NOEUDALLOC,PARAMNUMBER]=NSFB34(BLOCS,LIGNES,I, ... 
%	NOEUDS,NOEUDALLOC,NB_SORTIE,RLC,PARAMNUMBER,FLAGLIN)
% 	input arguments:
%		BLOCS: (string matrix) block name matrix
%		LIGNES: (integer matrix) block connection matrix
%		I: index of the block in BLOCS
%		NOEUDS: (integer vector) node assignment
%		NOEUDALLOC: (integer) node number for allocation
%		NB_SORTIE: (integer) output number in the equiv. state-space
%		           system for the block
%		RLC: (float matrix) rlc matrix for ETATFUN
%		PARAMNUMBER: (integer vector) Blocks special parameter vector
%		FLAGLIN: (integer)
%		         =1: computation of phase resistance matrix (rlc)
%		         i.e. only PARAM is computed. PARAMNUMBER is modified
%		         =0: computation of cuirrent source matrix     
%		         i.e. only PARAM_SRC and STR are computed		
% 	output arguments:
%		PARAM: (float matrix) RLC parameters of the block in the
%	               format required by ETATFUN
%		PARAM_SRC:(float vector) current source parametres in the
%	               format required by ETATFUN
%		NOEUDALLOC: (integer) node number for allocation
%		PARAMNUMBER: (integer vector) Blocks special parameter vector
%		NPHASE     : Number of phases of the line
%		LONG       : Length of the line (km)
%       ZM         : vector (nphase) of modal  characteristic impedances (ohms)
%       RM         : vector (nphase) of modal  series resistances (ohms/km)
%       SMODE      : vector (nphase) of modal  propagation speeds (km/s)
%       TI         : Modal current transformation matrix (nphase,nphase)
%                    such that :   [Iphase]=[Ti].[Imode]
%
%	See also ETATFUN.

% Note : This is a new version of DPL Block with implicit connection to ground.
%	 The block have no more input and output ground.
%   Christian Dufour   08-01-95, 
%   G. Sybille         03-25-96,
%   Patrice Brunelle   06-13-97, 
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.2 $

param=[];param_src=[];

str=get_param(nsdezero(blocs(i,:)),'Mask Entries');

retvar=nsparm(str,nsdezero(blocs(i,:)));

nphase=retvar{1};
freq=retvar{2};
Rmat=retvar{3};
Lmat=retvar{4};
Cmat=retvar{5};
long=retvar{6};	
	
[Zm,Rm,Smode,Ti]=blmodlin(nphase,freq,Rmat,Lmat,Cmat);
to=long./Smode;

neuin=zeros(nphase,1);
neuout=zeros(nphase,1);

for iphase=1:nphase;
	j=find(lignes(:,3)==i & lignes(:,4)==iphase);
	if isempty(j),            
	 	neuin(iphase)=NoeudAlloc;
		NoeudAlloc=NoeudAlloc+1;
	else
		neuin(iphase)=Noeuds(j(1));
	end
end

for iphase=1:nphase;
	j=find(lignes(:,1)==i & lignes(:,2)==iphase);
	if isempty(j)
	 	neuout(iphase)=NoeudAlloc;

		NoeudAlloc=NoeudAlloc+1;
	else
		neuout(iphase)=Noeuds(j(1));
	end
end


if flagLin==1

	Zimp=zeros(nphase,nphase);
	for iphase=1:nphase,
		Zimp(iphase,iphase)=Zm(iphase)+0.25*Rm(iphase)*long;
	end

	Yphase=Ti*inv(Zimp)*(Ti');

	param=[];
	masse=0;

	% phase-phase input resistances:
	for iphase=1:nphase,
		for iphase1=iphase+1:nphase,
			param=[param;...
			neuin(iphase) neuin(iphase1) 0 -1/Yphase(iphase,iphase1) 0 0 i 0];
		end
	end
	
	% phase-ground input resistances:
	for iphase=1:nphase,
		param=[param;...
		neuin(iphase) masse 0 1/sum(Yphase(iphase,:)) 0 0 i 0];
	end
	
	% phase-phase output resistances:
	for iphase=1:nphase,
		for iphase1=iphase+1:nphase,
			param=[param;...
			neuout(iphase) neuout(iphase1) 0 -1/Yphase(iphase,iphase1) 0 0 i 0];
		end
	end
	
	% phase-ground output resistances:
	for iphase=1:nphase,
		param=[param;...
		neuout(iphase) masse 0 1/sum(Yphase(iphase,:)) 0 0 i 0];
	end
	
	
	ParamNumber(i)=size(rlc,1)+1; 

else,
  	param_src=[];
	n=nphase*(nphase-1)/2; % number of phase-phase ground resistances

	% input current sources:
   	j=ParamNumber(i)+n;
	
  	for k= j:j+nphase-1,  
		param_src=[param_src; rlc(k,2) rlc(k,1) 1 0  0  0  1001];
	end
	
  	j=j+nphase+n;

	% output current sources:
  	for k= j:j+nphase-1,  
		param_src=[param_src; rlc(k,2) rlc(k,1) 1 0  0  0  1001];
	end

end

