function [rlc,source,switchns,line_dist,true_source,nb_true_sensor,nb_models,...
models,models_param,yout,y_type,srcstr,outstr,blocs,CustomBlocNumber, ...
ParamNumber,BrancheRef,Noeuds,lignes,capteurlist,capteurindice,others]= ...
nsgrafx(simuwin,nsfid,nsflag);
%NSGRAFX Simulink graphical interface analyser for EPSD toolbox
%	[RLC,SOURCE,SWITCH,TRUE_SOURCE,NB_TRUE_SENSOR,NB_MODELS, ...
%	MODELS,MODELS_PARAM,YOUT,Y_TYPE,SRCSTR,OUTSTR,BLOCS, ...
%	CUSTOMBLOCNUMBER,PARAMNUMBER,BRANCHEREF,NOEUDS,LIGNES, ...
%	CAPTEURLIST,CAPTEURINDICE,OTHERS]=NSGRAFX(SIMUWIN,NSFID,NSFLAG) 
%	returns parameters describing the network drawn in the Simulink 
%	canevas SIMUWIN
%	Parameters:
%	   input:
%		SIMUWIN:(char vector) name of the simulink window to analyse
%		NSFID		file identifier for output to file.
%		NSFLAG		flag vector for warnings, file output, test.
%	   output:
%		RLC:		rlc matrice *
%		SOURCE:		source matrice *
%		SWITCH:		switchns matrice *
%		TRUE_SOURCE: 	number of sources from 'Current source'
%				and 'Voltage source' blocks only
%		NB_TRUE_SENSOR:	number of output from 'Current measurement'
%				and 'Voltage measurement' blocks only
%		NB_MODELS:	vector containing the number of non-linear
%				models in the network
%			NB_MODELS(1)= # Breaker (26)
%			NB_MODELS(2)= # Simplified alternator (16)
%			NB_MODELS(3)= # Saturated transformer (6)
%			NB_MODELS(4)= # Thyristor (25)
%			NB_MODELS(5)= # Diode (24)
%			NB_MODELS(6)= # Surge arrester (28)
%			NB_MODELS(7)= #	Controlled sources(V or I)
%			NB_MODELS(8)= # Switch
%			NB_MODELS(9)= # reserved 1pdp line
%			NB_MODELS(10)=# reserved 3pdp line
%			NB_MODELS(11)=#	Alternator (17)
%		MODELS:		vector containing the complete names of
%				all non-linear models
%				They are listed in the order of the NB_MODELS
%				vector
%		MODELS_PARAM:   for each line of MODELS, corresponding special
%				parameters if any (0 for no parameter)
%				Simplified alternator:  =1 if floating neutral
%		YOUT:		string matrice of the output values *
%		Y_TYPE:		vector of the type of the output value *
%		SRCSTR:		vector containing the block names of the 
%				sources of the network corresponding to the
%				source matrice
%		OUTSTR:		vector containing the block names of the 
%				output	of the network corresponding to the
%				yout matrice
%		BLOCS:		list of the names of the blocks in the network
%		CUSTOMBLOCNUMBER:vector that indicates the number of the 
%				blocks in reference to the CustomBlocs matrice.
%				In addition, special values indicates special
%				blocks: 
%				= -1  subsystem
%				=666666	non-drawn block created in the case
%					of unconnected lines
%				=999	in-port block (in subsystems)
%				=1001	out-port block (in subsystems)
%		PARAMNUMBER:	parameter vector for blocks. Depending on the
%				block this number has a different meaning
%			in/out port blocks:	number of the port
%			Neutral block:		number of the neutral
%			Busbar block:		number of the busbar
%			Saturable transformer:	row indice in the rlc matrice
%						corresponding to the
%						'Core Losses' of the block
%		BRANCHEREF:	Block number referencing matrice for the RLC 
%				matrice. 
%			1e col:	For the corresponding line in RLC,
%				indicates the number of the block from which
%				the line comes from 
%			2e col: special number used in multi state variable 
%				blocks
%				Line:	Capacity or inductance number
%				Mutual inductance: coil number
%				Linear transformer: coil number
%				Saturable transformer: coil number
%		NOEUDS:		Node allocation for each line of the circuit
%				Each lines of LIGNES has a node
%		LIGNES:		Line matrix of the circuit
%			Format of LIGNES:
%			LIGNES(1): Block number at the origin of the line
%			LIGNES(2): Output number of the block at the origin
%			LIGNES(3): Block number at the destination of the line
%			LIGNES(4): Input number of the block at the destin.
%			LIGNES(5): not used 			
%		CAPTEURLIST:	'Voltage sensor' and 'Current
%				 sensor' name list
%		CAPTEURINDICE:	Indice of the captor with respect to its output
%				rank in yout or outstr vectors.
%				Negative value for unconnected sensors.
%		OTHERS:		matrix of simulink connection to electrical
%				blocks
%			Format of OTHERS (each line):
%			OTHERS(1): node number
%			OTHERS(2): block number (index in BLOCS) 
%			OTHERS(3): input/output number in block
%			OTHERS(4): =1:input  =2:output
%						
%
%	* see etatfun.m for more details
%
%	See also ETATFUN, NETSIM

%   Christian Dufour 11-22-95, Patrice Brunelle 26-jan-97 
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.2 $
     
test=0;
errstr=[];
symbole_accelerateur='$';		        % block number
CustomBlocs={
	'Series RLC Branch'			,1
	'Parallel RLC Branch'			,2	
	'Pi Section Line'			,3
 	'Mutual Inductance'			,4
	'Linear Transformer'			,5
	'Saturable Transformer'			,6
	'Series RLC Load'			,7
	'Parallel RLC Load'			,8
	'Voltage Measurement'			,9
	'Current Measurement'			,10
	'AC Voltage Source'			,11
	'AC Current Source'			,12
	'Bus Bar'				,13
	'Ground'				,14
	'Neutral'				,15
        'Simplified Synchronous Machine'	,16
	'Synchronous Machine'			,17
	'PM Synchronous Machine' 	        ,18
	'Gto'					,19
	'Asynchronous Machine'			,20
	'Ideal Switch'				,21
	'Mosfet'				,22
	'Simplified Thyristor'			,23
	'Diode'					,24
	'Thyristor'				,25
	'Breaker'				,26
	'Surge Arrester'			,28
	'3 phase converter'			,29
	'DC Voltage Source'			,32
	'Distributed Parameters Line'		,34
	'Controlled Voltage Source'		,35
	'Controlled Current Source' 		,36 
	};	

SimulinkSub={
	'Repeating table',1;
	'Chirp',1;
	'Continuous White Noise',1;
	'Ramp',1;
	'Pulse Generator',1;
	'First-Order Hold',1;
	'Dot Product',1};
 
bloctype=[	'EPSD block            ';
		'Simulink basic block  ';
		'Simulink masked block ';
		'Simulink subsystem    ';
		'Subsystem             ';
		'Ghost block           '];
 
system=simuwin;
if nsflag(2)==1
   fprintf(nsfid,'Processing of EPSD Simulink window named: %s \n\n',system);
end

lignes=nslines(system);

% flush unused columns:
if size(lignes,1)~=0
	lignes=lignes(:,1:5);
	%INDIRECT LINE CONNECTIONS TREATMENT:
	lignes=nsdiscon(lignes);
end

%*******ADAPTATION*********
blocs=get_param(system,'blocks');
blocs=nsadapte(blocs);  
%********FIN***************

slash=nsslash(blocs);
if (slash==1)
    errstr=['FATAL! Main system: "' system  '" contains block name with "/". '];
    nserror(errstr,'',13);
end

% total "path":
blocs=[ones(size(blocs,1),1)*[system '/'] blocs zeros(size(blocs,1),5)];

Nlignes=size(lignes,1);		      % Nligne(1)=nombre de lignes
Nblocs=size(blocs,1);		      % Nblocs(1)=nombre de blocs

RelativeBlocIndex=1:1:size(blocs,1);  % BLOCK INDEX RELATIVE TO THE PARENT BLOC 
ParentBloc=zeros(Nblocs,1);	      % PARENT BLOCK NUMBER 
CustomBlocNumber=zeros(Nblocs,1);     % BLOCK TYPE NUMBER
ParamNumber=zeros(Nblocs,1);		
 
  
% SCAN 'BLOCS' MATRIX AND SEARCH FOR ELECTRICAL SUBSYSTEMS:

i=1;
while( i<=size(blocs,1) )
	Nblocs=size(blocs,1);
	Nlignes=size(lignes,1);		
	flag=0;
	isCustom=0;

	blktyp=get_param([nsdezero(blocs(i,:))],'BlockType');


	% mise a jour : doit etre enleve dans la version beta definitive.
	%%%%%
	%misajourblocs(nsdezero(blocs(i,:)));
	%%%%%

	% Is it a MARKED (accelerator) BLOCK ?

	first_name=get_param([nsdezero(blocs(i,:))],'Name');
	first_letter=first_name(1);
	if strcmp(first_letter,symbole_accelerateur)
		CustomBlocNumber(i)=0;	% ecrire le type de bloc (Simulink->0)
		flag=1;		        % si oui flag=1
	end

        % Is it a SIMULINK BLOCK ?

	bsm=~strcmp(blktyp,'SubSystem');
        if bsm
		CustomBlocNumber(i)=0;	% ecrire le type de bloc (Simulink->0)
		flag=1;		        % si oui flag=1
	end

        % Is it an ELECTRIC BLOCK ?
 
 	[isCustom,type]=nsinlist(blocs,i,CustomBlocs);

	if (isCustom==1)
		CustomBlocNumber(i)=type;   
		flag=1;		         % si oui flag=1 ( pas un sous-systeme )
	end
 
        % Is it an INPORT SIMULINK BLOCK ?
 
        if strcmp(blktyp,'Inport')
		PortNum=get_param([nsdezero(blocs(i,:))],'Port');
		PortNum=str2num(PortNum);
		CustomBlocNumber(i)=999;	% INPORT BLOCK TYPE: 999
		ParamNumber(i)=PortNum;
	end

        % Is it an OUTPORT SIMULINK BLOCK ?
 
        if strcmp(blktyp,'Outport')
		PortNum=get_param([nsdezero(blocs(i,:))],'Port');
		PortNum=str2num(PortNum);
		CustomBlocNumber(i)=1001;	% INPORT BLOCK TYPE: 1001
		ParamNumber(i)=PortNum;
	end

        % Is it a NEUTRAL ELECTRIC BLOCK ?
	
 	if (CustomBlocNumber(i)==15)
 		str=get_param(nsdezero(blocs(i,:)),'Mask Entries');
		retvar=nsparm(str,nsdezero(blocs(i,:)));
		ParamNumber(i)=retvar{1};
	end

	% Is it a SUBSYSTEM CONTAINING ONLY SIMULINK BASIC BLOCKS ?

	if (flag==0)&~bsm

		Simflag=1;
		%**********************
 		NouveauxBlocs=get_param([nsdezero(blocs(i,:))],'Blocks');
		NouveauxBlocs=nsadapte(NouveauxBlocs);
		%**********************
		slash=nsslash(NouveauxBlocs);
		if (slash==1)
 			errstr=['FATAL! Subsystem: "' nsdezero(blocs(i,:)) ...
				 '" contains block name with "/". '];
			nserror(errstr,'',13);
		end
		for j=1:size(NouveauxBlocs,1)
			sblocs=[nsdezero(blocs(i,:)) '/' NouveauxBlocs(j,:)];
	                blktyp=get_param([nsdezero(sblocs)],'BlockType');

	% mise a jour : doit etre enleve dans la version beta definitive.
	%%%%%
	%misajourblocs(nsdezero(sblocs));
	%%%%%

			if strcmp(blktyp,'SubSystem');
				% IS IT A SIMULINK SUBSYSTEM BLOCK ?
				Simflag=nsinlist(sblocs,1,SimulinkSub);
				if Simflag==0	
				    break
				end
			end
		end
		flag=Simflag;
		if flag==1 & nsflag(2)==1
  			fprintf(nsfid,'%s%s%s%s\n',num2str(i),...
			     blanks(10-length(num2str(i))),bloctype(4,:),...
			     nsrtrn(get_param([nsdezero(blocs(i,:))],'Name')));
		end		
	end

	% FLAG==0 ? , SUBSYSTEM MUST BE OPENED AND TREATED :

  	if flag==0
		CustomBlocNumber(i)=-1;
		% READ PARAMETERS FROM SUBSYSTEM :
		NouveauxBlocs=get_param([nsdezero(blocs(i,:))],'Blocks');
		NouveauxBlocs=nsadapte(NouveauxBlocs);
		RelativeBlocIndex=[RelativeBlocIndex 1:1:size(NouveauxBlocs,1)];

		% COMPLETE ROOT ADDED TO NEW BLOCKS:
		NouveauxBlocs=[ones(size(NouveauxBlocs,1),1)* ...
		    [nsdezero(blocs(i,:)) '/'] NouveauxBlocs ];

		% ADD NouveauxBlocs TO Blocs AND ADJUST NUMBER OF COLOMNS
		sizeB=size(blocs);
		sizeNB=size(NouveauxBlocs);
		if(sizeB(2)>sizeNB(2))
			NouveauxBlocs=[ NouveauxBlocs ...
			   zeros(sizeNB(1),sizeB(2)-sizeNB(2))];
		end
		if(sizeB(2)<sizeNB(2))
			blocs=[ blocs zeros(sizeB(1),sizeNB(2)-sizeB(2))];
		end
		blocs=[blocs' NouveauxBlocs']';

		% ADD TO ParentBloc[] :
		ParentBloc=[ParentBloc' i*ones(1,sizeNB(1))]';

		% ADD 0's TO ParamNumber : WILL BE CHANGED LATER IF NEEDED :
		ParamNumber=[ ParamNumber' zeros(1,sizeNB(1))]';

		% SAME THING FOR CustomBlocNumber :
		CustomBlocNumber=[ CustomBlocNumber' zeros(1,sizeNB(1))]';

 		NouvellesLignes=nslines([nsdezero(blocs(i,:))]);
		if length(NouvellesLignes)~=0

			% INDIRECT CONNECTIOIN TREATMENT:
	  		 NouvellesLignes=nsdiscon(NouvellesLignes);
 	
			% ADD NouvellesLignes TO lignes,
			% OFFSET BLOCK NUMBER IN NouvellesLignes
		
	  		 NouvellesLignes(:,1)=(NouvellesLignes(:,1)~=0).* ...
				(NouvellesLignes(:,1)+Nblocs);
	  		 NouvellesLignes(:,3)=(NouvellesLignes(:,3)~=0).* ...
				(NouvellesLignes(:,3)+Nblocs);

  	   		% modifier les numeros de lignes dans NouvellesLignes
	  		% la 5e colonne de lignes=get_param('xyz','Lines') , 
			% si differente de 0,indique l'indice de 'lignes' d'ou 
			% origine la ligne pour les cas ou une ligne origine
	  		% d'une autre ligne
			% OFFSET INDIRECT LINE REFERENCES:
	
	  		 NouvellesLignes(:,5)=(NouvellesLignes(:,5)~=0).* ...
				(NouvellesLignes(:,5)+Nlignes);

			% CONCATENATION MADE HERE
	   		lignes=[lignes' NouvellesLignes(:,1:5)']';
		end
	end 
	i=i+1;
end 


% TREATMENT FOR I/O PORT CONNECTIONS :
lignes=nsrerout(lignes,blocs,CustomBlocNumber,ParentBloc,ParamNumber);
 
% UNWRAPPING OF SUBSYSTEMS :
lignes=nscnport(lignes,blocs,CustomBlocNumber,ParentBloc,ParamNumber);
	
% OPEN_LINE TREATMENT :
[lignes,nb_bloc_fantomes]=nsopenln(lignes,blocs);


% CREATION OF GHOST BLOCKS FOR OPEN ENDED LINES:
if nb_bloc_fantomes>0 & nsflag(2)==1
	fprintf(nsfid,['\nThe following blocks correspond to lines',  ...
	 'opened at their origin:\n']);
end
blknombre=size(blocs,1);
for i=1:nb_bloc_fantomes
	blocs=[blocs; [simuwin '/(null' num2str(i) ')',...
		blanks(size(blocs,2)-length(simuwin)-7-length(num2str(i)))]];
end
CustomBlocNumber=[CustomBlocNumber; 666666*ones(nb_bloc_fantomes,1) ]; 
% le CustomBlocNumber d'un bloc fantome est: 666666
ParamNumber=[ParamNumber ; zeros(nb_bloc_fantomes,1) ];

% DIRECT CONNECTION OF ALL LINES & RATIONALISATION OF LINES :
lignes=nscnline(lignes);
    
% FIRST NODE ALLOCATION :
Noeuds=nsatribn(lignes);
 
% FUSION OF NODES SEPARATED BY BUSBAR BLOCKS :
Noeuds=nscnbusb(lignes,Noeuds,CustomBlocNumber);

% FUSION OF NODES SEPARATED BY LINE BLOCKS :
Noeuds=nscnpi(lignes,Noeuds,CustomBlocNumber);

% FUSION OF NODES SEPARATED BY NEUTRAL BLOCKS :
[Noeuds,CustomBlocNumber]=nscnneut(lignes,Noeuds,CustomBlocNumber,ParamNumber);
 
%GROUNDING OF NODES CONNECTED TO GROUND BLOCKS
Noeuds=nscngnd(lignes,Noeuds,CustomBlocNumber);

%$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
%$$					$$
%$$     NODAL ANALYSIS STOP HERE	$$
%$$					$$
%$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$

  	
% MATRICE COMPUTATION FOR ETATFUN:


BrancheAlloc=size(blocs,1)+1;
NoeudAlloc=max(Noeuds)+1;
if length(Noeuds)==0  % cas special ou aucun noeud n'a ete alloue
	NoeudAlloc=1;
end
blocswo=blocs(:,length(simuwin)+2:size(blocs,2)); % blocs sans fenetre d'origine
srcstr=[];	% STRING MATRIX OF SOURCE NAMES
outstr=[];	% STRING MATRIX OF OUTPUT NAMES
nb_source=0;
nb_sortie=0;
nb_line_dist=0;
line_dist=[];
source=[];
sourcename=[];
rlc=[];
others=[];  	% LISTS SIMULINK CONNECTION OF EPSD BLOCKS
		% format [node #block #in/out type]
		% type =1 for input; =2 for output

% 'rlc' COMPUTATION:
for i=1:size(blocs,1)
 	% CASE: SERIES RLC BLOCK :
	if (	CustomBlocNumber(i)==1 	)
 		[rlctemp]=nsfb01(blocs,lignes,i,Noeuds);
	 	rlc=[rlc; rlctemp];
	end
	% CASE: PARALLEL RLC BLOCK :
	if (	CustomBlocNumber(i)==2 	)
		[rlctemp]=nsfb03(blocs,lignes,i,Noeuds); 
		rlc=[rlc; rlctemp];
	end
	% CASE: LINE BLOCK :
	if (	CustomBlocNumber(i)==3 	)
		[rlctemp,NoeudAlloc]=nsfb08(blocs,lignes,i,Noeuds,NoeudAlloc);
 		rlc=[rlc; rlctemp];		
	end
	% CASE: MUTUAL INDUCTANCE BLOCK :
	if (	CustomBlocNumber(i)==4 	)
		[rlctemp,NoeudAlloc]=nsfb09(blocs,lignes,i,Noeuds,NoeudAlloc);
		rlc=[rlc; rlctemp];		
	end
	% CASE: LINEAR TRANSFORMER BLOCK :
	if (	CustomBlocNumber(i)==5 	)
		[rlctemp,NoeudAlloc]=nsfb10(blocs,lignes,i,Noeuds,NoeudAlloc);
		rlc=[rlc; rlctemp];		
	end
	% CASE: LINEAR PART OF SATURABLE TRANSFORMER :
	if (	CustomBlocNumber(i)==6 	)
  		[rlctemp,sourcetemp,str,NoeudAlloc,ParamNumber]= ...
		  nsfb11(blocs,lignes,i,Noeuds,NoeudAlloc,nb_sortie,...
		  rlc,ParamNumber,1);
 		rlc=[rlc; rlctemp];	
	end
	% CASE: LOAD SERIES RLC  BLOCK :
	if (	CustomBlocNumber(i)==7 	)
		[rlctemp]=nsfb02(blocs,lignes,i,Noeuds);
		rlc=[rlc; rlctemp];		
	end
	% CASE: LOAD PARALLEL LOAD BLOCK :
	if (	CustomBlocNumber(i)==8 	)	 
		[rlctemp]=nsfb04(blocs,lignes,i,Noeuds);
		rlc=[rlc; rlctemp];
	end
	% CASE: LINEAR PART OF GTO :
	if (	CustomBlocNumber(i)==19 )
		[rlctemp,sourcetemp,othertemp,NoeudAlloc]= ...
			nsfb26(blocs,lignes,i,Noeuds,NoeudAlloc,rlc,1);
		rlc=[rlc; rlctemp];	
	end
	% CASE: LINEAR PART OF IDEAL SWITCH :
	if (	CustomBlocNumber(i)==21 )
		[rlctemp,sourcetemp,othertemp,NoeudAlloc]= ...
			nsfb32(blocs,lignes,i,Noeuds,NoeudAlloc,rlc,1);
		rlc=[rlc; rlctemp];	
	end
	% CASE: LINEAR PART OF MOSFET :
	if (	CustomBlocNumber(i)==22 )
		[rlctemp,sourcetemp,othertemp,NoeudAlloc]= ...
			nsfb31(blocs,lignes,i,Noeuds,NoeudAlloc,rlc,1);
		rlc=[rlc; rlctemp];	
	end
	% CASE: LINEAR PART OF DIODE :
	if (	CustomBlocNumber(i)==24 )
		[rlctemp,sourcetemp,othertemp,NoeudAlloc]= ...
			nsfb19(blocs,lignes,i,Noeuds,NoeudAlloc,rlc,1);
		rlc=[rlc; rlctemp];	
	end
	% CASE:  LINEAR PART OF THYRISTOR :
	if (	CustomBlocNumber(i)==25 )
		[rlctemp,sourcetemp,othertemp,NoeudAlloc]= ...
			nsfb20(blocs,lignes,i,Noeuds,NoeudAlloc,rlc,1);
		rlc=[rlc; rlctemp];	
	end
	% CASE:  LINEAR PART OF SIMPLIFIED THYRISTOR :
	if (	CustomBlocNumber(i)==23 )
		[rlctemp,sourcetemp,othertemp,NoeudAlloc]= ...
			nsfb20(blocs,lignes,i,Noeuds,NoeudAlloc,rlc,1);
		rlc=[rlc; rlctemp];	
	end
	% CASE:  LINEAR PART OF DISTRIBUTED PARAMETERS LINE
	if (	CustomBlocNumber(i)==34 )
  		[rlctemp,sourcetemp,NoeudAlloc,ParamNumber,nphase]= ...
		  nsfb34(blocs,lignes,i,Noeuds,NoeudAlloc,nb_sortie,...
		  rlc,ParamNumber,1);
 		rlc=[rlc; rlctemp];	
	end
end

% RLC NODE ALLOCATION FOR UNALLOCATED BLOCK NODE :
for i=1:size(rlc,1)
	if(isnan(rlc(i,1)))
		rlc(i,1)=NoeudAlloc;
		NoeudAlloc=NoeudAlloc+1;
	end
	if(isnan(rlc(i,2)))
		rlc(i,2)=NoeudAlloc;
		NoeudAlloc=NoeudAlloc+1;
	end
end

% 'source' COMPUTATION :
for i=1:size(blocs,1)	
	% CASE:  VOLTAGE SOURCE :
	if (	CustomBlocNumber(i)==11 ) 
 		[sourcetemp]=nsfb05(blocs,lignes,i,Noeuds);
		sourcename=[sourcename;blocs(i,:)];
		source=[source; sourcetemp ];
		nb_source=nb_source+1;
		srcstr=nstr2mat(srcstr,['U_',blocswo(i,:)]);		
	end
	% CASE:  CURRENT SOURCE :
	if (	CustomBlocNumber(i)==12 )
		[sourcetemp]=nsfb06(blocs,lignes,i,Noeuds);
		sourcename=[sourcename;blocs(i,:)];
		source=[source; sourcetemp ];
		nb_source=nb_source+1;
		srcstr=nstr2mat(srcstr,['I_',blocswo(i,:)]);
	end
	% CASE:  DC SOURCE
	if (	CustomBlocNumber(i) )==32
		[sourcetemp]=nsfb07(blocs,lignes,i,Noeuds);
		sourcename=[sourcename;blocs(i,:)];
		source=[source; sourcetemp ];
		nb_source=nb_source+1;
		srcstr=nstr2mat(srcstr,['U_',blocswo(i,:)]);
	end
end
sourcenbre=nb_source; % the number of fixed sources blocks
% SOURCE NODE ALLOCATION FOR UNALLOCATED ENTRIES :
for i=1:size(source,1)
	if(isnan(source(i,1)))
		source(i,1)=NoeudAlloc;
		NoeudAlloc=NoeudAlloc+1;
	end
	if(isnan(source(i,2)))
		source(i,2)=NoeudAlloc;
		NoeudAlloc=NoeudAlloc+1;
	end
end

 			
% TREATMENT OF NON-LINEAR ELEMENTS :

switchns=[];
matrice_phase=[];
nb_models=zeros(1,15);
nb_models(1)=sourcenbre;
models=[sourcename];
models_param=[zeros(1,sourcenbre)];
others=zeros(nb_models(1),4);

% VARIABLE VOLTAGE SOURCE :

for i=1:size(blocs,1)
	if (	CustomBlocNumber(i)==35 	)
 		[params,othertemp,NoeudAlloc]= ...
		   nsfb21(blocs,lignes,i,Noeuds,NoeudAlloc);
 		source=[source; params ];
 		models=[models;blocs(i,:)];
		models_param=[models_param 0];
		others=[others;othertemp];
		nb_models(1)=nb_models(1)+1;
		nb_source=nb_source+1;		% 1 source de plus
 		srcstr=nstr2mat(srcstr,['U_',blocswo(i,:)]);
	end
end

% VARIABLE CURRENT SOURCE:

for i=1:size(blocs,1)
	if (	CustomBlocNumber(i)==36 	)
		[params,othertemp,NoeudAlloc]= ...
		   nsfb22(blocs,lignes,i,Noeuds,NoeudAlloc);
 		source=[source; params ];
 		models=[models;blocs(i,:)];
		models_param=[models_param 0];
		others=[others;othertemp];
		nb_models(1)=nb_models(1)+1;
		nb_source=nb_source+1;		% 1 source de plus
 		srcstr=nstr2mat(srcstr,['I_',blocswo(i,:)]);
	end
end

true_source=source;

% BREAKER :
 
for i=1:size(blocs,1)
	if ( CustomBlocNumber(i)==26)
 		[params,othertemp,NoeudAlloc]=...
		   nsfb15(blocs,lignes,i,Noeuds,NoeudAlloc);
		others=[others; othertemp];
  		models=[models;blocs(i,:)];
		models_param=[models_param 0];
		nb_models(2)=nb_models(2)+1;
  		source=[source;[params(1:2) 1 0 0 0 8 ]];
		nb_source=nb_source+1;		% 1 source de plus
		nb_sortie=nb_sortie+1;		% 1 sortie de plus
		params(6)=nb_source;
		params(7)=nb_sortie;
		switchns=[switchns;params];

		% switchns: convention receveur   +	-
		%				---->----
		%				    i

		str=['y_u' num2str(nb_sortie) '=' '''' 'U_n' ...
 		    num2str(params(1)) '_' num2str(params(2)) ''''  ';'];
		eval(str);			
		srcstr=nstr2mat(srcstr,['I_',blocswo(i,:)]);
		outstr=nstr2mat(outstr,['U_',blocswo(i,:)]);
	end
end

% SIMPLIFIED ALTERNATOR :
 
for i=1:size(blocs,1)
	if ( CustomBlocNumber(i)==16)
		[params,othertemp,NoeudAlloc,type]=...
		    nsfb24(blocs,lignes,i,Noeuds,NoeudAlloc);
		others=[others; othertemp];
		models=[models;blocs(i,:)];
		nb_models(3)=nb_models(3)+1;
		models_param=[models_param type];	
 		source=[source;params ];
		nb_source=nb_source+2;		% 2 sources de plus
		nb_sortie=nb_sortie+2;		% 2 sorties de plus

		% alternateur: convention generateur   -	+
		%					---->----
		%				  	    i
		% formulaire d'entree ( )
		% tensions de sortie:  	Uab 
		%			Ubc 
		% sources courant de sortie:
		%			Ica
		%			Icb


		str=['y_u' num2str(nb_sortie-1) '=' '''' 'U_n' ...
		    num2str(params(1,2)) '_' num2str(params(2,2)) ''''  ';'];
		eval(str);
		str=['y_u' num2str(nb_sortie) '=' '''' 'U_n' ...
		    num2str(params(2,2)) '_' num2str(params(2,1)) ''''  ';'];
		eval(str); 
		srcstr=nstr2mat(srcstr,['I_',nsdezero(blocswo(i,:)),'_A']);
		srcstr=nstr2mat(srcstr,['I_',nsdezero(blocswo(i,:)),'_B']); 
		outstr=nstr2mat(outstr,['U_',nsdezero(blocswo(i,:)),'_AB']);
		outstr=nstr2mat(outstr,['U_',nsdezero(blocswo(i,:)),'_BC']);
	end
end

% SATURATED TRANSFORMER (non-linear part) :
 
for i=1:size(blocs,1)
	if (	CustomBlocNumber(i)==6 	)		 
		models=[models;blocs(i,:)];
		models_param=[models_param 0];
		nb_models(4)=nb_models(4)+1;
		[rlctemp,sourcetemp,str,NoeudAlloc,ParamNumber]= ...
			nsfb11(blocs,lignes,i,Noeuds,NoeudAlloc,nb_sortie,...
			rlc,ParamNumber,0);
 		source=[source; sourcetemp ];
		eval(str);
		nb_source=nb_source+1;		% 1 source de plus
		nb_sortie=nb_sortie+1;		% 1 sortie de plus
		srcstr=nstr2mat(srcstr,['I_',nsdezero(blocswo(i,:)),'_core']);
		outstr=nstr2mat(outstr,['U_',nsdezero(blocswo(i,:)),'_core']);
	end
end

% THYRISTOR:

for i=1:size(blocs,1)
	if (	CustomBlocNumber(i)==25 	)
		[rlctemp,params,othertemp,NoeudAlloc]= ...
			nsfb20(blocs,lignes,i,Noeuds,NoeudAlloc,rlc,0);
		others=[others;othertemp];
		nb_models(5)=nb_models(5)+1;
 		source=[source; [params(1:2) 1 0 0 0 22 ] ];
		models=[models;blocs(i,:)];
		models_param=[models_param 0];
		nb_source=nb_source+1;		% 1 source de plus
		nb_sortie=nb_sortie+1;		% 1 sortie de plus
		params(6)=nb_source;
		params(7)=nb_sortie;
		switchns=[switchns;params];

		% thyristor: convention receveur   	+	-
		%					---->----
		%				    	    i

		str=['y_u' num2str(nb_sortie) '=' '''' 'U_n' ...
		   num2str(params(1)) '_' num2str(params(2)) ''''  ';'];
		eval(str);
		srcstr=nstr2mat(srcstr,['I_',blocswo(i,:)]);
		outstr=nstr2mat(outstr,['U_',blocswo(i,:)]);
	end
end

% DIODE :

for i=1:size(blocs,1)
	if (	CustomBlocNumber(i)==24 )
		[rlctemp,params,othertemp,NoeudAlloc]= ...
			nsfb19(blocs,lignes,i,Noeuds,NoeudAlloc,rlc,0);
		others=[others;othertemp];
		nb_models(6)=nb_models(6)+1;
		source=[source; [params(1:2) 1 0 0 0 21 ] ];
 		models=[models;blocs(i,:)];
		models_param=[models_param 0];
		nb_source=nb_source+1;		% 1 source de plus
		nb_sortie=nb_sortie+1;		% 1 sortie de plus
		params(6)=nb_source;
		params(7)=nb_sortie;
		switchns=[switchns;params];

		% diode  : convention receveur   	+	-
		%					---->----
		%				    	    i

		str=['y_u' num2str(nb_sortie) '=' '''' 'U_n' ...
		   num2str(params(1)) '_' num2str(params(2)) ''''  ';'];
		eval(str);
		srcstr=nstr2mat(srcstr,['I_',blocswo(i,:)]);
		outstr=nstr2mat(outstr,['U_',blocswo(i,:)]);
	end
end

% SURGE ARRESTER :

for i=1:size(blocs,1)
	if (	CustomBlocNumber(i)==28 	)
		[params,NoeudAlloc]= nsfb16(blocs,lignes,i,Noeuds,NoeudAlloc);
 		source=[source; params ];
 		models=[models;blocs(i,:)];
		models_param=[models_param 0];
		nb_models(7)=nb_models(7)+1;
		str=['y_u' num2str(nb_sortie+1) '=' '''' 'U_n' ...
		   num2str(params(1)) '_' num2str(params(2)) ''''  ';'];
		eval(str);
		nb_source=nb_source+1;		% 1 source de plus
		nb_sortie=nb_sortie+1;		% 1 sortie de plus
		srcstr=nstr2mat(srcstr,['I_',blocswo(i,:) zeros(1,6)]);
		outstr=nstr2mat(outstr,['U_',blocswo(i,:) zeros(1,6)]);
	end
end

% MOSFET:

for i=1:size(blocs,1)
	if (	CustomBlocNumber(i)==22 	)
		[rlctemp,params,othertemp,NoeudAlloc]= ...
			nsfb31(blocs,lignes,i,Noeuds,NoeudAlloc,rlc,0);
		others=[others;othertemp];
		nb_models(8)=nb_models(8)+1;
 		source=[source; [params(1:2) 1 0 0 0 24 ] ];
		models=[models;blocs(i,:)];
		models_param=[models_param 0];
		nb_source=nb_source+1;		% 1 source de plus
		nb_sortie=nb_sortie+1;		% 1 sortie de plus
		params(6)=nb_source;
		params(7)=nb_sortie;
		switchns=[switchns;params];

		% mosfet: convention receveur   	+	-
		%					---->----
		%				    	    i

		str=['y_u' num2str(nb_sortie) '=' '''' 'U_n' ...
		   num2str(params(1)) '_' num2str(params(2)) ''''  ';'];
		eval(str);
		srcstr=nstr2mat(srcstr,['I_',blocswo(i,:)]);
		outstr=nstr2mat(outstr,['U_',blocswo(i,:)]);
	end
end

% ASYNCHRONOUS MACHINE :

for i=1:size(blocs,1)
	if ( CustomBlocNumber(i)==20)
		[params,othertemp,NoeudAlloc,type]= ...
			nsfb30(blocs,lignes,i,Noeuds,NoeudAlloc);
		others=[others; othertemp];
		models=[models;blocs(i,:)];
		nb_models(9)=nb_models(9)+1;
		models_param=[models_param type];	
 		source=[source;params ];
		nb_source=nb_source+4;		% 4 source de plus
		nb_sortie=nb_sortie+4;		% 4 sortie de plus

		% tensions de sortie:  	Urab 
		%			Urbc 
		%			Usab
		%			Usbc 
		% sources courant de sortie
		%			IrA entrant dans phase A rotor
		%			IrB entrant dans phase B
		%			IsA entrant dans phase A stator
		%			IsB entrant dans phase B

		str=['y_u' num2str(nb_sortie-3) '=' '''' 'U_n' ...
		    num2str(params(1,1)) '_' num2str(params(2,1)) ''''  ';'];
		eval(str);
		str=['y_u' num2str(nb_sortie-2) '=' '''' 'U_n' ...
		    num2str(params(2,1)) '_' num2str(params(2,2)) ''''  ';'];
		eval(str);
		str=['y_u' num2str(nb_sortie-1) '=' '''' 'U_n' ...
	    num2str(params(3,1)) '_' num2str(params(4,1)) ''''  ';'];
		eval(str);
		str=['y_u' num2str(nb_sortie-0) '=' '''' 'U_n' ...
	    num2str(params(4,1)) '_' num2str(params(4,2)) ''''  ';'];
		eval(str);
 
 						 
	        srcstr=nstr2mat(srcstr,['I_' nsdezero(blocswo(i,:)) '_Arotor']);
	        srcstr=nstr2mat(srcstr,['I_' nsdezero(blocswo(i,:)) '_Brotor']);
	       srcstr=nstr2mat(srcstr,['I_' nsdezero(blocswo(i,:)) '_Astator']);
	       srcstr=nstr2mat(srcstr,['I_' nsdezero(blocswo(i,:)) '_Bstator']);

	       outstr=nstr2mat(outstr,['U_',nsdezero(blocswo(i,:)),'_ABrotor']);
	       outstr=nstr2mat(outstr,['U_',nsdezero(blocswo(i,:)),'_BCrotor']);
	      outstr=nstr2mat(outstr,['U_',nsdezero(blocswo(i,:)),'_ABstator']);
	      outstr=nstr2mat(outstr,['U_',nsdezero(blocswo(i,:)),'_BCstator']);
	end
end

% DISTRIBUTED PARAMETER LINE:
 
for i=1:size(blocs,1)
	if (	CustomBlocNumber(i)==34 ) 
		models=[models;blocs(i,:)];
		models_param=[models_param 0];
		nb_models(10)=nb_models(10)+1;
		[rlctemp,sourcetemp,NoeudAlloc,ParamNumber,nphase,...
			long,Zm,Rm,Sm,Ti]= nsfb34(blocs,lignes,i,Noeuds, ...
			NoeudAlloc,nb_sortie,rlc,ParamNumber,0);
		% Update line matrix
		% ------------------
		% Format line_dist :
		% col: 1      2     3     4     5....    
		%   [ nphase nosrc noout long   Zc Rmode Smode Ti]

		nb_line_dist=nb_line_dist+1;
		line_dist(nb_line_dist,1:4+3*nphase+nphase^2)= ...
			[nphase,nb_source+1,nb_sortie+1,long,Zm,Rm, ...
			Sm,reshape(Ti,1,nphase^2)];
		%
		% Update Source matrix
		% --------------------
 		source=[source; sourcetemp ];
		%
		% Update outut string matrix (srcstr)
		% ----------------------------------
		for iphase=1:2*nphase,
			nb_sortie=nb_sortie+1;
			str=['y_u' num2str(nb_sortie) '=' '''' 'U_n' ...
			   num2str(sourcetemp(iphase,2)) '_' ...
			   num2str(sourcetemp(iphase,1)) ''''  ';'];
			eval(str);
		end
		for iphase=1:nphase,
		        if iphase<=9, nadd=2; else, nadd=1; end
			srcstr=nstr2mat(srcstr,['I_' nsdezero(blocswo(i,:)) ...
			      '_in' num2str(iphase)]);
		end
		for iphase=1:nphase,
		      if iphase<=9, nadd=1; else, nadd=0; end
		      srcstr=nstr2mat(srcstr,['I_' nsdezero(blocswo(i,:)) ...
		            '_out' num2str(iphase)]);
		end
		for iphase=1:nphase,
			if iphase<=9, nadd=2; else, nadd=1; end
			outstr=nstr2mat(outstr,['U_' nsdezero(blocswo(i,:)) ...
			      '_in' num2str(iphase)]);
		end
		for iphase=1:nphase,
		      if iphase<=9, nadd=1; else, nadd=0; end
		      outstr=nstr2mat(outstr,['U_' nsdezero(blocswo(i,:)) ...
		            '_out' num2str(iphase)]);
		end
		nb_source=nb_source+2*nphase;   % nphase sources de plus
		matrice_phase=[matrice_phase 2*nphase];
	end
end

% SYNCHRONOUS MACHINE :

for i=1:size(blocs,1)
	if ( CustomBlocNumber(i)==17)
		[params,othertemp,NoeudAlloc,type]= ...
			nsfb25(blocs,lignes,i,Noeuds,NoeudAlloc);
		others=[others; othertemp];
		models=[models;blocs(i,:)];
		nb_models(11)=nb_models(11)+1;
		models_param=[models_param type];	
 		source=[source;params ];
		nb_source=nb_source+2;		% 2 sources de plus
		nb_sortie=nb_sortie+2;		% 2 sorties de plus

		% alternateur: convention generateur   -	+
		%					---->----
		%				  	    i
		% formulaire d'entree ( )
		% tensions de sortie:  	Uab 
		%			Ubc 
		% sources courant de sortie:
		%			Ica
		%			Icb
	
		str=['y_u' num2str(nb_sortie-1) '=' '''' 'U_n' ...
		    num2str(params(1,2)) '_' num2str(params(2,2)) ''''  ';'];
		eval(str);
		str=['y_u' num2str(nb_sortie) '=' '''' 'U_n' ...
		    num2str(params(2,2)) '_' num2str(params(2,1)) ''''  ';'];
		eval(str); 
 
		srcstr=nstr2mat(srcstr,['I_',nsdezero(blocswo(i,:)),'_A']);
		srcstr=nstr2mat(srcstr,['I_',nsdezero(blocswo(i,:)),'_B']); 
		outstr=nstr2mat(outstr,['U_',nsdezero(blocswo(i,:)),'_AB']);
		outstr=nstr2mat(outstr,['U_',nsdezero(blocswo(i,:)),'_BC']);
	end
end

% GTO:

for i=1:size(blocs,1)
	if (	CustomBlocNumber(i)==19 	)
		[rlctemp,params,othertemp,NoeudAlloc]= ...
			nsfb26(blocs,lignes,i,Noeuds,NoeudAlloc,rlc,0);
		others=[others;othertemp];
 		source=[source; [params(1:2) 1 0 0 0 23 ] ];
		models=[models;blocs(i,:)];
		models_param=[models_param 0];
		nb_models(12)=nb_models(12)+1;
		nb_source=nb_source+1;		% 1 source de plus
		nb_sortie=nb_sortie+1;		% 1 sortie de plus
		params(6)=nb_source;
		params(7)=nb_sortie;
		switchns=[switchns;params];

		% gto: convention receveur   	+	-
		%				---->----
		%				    i

		str=['y_u' num2str(nb_sortie) '=' '''' 'U_n' ...
		   num2str(params(1)) '_' num2str(params(2)) ''''  ';'];
		eval(str);
		srcstr=nstr2mat(srcstr,['I_',blocswo(i,:)]);
		outstr=nstr2mat(outstr,['U_',blocswo(i,:)]);
	end
end

% IDEAL SWITCH:

for i=1:size(blocs,1)
	if (	CustomBlocNumber(i)==21 	)
		[rlctemp,params,othertemp,NoeudAlloc]= ...
			nsfb32(blocs,lignes,i,Noeuds,NoeudAlloc,rlc,0);
		others=[others;othertemp];
		nb_models(13)=nb_models(13)+1;
 		source=[source; [params(1:2) 1 0 0 0 25 ] ];
		models=[models;blocs(i,:)];
		models_param=[models_param 0];
		nb_source=nb_source+1;		% 1 source de plus
		nb_sortie=nb_sortie+1;		% 1 sortie de plus
		params(6)=nb_source;
		params(7)=nb_sortie;
		switchns=[switchns;params];

		% Ideal switch: convention receveur   	+	-
		%					---->----
		%				   	    i

		str=['y_u' num2str(nb_sortie) '=' '''' 'U_n' ...
		   num2str(params(1)) '_' num2str(params(2)) ''''  ';'];
		eval(str);
		srcstr=nstr2mat(srcstr,['I_',blocswo(i,:)]);
		outstr=nstr2mat(outstr,['U_',blocswo(i,:)]);
	end
end

% SIMPLIFIED THYRISTOR:

for i=1:size(blocs,1)
	if (	CustomBlocNumber(i)==23 	)
		[rlctemp,params,othertemp,NoeudAlloc]= ...
			nsfb20(blocs,lignes,i,Noeuds,NoeudAlloc,rlc,0); %identi
		others=[others;othertemp];
		nb_models(14)=nb_models(14)+1;
 		source=[source; [params(1:2) 1 0 0 0 22 ] ];
		models=[models;blocs(i,:)];
		models_param=[models_param 0];
		nb_source=nb_source+1;		% 1 source de plus
		nb_sortie=nb_sortie+1;		% 1 sortie de plus
		params(6)=nb_source;
		params(7)=nb_sortie;
		switchns=[switchns;params];

		% Simpl. thyristor: convention receveur   	+	-
		%						---->----
		%				    	  	    i

		str=['y_u' num2str(nb_sortie) '=' '''' 'U_n' ...
		   num2str(params(1)) '_' num2str(params(2)) ''''  ';'];
		eval(str);
		srcstr=nstr2mat(srcstr,['I_',blocswo(i,:)]);
		outstr=nstr2mat(outstr,['U_',blocswo(i,:)]);
	end
end

% PM SYNCHRONOUS MOTOR :

for i=1:size(blocs,1)
	if ( CustomBlocNumber(i)==18)
		[params,othertemp,NoeudAlloc,type]= ...
			nsfb29(blocs,lignes,i,Noeuds,NoeudAlloc);
		others=[others; othertemp];
		models=[models;blocs(i,:)];
		nb_models(15)=nb_models(15)+1;
		models_param=[models_param type];	
 		source=[source;params ];
		nb_source=nb_source+2;		% 2 sources de plus
		nb_sortie=nb_sortie+2;		% 2 sorties de plus

		% tensions de sortie:  	Uab 
		%			Ubc 
		% sources courant de sortie:
		%			Ia->c (entrant dans phase A)
		%			Ib->c (entrant dans phase B)
	

		str=['y_u' num2str(nb_sortie-1) '=' '''' 'U_n' ...
		    num2str(params(1,1)) '_' num2str(params(2,1)) ''''  ';'];
		eval(str);
		str=['y_u' num2str(nb_sortie) '=' '''' 'U_n' ...
		    num2str(params(2,1)) '_' num2str(params(2,2)) ''''  ';'];
		eval(str); 
		srcstr=nstr2mat(srcstr,['I_',nsdezero(blocswo(i,:)),'_A']);
		srcstr=nstr2mat(srcstr,['I_',nsdezero(blocswo(i,:)),'_B']); 
		outstr=nstr2mat(outstr,['U_',nsdezero(blocswo(i,:)),'_AB']);
		outstr=nstr2mat(outstr,['U_',nsdezero(blocswo(i,:)),'_BC']);
	end
end

% SAVE RLC REFERENCE FOR SENSORS REQUESTS :
if ~isempty(rlc);
	BrancheRef=rlc(:,7:8);
	rlc(:,7)=[1:1:size(rlc,1)]';
	rlc(:,8)=[1:1:size(rlc,1)]'*0.0;
else
 	BrancheRef=[];
end


% SENSOR ANALYSIS :         

allcapteurnoeuds=[];
capteurlist=[];
capteurindice=[];
nb_true_sensor=0; 
for i=1:size(blocs,1)
	% Voltage measurement :
	if (	CustomBlocNumber(i)==9 )  	  
  		[str,NoeudAlloc]=nsfb17(blocs,lignes,i,Noeuds,...
			nb_sortie,NoeudAlloc);
 		eval(str);

		nb_sortie=nb_sortie+1;
		nb_true_sensor=nb_true_sensor+1;
		outstr=nstr2mat(outstr,['U_' blocswo(i,:)]);
		capteurlist=[capteurlist i];
		capteurindice=[	capteurindice nb_sortie];		
	end
	% Current measurement :
	if (	CustomBlocNumber(i)==10 )  	 
 		[str,capteurnoeuds,NoeudAlloc]=nsfb18(blocs,lignes,i, ...
			Noeuds,CustomBlocNumber,nb_sortie,BrancheRef,...
			rlc,source,NoeudAlloc); 
		eval(str);
		nb_sortie=nb_sortie+1;
		nb_true_sensor=nb_true_sensor+1;
		outstr=nstr2mat(outstr,['I_' blocswo(i,:)]);
		capteurlist=[capteurlist i];
		capteurindice=[	capteurindice nb_sortie];
 		allcapteurnoeuds=[allcapteurnoeuds; 	capteurnoeuds];	
	end
end

if size(srcstr,1)>0
	srcstr(1,:)=[];
end
if size(outstr,1)>0
	outstr(1,:)=[];
end

% SORTING OF VOLTAGE OUTPUT REQUEST TO EXTRACT NODE NUMBERS :
%   tri des variables de sorties se referant a nes numeros 
%   de noeuds modele: y_ux='U_nx1_x2'.
neusortieU=[];
indicesU_n=[];
for i=1:nb_sortie
	var1=['y_u' num2str(i)];   
 	if exist(var1)==1
		eval(['str=' var1 ';']);
		if sum(str(1:3)=='U_n')==3
			indicesU_n=[indicesU_n i];			 
			loc=find(str=='_');
 			neusortieU=[neusortieU; str2num(str(loc(1)+2: ...
				loc(2)-1))  str2num(str(loc(2)+1:length(str)))];
 		end
	end
end
 
% FUSION OF NODES SEPARATED BY CURRENT MEASUREMENT BLOCKS :
if ~isempty(allcapteurnoeuds)
	[Noeuds,rlc,source,switchns,neusortieU]= ...
	nscapnod(Noeuds,rlc,source,switchns,neusortieU,allcapteurnoeuds);
end
		
% REWRITE VOLTAGE OUTPUT REQUESTS IN THE RIGHT OUTPUT FORMAT :
%   reconversion des sorties sous le format y_ux='Ua_b'
for i=1:size(neusortieU,1)
	eval(['y_u' num2str(indicesU_n(i)) '=' '''' 'U_n' ...
        num2str(neusortieU(i,1)) '_' num2str(neusortieU(i,2))  '''' ';']);
end

% VECTORISATION OF ALL OUTPUT REQUESTS:
yout=[];	%matrice des valeurs seulement
y_type=[];	%vecteur du type de sortie tension:0 courant:1
for i=1:nb_sortie
	var1=['y_u' num2str(i)];
	var2=['y_i' num2str(i)];
 	if exist(var1)==1
		eval(['str=' var1 ';']);
		type='u';
		y_type(i)=0;
 	elseif exist(var2)==1
		eval(['str=' var2 ';']);
		type='i';
		y_type(i)=1;
	else
		error('nsgrafx err:1');
	end
 	str2=str;
	if size(yout,2)<length(str2)
	     yout=[yout ones(size(yout,1),1)*blanks(length(str2)-size(yout,2))];
	else
	     str2=[str2 blanks(size(yout,2)-length(str2))];
	end
	yout=[yout; str2];
end

% DISPLAY WARNINGS :
if isempty(rlc) & isempty(source)
	errstr=['FATAL! No rlc or source componants found in system: "' ...
	    system '". Analysis halted!'];
	nserror(errstr,'',14);
end

models_param=matrice_phase;
