function pointeur = nssysbld(n,sensorname,groupe,nb_models,models,nb_sensor, ...
		    pointeur,direct,gto,frm,spec,spec_line_dist,x0sw)
%NSSYSBLD Build structure of non-linear model subsystems into sensors
% 
%	NSSYSBLD(N,SENSORNAME,GROUPE,NB_MODELS,NB_SENSOR)
%	This code is used by nssyswrt.m function to build the structure
%	for subsystems that contains non-linear models in the SIMULINK 
%	figure.
%       This function is used by nssyswrt.m and cannot be used alone.
%
%	N		Rank number of the subsystem	
%	SENSORNAME	The name of the sensor that contains equivalent circuit
%	GROUPE		The name of the subsystem
%	NB_MODELS	Corresponding number of models for each subsystem.
%	NB_SENSOR	the number of sensors in the system

%	nb_models(1)	The number of fixed & Controlable sources in the figure
% 	nb_models(2)    The number of breaker blocks in the figure
% 	nb_models(3) 	The number of Simplified alternators in the figure
% 	nb_models(4) 	The number of saturated transformer blocks in the figure
% 	nb_models(5) 	The number of thyristors blocks in the figure
% 	nb_models(6)	The number of diode blocks in the figure
%	nb_models(7)	The number of Surge arrester in the figure
%	nb_models(8)    The number of switchs in the figure
%	nb_models(9)    The number of mosfet
%	nb_models(10)   Distributed parameters lines 
%	nb_models(11)   The number of Sychronous machine blocks in the figure
%	nb_models(12)   The number of gto
%	nb_models(13)   The number of switchs
%	nb_models(14)   The number of Simplified thyristor

%   Patrice Brunelle 01-23-96, 06-17-97
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.3 $

% modifs depuis la revision 1.1: 
% 1.  Modification de la lecture-ecriture des blocs goto/from : 16 septembre
 
sensorSysh = get_param(gcs,'Handle');

%%%%%%%%%%  CREATE 'groupe' SUBSYSTEM:  %%%%%%%%%%%%%%%%%%%%%%%%%%%

if ~exist('spec_line_dist'),spec_line_dist=[];end
systeme=[sensorname,'/source/',groupe];
pregrp=sum(nb_models(1:n-1)&1);
p1=180+50*(pregrp);
p2=p1+32;
position=[185,p1,240,p2];
nbr=nb_models(n);
nbrx=nbr;

% VECTORIZED GROUP ?:

vectorise=strcmp(groupe,'thyristor')| ...
	  strcmp(groupe,'thyristor_S')| ...
	  strcmp(groupe,'breaker')| ...
	  strcmp(groupe,'switch')| ...
	  strcmp(groupe,'mosfet')| ...
	  strcmp(groupe,'diode')| ...
	  strcmp(groupe,'gto') ;
if vectorise
    nbr=1;
end
if nbr==1
    substr='subs1';
else
    substr='subsn';
end
if n~=1 % (~= elec_src)
     add_block(['powerlib_utility/',substr],systeme)
     set_param(systeme,'position',position,'Orientation','left');
     add_line([sensorname,'/source'],'State-Space/1',[groupe,'/1'])
else
     add_block('powerlib_utility/subsour',systeme)
     set_param(systeme,'position',position,'Orientation','left'); 
end
add_line([sensorname,'/source'],[groupe,'/1'],['Mux/',num2str(pointeur)]);
pointeur = pointeur + 1;




%%%%%%%%%%%%  INSIDE 'groupe':   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 

if ~strcmp(groupe,'elec_src')

   % number of input voltages for each model:
   entrees=[1,1,2,1,1,1,1,1,4,1,2,1,1,1,2];
   sorties = nb_models(1:15).*entrees;
   sorties(1) = 0; % This model don't have a state-space output

   %% modif PB 06-17-97   cas particulier des lignes distribues.
   sorties(10)=sum(spec_line_dist);
   %% end of modif PB

   % Yout Selector :
   dep=num2str(sum(sorties(1:n-1))+1);
   arr=num2str(sum(sorties(1:n)));
   set_param([sensorname '/source/',groupe,'/Selector'],'Elements', ...
	[dep ':' arr],'InputPortWidth',num2str(direct) );

   % demux & mux blocks:
   if nb_models(n)~=1 & ~vectorise
	st=entrees(n)*ones(1,nbr);

	%% modif PB 06-16-97 cas particulier des lignes distribues.
	if strcmp(groupe,'dist_line')
		st=spec_line_dist;
	end
	%% end of modif PB

	set_param([sensorname '/source/',groupe,'/Demux'],'Outputs',mat2str(st))
	set_param([sensorname '/source/',groupe,'/Mux'],'Inputs',num2str(nbr))
   end

   %%%%%%   ADD THE MODELS:   %%%%%%%%%%%%%%%%%%%%
   
   lst=[];
   for k=1:nbrx
	lst=[lst,k,k+nbrx];
   end
   lst=mat2str(lst);
   for k=1:nbr
	blk = [systeme,'/d',num2str(k)];
	mod = nsdezero(models(sum(nb_models(1:n-1))+k,:));

	% import model from modellib library
	add_block(['powerlib_models/',groupe],blk)

	p1 = 20+(k-1)*65; 
	p2 = p1+45;
	set_param(blk,'position',[250,p1,280,p2]);


	%%%%%%%%   COPY MASK ENTRIES:   %%%%%%%%%%%%%%

	
	if vectorise
		mskentries=spec; 
	else
		mskentries=get_param(mod,'MaskValueString');
	end

	%%%%  MASK SPECIALS: %%%%%%%

	if strcmp(groupe,'transfosat')
	 
		% mask is set later in power2sys code.
		
	elseif strcmp(groupe,'simp_alt')|strcmp(groupe,'sync_mac')|strcmp(groupe,'async_mac')
	
	        typ=get_param([mod,'/data/type'],'mask entries');
		% SI :
		if typ=='1'
			if strcmp(groupe,'simp_alt')
				x1=str2num(get_param(mod,'x1'));
				x2=str2num(get_param(mod,'x2'));
				x3=str2num(get_param(mod,'x3'));
				x4=str2num(get_param(mod,'x4'));
				mskentries=bl24conv(x1,x2,x3,x4);
			elseif strcmp(groupe,'sync_mac')
				x1=str2num(get_param(mod,'x1'));
				x2=str2num(get_param(mod,'x2'));
				x3=str2num(get_param(mod,'x3'));
				x4=str2num(get_param(mod,'x4'));
				x5=str2num(get_param(mod,'x5'));
				x6=str2num(get_param(mod,'x6'));
				x7=get_param(mod,'x7');
				x8=str2num(get_param(mod,'x8'));
				x9=get_param(mod,'x9');
				mskentries=bl25conv(x1,x2,x3,x4,x5,x6,x7,x8,x9,'1');
			else
				x1=str2num(get_param(mod,'x1'));
				x2=str2num(get_param(mod,'x2'));
				x3=str2num(get_param(mod,'x3'));
				x4=str2num(get_param(mod,'x4'));
				x5=str2num(get_param(mod,'x5'));
				x6=str2num(get_param(mod,'x6'));
				mskentries=bl29conv(x1,x2,x3,x4,x5,x6);
			end
			set_param(blk,'MaskValueString',mskentries);

		% PU : direct transfer of maskValueString
		elseif typ=='2' 
			set_param(blk,'MaskValueString',mskentries);
			
		% PU STANDARD : synchronous machine only.
		else 
			x1=str2num(get_param(mod,'x1'));
			x2=str2num(get_param(mod,'x2'));
			x3=str2num(get_param(mod,'x3'));
			x4=str2num(get_param(mod,'x4'));
			x5=str2num(get_param(mod,'x5'));
			x6=str2num(get_param(mod,'x6'));
			x7=get_param(mod,'x7');
			x8=str2num(get_param(mod,'x8'));
			x9=get_param(mod,'x9');
			mskentries=bl25conv(x1,x2,x3,x4,x5,x6,x7,x8,x9,'3');
			set_param(blk,'MaskValueString',mskentries);
		end

	elseif strcmp(groupe,'dist_line')

%		mskentries=[mskentries,'|0|0|0|0|0'];
%		set_param(blk,'MaskValueString',mskentries);

	else
	        set_param(blk,'MaskValueString',mskentries);
	end


	%%%%%%%%   MAKE THE GOTO->FROM LINK: %%%%%%%%%%%%%%%%

	set_param(0,'CurrentSystem',sensorSysh);
	if vectorise
		if gto>0
			set_param([systeme,'/gotos/Demux'],'Outputs',num2str(gto));
			set_param([systeme,'/gotos/Selector'], ...
				'Elements',lst, ...
				'InputPortWidth',num2str(2*nbrx));
			add_line(systeme,'d1/2','gotos/1');
			for i=1:gto
				p1 = 30+35*(i-1);
				p2 = p1+30;
				mod = nsdezero(models(sum(nb_models(1:n-1))+i,:));
				num = num2str(i);
				add_block('built-in/Goto',[systeme,'/gotos/Goto',num])

				tagg = get_param([mod,'/From'],'GotoTag');

				set_param([systeme,'/gotos/Goto',num], ...
					'position',[220,p1,275,p2], ...
					'GotoTag',tagg, ...
					'TagVisibility','global');

				add_line([systeme,'/gotos'],['Demux/',num],['Goto',num,'/1']);
			end
		else
			delete_block([systeme,'/gotos']);
		end

		set_param(0,'CurrentSystem',sensorSysh);

		if frm>0
			set_param([systeme,'/froms/Mux'],'inputs',num2str(frm));
			add_line(systeme,'froms/1','d1/2');

			for i=1:frm
				p1 = 30+35*(i-1);
				p2 = p1+30;
				mod = nsdezero(models(sum(nb_models(1:n-1))+i,:));
				num = num2str(i);
				add_block('built-in/From',[systeme,'/froms/From',num])

				tagg = get_param([mod,'/Goto'],'GotoTag');

				set_param([systeme,'/froms/From',num], ...
					'position',[20,p1,75,p2] , ...
					'GotoTag',tagg);

				add_line([systeme,'/froms'],['From',num,'/1'],['Mux/',num]);
			end
		else
			delete_block([systeme,'/froms']);
		end

		set_param(0,'CurrentSystem',sensorSysh);

	else
		set_param(0,'CurrentSystem',sensorSysh);
		if nbr==1,
			delete_block([systeme,'/gotos']);
			set_param(0,'CurrentSystem',sensorSysh);
			delete_block([systeme,'/froms']);
			
		end
		for i=1:frm
			p1 = 52+65*(k-1)+(i-1)*15;
			p2 = p1+16;
			set_param(0,'CurrentSystem',sensorSysh);
			add_block('built-in/From',[systeme,'/From',num2str(k),num2str(i)]);
			set_param(0,'CurrentSystem',sensorSysh);

			if frm==1
			    tagg = get_param([mod,'/Goto'],'GotoTag');
			else
			    tagg = get_param([mod,'/Goto',num2str(i)],'GotoTag');
			end

			set_param([systeme,'/From',num2str(k),num2str(i)], ...
				'position',[195,p1,230,p2], ...
				'GotoTag',tagg);

			add_line(systeme,['From',num2str(k),num2str(i),'/1'], ...
				['d',num2str(k),'/',num2str(i+1)]);
		end
		set_param(0,'CurrentSystem',sensorSysh);
		for i=1:gto
			p1 = 52+65*(k-1)+(i-1)*10;
			p2 = p1+16;
			add_block('built-in/Goto',[systeme,'/Goto',num2str(k),num2str(i)]);

			tagg = get_param([mod,'/From'],'GotoTag');

			set_param([systeme,'/Goto',num2str(k),num2str(i)], ...
				'position',[340,p1,380,p2], ...
				'GotoTag',tagg, ...
				'tagvisibility','Global');

			add_line(systeme,['d',num2str(k),'/',num2str(i+1)], ...
				['Goto',num2str(k),num2str(i),'/1']);
		end
	end


	%%%%%%%%%%%    ADD CONNECTOR LINES:  %%%%%%%%%%%%%%%%%%
	
	if ~vectorise&nbr>1
	    add_line([sensorname,'/source/',groupe],['Demux/',num2str(k)],...
		['d',num2str(k),'/1'])
	    add_line([sensorname,'/source/',groupe],['d',num2str(k),'/1'],...
		['Mux/',num2str(k)])
	elseif vectorise|nbr==1
	    add_line([sensorname,'/source/',groupe],'Selector/1',...
		['d',num2str(k),'/1'])
	    add_line([sensorname,'/source/',groupe],['d',num2str(k),'/1'],...
		'Out/1')
	end
   end
   
else   		   %%%%   elec_src group   %%%%%%

   set_param([sensorname,'/source/elec_src/Mux'],'inputs',num2str(nbr))
   for k=1:nbr
	p1 = 30+35*(k-1);
	p2 = p1+30;
	mod = nsdezero(models(sum(nb_models(1:n-1))+k,:));
	num = num2str(k);


	tagg = get_param([mod,'/Goto'],'GotoTag');

	add_block('built-in/From',[sensorname,'/source/elec_src/from',num])
	set_param([sensorname,'/source/elec_src/from',num],...
		'position',[20,p1,75,p2],...
		'GotoTag',tagg);

	add_line([sensorname,'/source/elec_src'],...
		['from',num,'/1'],['Mux/',num])
   end

end
