function simsensor=nssyswrt(blocks,nb_models,models,models_param,nb_sensor,  ...
         true_src,switchns,x0sw,sensorlist,sensorindice,systeme,sizeA,sizeB, ...
         sizeC, sizeD)
%NSSYSWRT Write State-Space system in sensor blocks
%
%       This code generate the internal structure of 'sensor' blocks 
%       in the SIMULINK figure. This is to assure simulation of the network.  
%       This function is used by netsim.m and cannot be used alone.

%   Patrice Brunelle 01-18-95, 06-17-97
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.4 $

% modifs depuis revision 1.1:
%       1. modification du code pour fonctionalite library.
%	2. modification dans nscoerans: il n'y a plus de mauvais measurements.

% Initializations.
sensorname=gcb;
sensorBlkh = gcbh;
sensorSysh = get_param(gcs,'Handle');

pointeur=1;
states=sizeA(1);
direct=sizeD(1);
if direct==0,direct=sizeC(1);end
simsensor='';
spec_line_dist=models_param;

 
% Load simulink models and utility blocks.
powerlib_models([],[],[],'load');
powerlib_utility([],[],[],'load');
powerlib([],[],[],'load');



if ~strcmp(gcb,sensorname)
set_param(0,'CurrentSystem',sensorSysh);
end


% Chose the apropriate structure for the equivalent circuit.
t2=sum(nb_models)==0;
if nb_sensor>1
   if t2
	quelstruct='struct4';
   else
	quelstruct='struct3';
   end
else
   if t2
	quelstruct='struct1';
   else
	quelstruct='struct2';
   end
end



% Replace the current 'source' block (old eq.circuit or default block) by a new one.
position=get_param([sensorname,'/source'],'Position');
delete_line(sensorname,'source/1','Gain/1');
delete_block([sensorname,'/source']);
add_block(['powerlib_utility/',quelstruct],[sensorname,'/source'],'Position',position);
add_line(sensorname,'source/1','Gain/1');


set_param(0,'CurrentSystem',sensorSysh);


% Set correctly the State-Space block.

% system without states-variables.
if states==0  
   set_param([sensorname,'/source/State-Space'],'D','D')

   % system with inputs.
   if ~t2 
	set_param([sensorname,'/source/Mux'],'inputs',num2str(sum([nb_models&1])))
   end

% system with states-variables.
else             
		
   % system with inputs.
   if ~t2 



set_param(0,'CurrentSystem',sensorSysh);

	set_param([sensorname,'/source/Mux'],'inputs',num2str(sum([nb_models&1])))
	set_param([sensorname,'/source/State-Space'],'A','A','B','B','C','C','D','D','X0','x0')

   % system without inputs.
   else

	set_param([sensorname,'/source/State-Space'],...
		'A','A','B','zeros(size(A,1),1)', ...
		'C','C','D','[0]','X0','x0')

   end
end

% Add the model subsystems.

% 'elec_src' subsystem.
n   = 1;
gto = 0;
frm = 0;
if nb_models(n)>0
	pointeur = nssysbld(n,sensorname,'elec_src', ...
		 nb_models,models,nb_sensor,pointeur,...
		direct,gto,frm);
end

% 'breaker' subsystem.
n   = 2;
gto = 0;
frm = nb_models(n);
if nb_models(n)>0
	spec=[];
	Rslist=[]; 
	Lslist=[];
	IClist=[];
	for k=1:nb_models(n)
		mod=deblank(models(sum(nb_models(1:n-1))+k,:));
		mskentries=get_param(mod,'Mask Entries');
		retvar=nsparm(mskentries,mod);
		Rslist(k)=retvar{1};
		Lslist(k)=retvar{2};
		IClist(k)=x0sw(k);
	end
	Rs=mat2str(Rslist);
	Ls=mat2str(Lslist);
	IC=mat2str(IClist);
	spec=[Rs,'|',Ls,'|',IC];
	pointeur = nssysbld(n,sensorname,'breaker', ...
		nb_models,models,nb_sensor,pointeur,...
		direct,gto,frm,spec,spec_line_dist,x0sw);
end

% 'simp_alt' subsystem.
n   = 3;
frm = 2;
gto = 1;
if nb_models(n)>0
	pointeur = nssysbld(n,sensorname,'simp_alt', ...
	           nb_models,models,nb_sensor,pointeur,...
		   direct,gto,frm,[],spec_line_dist);
end
 
% 'transfosat' subsystem. 
n   = 4;
gto = 0;
frm = 0;
if nb_models(n)>0
	pointeur = nssysbld(n,sensorname,'transfosat', ...
		nb_models,models,nb_sensor,pointeur,...
		direct,gto,frm,[],spec_line_dist);
end

% 'thyristor' subsystem.
n   = 5;
gto = nb_models(n);
frm = gto;
if nb_models(n)>0 
	spec=[];
	Rtlist=[]; 
	Ltlist=[]; 
	Vtlist=[]; 
	Illist=[]; 
	Tqlist=[]; 
	IClist=[]; 
	for k=1:nb_models(n)
		mod=deblank(models(sum(nb_models(1:n-1))+k,:));
		mskentries = get_param(mod,'Mask Entries');
		retvar=nsparm(mskentries,mod);
		Rtlist(k)=retvar{1};
		Ltlist(k)=retvar{2};
		Vtlist(k)=retvar{3};
		Illist(k)=retvar{4};
		Tqlist(k)=retvar{5};
		IClist(k)=retvar{6};
	end
	Rt = mat2str(Rtlist);
	Lt = mat2str(Ltlist);
	Vt = mat2str(Vtlist);
	Il = mat2str(Illist);
	Tq = mat2str(Tqlist);
	IC = mat2str(IClist);
	spec=[Rt,'|',Lt,'|',Vt,'|',Il,'|',Tq,'|',IC,'|0|0'];
	pointeur = nssysbld(n,sensorname,'thyristor', ...
		nb_models,models,nb_sensor,pointeur,...
		direct,gto,frm,spec,spec_line_dist);
end

% 'diode' subsystem.
n   = 6;
gto = nb_models(n);
frm = 0;
if nb_models(n)>0
	spec=[];
	Lflist=[]; 
	Rflist=[];
	Vflist=[];
	IClist=[];
	for k=1:nb_models(n)
		mod=deblank(models(sum(nb_models(1:n-1))+k,:));
		mskentries = get_param(mod,'Mask Entries');
		retvar=nsparm(mskentries,mod);
		Rflist(k)=retvar{1};
		Lflist(k)=retvar{2};
		Vflist(k)=retvar{3};
		IClist(k)=retvar{4};
	end
	Lf = mat2str(Lflist);
	Rf = mat2str(Rflist);
	Vf = mat2str(Vflist);
	IC = mat2str(IClist);
	spec=[Rf,'|',Lf,'|',Vf,'|',IC,'|0|0'];
	pointeur = nssysbld(n,sensorname,'diode', ...
		nb_models,models,nb_sensor,pointeur,...
		direct,gto,frm,spec,spec_line_dist);
end

% 'Surge' subsystem.
n   = 7;
gto = 0;
frm = 0;
if nb_models(n)>0
	pointeur = nssysbld(n,sensorname,'surge', ...
		nb_models,models,nb_sensor,pointeur,...
		direct,gto,frm,spec_line_dist);
end

% 'mosfet' subsystem.
n   = 8;
gto = nb_models(n);
frm = gto;
if nb_models(n)>0
	spec=[];
	Rtlist=[];
	Ltlist=[];
	Rdlist=[]; 
	IClist=[]; 
	for k=1:nb_models(n)
		mod=deblank(models(sum(nb_models(1:n-1))+k,:));
		mskentries=get_param(mod,'Mask Entries');
		retvar=nsparm(mskentries,mod);
		Rtlist(k)=retvar{1};
		Ltlist(k)=retvar{2};
		Rdlist(k)=retvar{3};
		IClist(k)=retvar{4};
	end
	Rt=mat2str(Rtlist);
	Lt=mat2str(Ltlist);
	Rd=mat2str(Rdlist);
	IC=mat2str(IClist);
	spec=[Rt,'|',Lt,'|',Rd,'|',IC,'|0|0'];
	pointeur = nssysbld(n,sensorname,'mosfet', ...
		 nb_models,models,nb_sensor,pointeur,...
		 direct,gto,frm,spec,spec_line_dist);
end

% 'async_mac' subsystem.
n   = 9;
gto = 1;
frm = 1;
if nb_models(n)>0
	pointeur = nssysbld(n,sensorname,'async_mac', ...
	        nb_models,models,nb_sensor,pointeur,...
	        direct,gto,frm,[],spec_line_dist);
end

% 'dist_line' subsystem.
n   = 10;
gto = 0;
frm = 0;
spec=models_param; 
if nb_models(n)>0
	pointeur = nssysbld(n,sensorname,'dist_line', ...
		nb_models,models,nb_sensor,pointeur,...
		direct,gto,frm,[],spec_line_dist);
end

% 'sync_mac' subsystem.
n   = 11;
gto = 1;
frm = 2;
if nb_models(n)>0
	pointeur = nssysbld(n,sensorname,'sync_mac', ...
		nb_models,models,nb_sensor,pointeur,...
		direct,gto,frm,[],spec_line_dist);
end

% 'gto' subsystem.
n   = 12;
gto = nb_models(n);
frm = gto;
if nb_models(n)>0
	spec=[];
	RTlist=[];
	LTlist=[]; 
	Vflist=[]; 
	Tflist=[]; 
	Ttlist=[];
	IClist=[]; 
	for k=1:nb_models(n)
		mod=deblank(models(sum(nb_models(1:n-1))+k,:));
		mskentries=get_param(mod,'Mask Entries');
		retvar=nsparm(mskentries,mod);
		RTlist(k)=retvar{1};
		LTlist(k)=retvar{2};
		Vflist(k)=retvar{3};
		Tflist=retvar{4};  
		Ttlist=retvar{5};
		IClist(k)=retvar{6};
	end
	RT=mat2str(RTlist);
	LT=mat2str(LTlist);
	Vf=mat2str(Vflist);
	Tf=mat2str(Tflist);
	Tt=mat2str(Ttlist);
	IC=mat2str(IClist);

	spec=[RT,'|',LT,'|',Vf,'|',Tf,'|',Tt,'|',IC,'|0|0'];
	pointeur = nssysbld(n,sensorname,'gto', ...
		nb_models,models,nb_sensor,pointeur,...
		direct,gto,frm,spec,spec_line_dist);
end

%  'switch' subsystem.
n   = 13;
gto = nb_models(n);
frm = gto;
delta = nb_models(2)+nb_models(5)+ ...
nb_models(6)+nb_models(8)+nb_models(12);
if nb_models(n)>0
	spec=[];
	RTlist=[]; 
	LTlist=[];
	IClist=[];
	for k=1:nb_models(n)
		mod=deblank(models(sum(nb_models(1:n-1))+k,:));
		mskentries=get_param(mod,'Mask Entries');
		retvar=nsparm(mskentries,mod);
		RTlist(k)=retvar{1};
		LTlist(k)=retvar{2};
		IClist(k)=x0sw(delta+k);
	end
	RT=mat2str(RTlist);
	LT=mat2str(LTlist);
	IC=mat2str(IClist);
	spec=[RT,'|',LT,'|',IC,'|0|0'];
	pointeur = nssysbld(n,sensorname,'switch', ...
		nb_models,models,nb_sensor,pointeur,...
		direct,gto,frm,spec,spec_line_dist,x0sw);
end

%  'thyristor_S' subsystem.
n   = 14;
gto = nb_models(n);
frm = gto;
if nb_models(n)>0 
	spec=[];
	Rtlist=[];
	Ltlist=[];
	Vtlist=[]; 
	Illist=[]; 
	IClist=[];
	for k=1:nb_models(n)
		mod=deblank(models(sum(nb_models(1:n-1))+k,:));
		mskentries = get_param(mod,'Mask Entries');
		retvar=nsparm(mskentries,mod);
		Rtlist(k)=retvar{1};
		Ltlist(k)=retvar{2};
		Vtlist(k)=retvar{3};
		Illist(k)=retvar{4};
	end
	Rt = mat2str(Rtlist);
	Lt = mat2str(Ltlist);
	Vt = mat2str(Vtlist);
	Il = mat2str(Illist);
	spec=[Rt,'|',Lt,'|',Vt,'|',Il,'|0|0'];
	pointeur = nssysbld(n,sensorname,'thyristor_S', ...
		nb_models,models,nb_sensor,pointeur,...
		direct,gto,frm,spec,spec_line_dist);
end

%  'sync_mot' subsystem.
n   = 15;
gto = 1;
frm = 1;
if nb_models(n)>0
	pointeur = nssysbld(n,sensorname,'sync_mot', ...
		nb_models,models,nb_sensor,pointeur,...
		direct,gto,frm,[],spec_line_dist);
end


% Make the connexion with all others measurements blocks.

% Set the Selector and the Demux blocks correctly.
n_meas = length(sensorindice);
selection = mat2str(sensorindice(1:end));
set_param([sensorname '/source/transit/Selector'], ...
	'Elements',selection, ...
	'InputPortWidth',num2str(direct) );
set_param([sensorname '/source/transit/Demux'], ...
	'Outputs',num2str(n_meas))


% Loop throught the measurement block list.
for k=1:n_meas
	name=nsdezero(blocks(sensorlist(k),:));

	% this is the first measurement block.
	if strcmp(name,sensorname)

		% Connect with Output block. 
		add_line([sensorname,'/source/transit'],['Demux/',num2str(k)],'Out/1');

	% Other measurement blocks.
	else

		% Connect to a Goto block.
		p1=70+45*(k-1);
		p2=p1+30;
		position=[330,p1,360,p2];
		tag=get_param([name,'/source'],'GotoTag');
		add_block('built-in/Goto',[sensorname,'/source/transit/Goto',num2str(k)]);
		set_param([sensorname,'/source/transit/Goto',num2str(k)], ...
			'position',position, ...
			'GotoTag',tag, ...
			'TagVisibility','global');
		add_line([sensorname,'/source/transit'],['Demux/',num2str(k)],['Goto',num2str(k),'/1'])
	end
end


% Set a special Tag for this measurement block: needed by the checksum mechanism.
set_param(sensorname,'Tag','PoWeRsYsTeMmEaSuReMeNtFiRsT');

% return
simsensor=sensorname;
