function psbchecksum(system)
%
% CHECKSUM is called by all Power System  blocks InitFcn.
%
%   Patrice Brunelle
%   Copyright (c) 1997 by TEQSIM Inc. and The MathWorks, Inc.
%   under sublicense from Hydro-Quebec.
%   $Revision: 1.3 $

%Look for measurement blocks.
m_blocks = find_system(system,'LookUnderMasks','on','Tag','PoWeRsYsTeMmEaSuReMeNt');

%Look For measurement block that contains an old equivalent circuit.
mfirst_block = find_system(system,'LookUnderMasks','on','Tag','PoWeRsYsTeMmEaSuReMeNtFiRsT');
m_blocks = [mfirst_block;m_blocks];

%Display an error if no measurement block found.
if isempty(m_blocks)
    p_blocks=find_system(system,'LookUnderMasks','on','Tag','PoWeRsYsTeMbLoCk');
    if strcmp(gcb,p_blocks{end})
   	errordlg('No Measurement Blocks found.')
    end

%Do the checksum on the first measurement block.
elseif strcmp(gcb,m_blocks{1})
    check(system);
end




function check(system)
%
% CHECK evaluate if power2sys is required before starting the simulation.
%
%   Patrice Brunelle

% Look into the store object for the reference maskvalue matrix.
 
psbdatas=loadsavedata(system,'load');

if isempty(psbdatas)
   ref_maskvalue={};
   ref_lines={};
else
   ref_maskvalue=psbdatas.ref_maskvalue;
   ref_lines=psbdatas.ref_lines;
end

% Get the current Power System block list.
new_1 = find_system(system,'LookUnderMasks','on','Tag','PoWeRsYsTeMbLoCk');
new_2 = find_system(system,'LookUnderMasks','on','Tag','PoWeRsYsTeMmEaSuReMeNt');
new_blocks = [new_1;new_2];
new_blocks_masks = get_param(new_blocks,'Mask Entries');

% Get lines at bottom level.
new_lines = get_param(system,'lines');

% Build current_maskvalue matrix and current_lines matrix.
current_maskvalue{1}=new_blocks_masks;
current_lines{1}=new_lines;
stop=0;i=2;
child=new_blocks;
while stop==0
    [stop,child,masks,parent_lines]=parentmasks(child,system);
    current_maskvalue{i}=masks;
    current_lines{i}=parent_lines;
    i=i+1;	
end

% Run POWER2SYS if needed.
if ~isequal(ref_maskvalue,current_maskvalue) |~isequal(ref_lines,current_lines)
    power2sys(system,'&');
    psbdatas=loadsavedata(system,'load');
    psbdatas.ref_maskvalue=current_maskvalue;
    psbdatas.ref_lines=current_lines;
    loadsavedata(system,'save',psbdatas);
    return
end


 


function [stop,parents,parents_masks,parents_lines]=parentmasks(childs,system)
%
% PARENTMASK returns the mask entries of the parents of childs blocks.
%
%   Patrice Brunelle


stop=1;

for i=1:size(childs,1)
    if isempty(childs{i,1})
	parents_masks{i,1}=[];
	parents{i,1}=[];
	parents_lines{i,1}=[];
    else
	parents{i,1} = get_param(childs{i,1},'Parent');
	if strcmp(parents{i,1},system)|isempty(parents{i,1})
	    parents_masks{i,1}=[];
	    parents_lines{i,1}=[];
	else
	    parents_masks{i,1}=get_param(parents{i,1},'Mask Entries');
	    parents_lines{i,1}=get_param(parents{i,1},'Lines');
	    stop=0; 
	end
    end  
end
